@@ -23,7 +23,7 @@
                          || !PyArray_ISCARRAY(a) || !PyArray_ISNUMBER(a)) { \
     PyErr_SetString(PyExc_TypeError,                                        \
                     "Not a proper NumPy array for MPI communication.");     \
-    return NULL; }
+    return NULL; } else
 
 // Check that array is well-behaved, read-only  and contains data that
 // can be sent.
@@ -32,7 +32,7 @@
                          || !PyArray_ISNUMBER(a)) {                         \
     PyErr_SetString(PyExc_TypeError,                                        \
                     "Not a proper NumPy array for MPI communication.");     \
-    return NULL; }
+    return NULL; } else
 
 // Check that two arrays have the same type, and the size of the
 // second is a given multiple of the size of the first
@@ -41,22 +41,22 @@
       || (PyArray_SIZE(b) != PyArray_SIZE(a) * n)) {                    \
     PyErr_SetString(PyExc_ValueError,                                   \
                     "Incompatible array types or sizes.");              \
-      return NULL; }
+      return NULL; } else
 
 // Check that a processor number is valid
 #define CHK_PROC(n) if (n < 0 || n >= self->size) {\
     PyErr_SetString(PyExc_ValueError, "Invalid processor number.");     \
-    return NULL; }
+    return NULL; } else
 
 // Check that a processor number is valid or is -1
 #define CHK_PROC_DEF(n) if (n < -1 || n >= self->size) {\
     PyErr_SetString(PyExc_ValueError, "Invalid processor number.");     \
-    return NULL; }
+    return NULL; } else
 
 // Check that a processor number is valid and is not this processor
 #define CHK_OTHER_PROC(n) if (n < 0 || n >= self->size || n == self->rank) { \
     PyErr_SetString(PyExc_ValueError, "Invalid processor number.");     \
-    return NULL; }
+    return NULL; } else
 
 // MPI request object, so we can store a reference to the buffer,
 // preventing its early deallocation.
@@ -201,13 +201,54 @@ static GPAW_MPI_Request *NewMPIRequest(void)
   return self;
 }
 
+
+static void mpi_ensure_finalized(void)
+{
+    int already_finalized = 1;
+    int ierr = MPI_SUCCESS;
+
+    MPI_Finalized(&already_finalized);
+    if (!already_finalized)
+    {
+        ierr = MPI_Finalize();
+    }
+    if (ierr != MPI_SUCCESS)
+        PyErr_SetString(PyExc_RuntimeError, "MPI_Finalize error occurred");
+}
+
+
+// MPI initialization
+static void mpi_ensure_initialized(void)
+{
+    int already_initialized = 1;
+    int ierr = MPI_SUCCESS;
+
+    // Check whether MPI is already initialized
+    MPI_Initialized(&already_initialized);
+    if (!already_initialized)
+    {
+        // if not, let's initialize it
+        ierr = MPI_Init(NULL, NULL);
+        if (ierr == MPI_SUCCESS)
+        {
+            // No problem: register finalization when at Python exit
+            Py_AtExit(*mpi_ensure_finalized);
+        }
+        else
+        {
+            // We have a problem: raise an exception
+            char err[MPI_MAX_ERROR_STRING];
+            int resultlen;
+            MPI_Error_string(ierr, err, &resultlen);
+            PyErr_SetString(PyExc_RuntimeError, err);
+        }
+    }
+}
+
+
 static void mpi_dealloc(MPIObject *obj)
 {
-    if (obj->comm == MPI_COMM_WORLD) {
-#       ifndef GPAW_INTERPRETER
-            MPI_Finalize();
-#       endif
-    } else
+    if (obj->comm != MPI_COMM_WORLD)
         MPI_Comm_free(&(obj->comm));
     Py_XDECREF(obj->parent);
     free(obj->members);
@@ -827,7 +868,11 @@ static PyObject * mpi_broadcast(MPIObject *self, PyObject *args)
   int root;
   if (!PyArg_ParseTuple(args, "Oi:broadcast", &buf, &root))
     return NULL;
-  CHK_ARRAY(buf);
+  if (root == self->rank)
+      CHK_ARRAY_RO(buf);
+  else
+      CHK_ARRAY(buf);
+
   CHK_PROC(root);
   int n = PyArray_DESCR(buf)->elsize;
   for (int d = 0; d < PyArray_NDIM(buf); d++)
@@ -1066,9 +1111,7 @@ static PyObject *NewMPIObject(PyTypeObject* type, PyObject *args,
     if (self == NULL)
         return NULL;
 
-#   ifndef GPAW_INTERPRETER
-        MPI_Init(NULL, NULL);
-#   endif
+    mpi_ensure_initialized();
 
     MPI_Comm_size(MPI_COMM_WORLD, &(self->size));
     MPI_Comm_rank(MPI_COMM_WORLD, &(self->rank));
