@@ -417,54 +417,6 @@ PyObject* utilities_gaussian_wave(PyObject *self, PyObject *args)
 }
 
 
-/* vdot
- *
- * If a and b are input vectors,
- * a[0]*b[0] + a[1]*b[1] + a[2]*b[2] + ...
- * is returned.
- */
-PyObject* utilities_vdot(PyObject *self, PyObject *args)
-{
-  PyArrayObject* aa;
-  PyArrayObject* bb;
-  if (!PyArg_ParseTuple(args, "OO", &aa, &bb))
-    return NULL;
-  const double* const a = DOUBLEP(aa);
-  const double* const b = DOUBLEP(bb);
-  double sum = 0.0;
-  int n = 1;
-  for (int d = 0; d < PyArray_NDIM(aa); d++)
-    n *= PyArray_DIMS(aa)[d];
-  for (int i = 0; i < n; i++)
-    {
-      sum += a[i] * b[i];
-    }
-  return PyFloat_FromDouble(sum);
-}
-
-/* vdot
- *
- * If a is the input vector,
- * a[0]*a[0] + a[1]*a[1] + a[2]*a[2] + ...
- * is returned.
- */
-PyObject* utilities_vdot_self(PyObject *self, PyObject *args)
-{
-  PyArrayObject* aa;
-  if (!PyArg_ParseTuple(args, "O", &aa))
-    return NULL;
-  const double* const a = DOUBLEP(aa);
-  double sum = 0.0;
-  int n = 1;
-  for (int d = 0; d < PyArray_NDIM(aa); d++)
-    n *= PyArray_DIMS(aa)[d];
-  for (int i = 0; i < n; i++)
-    {
-      sum += a[i] * a[i];
-    }
-  return PyFloat_FromDouble(sum);
-}
-
 PyObject* errorfunction(PyObject *self, PyObject *args)
 {
   double x;
