@@ -23,170 +23,6 @@ typedef struct
   int nspin; /* must be common to x and c, so declared redundantly here */
 } lxcXCFunctionalObject;
 
-void XC(lda_fxc_fd)(const XC(func_type) *p, const double *rho, double *fxc);
-
-/* a general call for an LDA functional - finite difference */
-void get_fxc_fd_lda(XC(func_type) *func, double point[7], double der[5][5])
-{
-  double v2rho2[3], v2rhosigma[6], v2sigma2[6];
-
-  for(int i=0; i<3; i++) v2rho2[i] = 0.0;
-  for(int i=0; i<6; i++){
-    v2rhosigma[i] = 0.0;
-    v2sigma2[i]    = 0.0;
-  }
-  XC(lda_fxc_fd)(func, point, v2rho2);
-  der[0][0] = v2rho2[0];
-  der[0][1] = der[1][0] = v2rho2[1];
-  der[1][1] = v2rho2[2];
-  der[0][2] = der[2][0] = v2rhosigma[0];
-  der[0][3] = der[3][0] = v2rhosigma[1];
-  der[0][4] = der[4][0] = v2rhosigma[2];
-  der[1][2] = der[2][1] = v2rhosigma[3];
-  der[1][3] = der[3][1] = v2rhosigma[4];
-  der[1][4] = der[4][1] = v2rhosigma[5];
-  der[2][2] = v2sigma2[0];
-  der[2][3] = der[3][2] = v2sigma2[1];
-  der[2][4] = der[4][2] = v2sigma2[2];
-  der[3][3] = v2sigma2[3];
-  der[3][4] = der[4][3] = v2sigma2[4];
-  der[4][4] = v2sigma2[5];
-}
-
-// finite difference calculation of second functional derivative
-// stolen from libxc/testsuite/xc-consistency.c
-
-double get_point(XC(func_type) *func, double point[7], double *e, double der[5], int which)
-{
-  const int np = 1;
-  switch(func->info->family)
-    {
-    case XC_FAMILY_LDA:
-      XC(lda_exc_vxc)(func, np, &(point[0]), e, &(der[0]));
-      break;
-    case XC_FAMILY_GGA:
-    case XC_FAMILY_HYB_GGA:
-      XC(gga_exc_vxc)(func, np, &(point[0]), &(point[2]),
-                      e, &(der[0]), &(der[2]));
-      break;
-    }
-
-  if(which == 0)
-    return (*e)*(point[0] + point[1]);
-  else
-    return der[which-1];
-}
-
-void first_derivative(XC(func_type) *func, double point[7], double der[5], int which,
-                      int nspin)
-{
-  int i;
-
-  for(i=0; i<5; i++){
-    const double delta = 5e-10;
-
-    double dd, p[5], v[5];
-    int j;
-
-    if(nspin==1 && (i!=0 && i!=2)){
-      der[i] = 0.0;
-      continue;
-    }
-
-    dd = point[i]*delta;
-    if(dd < delta) dd = delta;
-
-    for(j=0; j<5; j++) p[j] = point[j];
-
-    if(point[i]>=3.0*dd){ /* centered difference */
-      double e, em1, em2, ep1, ep2;
-
-      p[i] = point[i] + dd;
-      ep1 = get_point(func, p, &e, v, which);
-
-      p[i] = point[i] + 2*dd;
-      ep2 = get_point(func, p, &e, v, which);
-
-      p[i] = point[i] - dd;  /* backward point */
-      em1 = get_point(func, p, &e, v, which);
-
-      p[i] = point[i] - 2*dd;  /* backward point */
-      em2 = get_point(func, p, &e, v, which);
-
-      der[i]  = 1.0/2.0*(ep1 - em1);
-      der[i] += 1.0/12.0*(em2 - 2*em1 + 2*ep1 - ep2);
-
-      der[i] /= dd;
-
-    }else{  /* we use a 5 point forward difference */
-      double e, e1, e2, e3, e4, e5;
-
-      p[i] = point[i];
-      e1 = get_point(func, p, &e, v, which);
-
-      p[i] = point[i] + dd;
-      e2 = get_point(func, p, &e, v, which);
-
-      p[i] = point[i] + 2.0*dd;
-      e3 = get_point(func, p, &e, v, which);
-
-      p[i] = point[i] + 3.0*dd;
-      e4 = get_point(func, p, &e, v, which);
-
-      p[i] = point[i] + 4.0*dd;
-      e5 = get_point(func, p, &e, v, which);
-
-      der[i]  =          (-e1 + e2);
-      der[i] -=  1.0/2.0*( e1 - 2*e2 + e3);
-      der[i] +=  1.0/3.0*(-e1 + 3*e2 - 3*e3 + e4);
-      der[i] -=  1.0/4.0*( e1 - 4*e2 + 6*e3 - 4*e4 + e5);
-
-      der[i] /= dd;
-    }
-  }
-}
-
-void first_derivative_spinpaired(XC(func_type) *func, double point[7], double der[5],
-                                 int which)
-{
-  first_derivative(func, point, der, which, XC_UNPOLARIZED);
-}
-
-void first_derivative_spinpolarized(XC(func_type) *func, double point[7], double der[5],
-                                    int which)
-{
-  first_derivative(func, point, der, which, XC_POLARIZED);
-}
-
-void second_derivatives_spinpaired(XC(func_type) *func, double point[7], double der[5][5])
-{
-  int i;
-
-  for(i=0; i<5; i++){
-    first_derivative_spinpaired(func, point, der[i], i+1);
-  }
-}
-
-void second_derivatives_spinpolarized(XC(func_type) *func, double point[7], double der[5][5])
-{
-  int i;
-
-  for(i=0; i<5; i++){
-    first_derivative_spinpolarized(func, point, der[i], i+1);
-  }
-}
-
-/* a general call for a functional - finite difference */
-void get_fxc_fd_spinpaired(XC(func_type) *func, double point[7], double der[5][5])
-{
-  second_derivatives_spinpaired(func, point, der);
-}
-
-/* a general call for a functional - finite difference */
-void get_fxc_fd_spinpolarized(XC(func_type) *func, double point[7], double der[5][5])
-{
-  second_derivatives_spinpolarized(func, point, der);
-}
 
 static void lxcXCFunctional_dealloc(lxcXCFunctionalObject *self)
 {
@@ -216,123 +52,34 @@ lxcXCFunctional_is_mgga(lxcXCFunctionalObject *self, PyObject *args)
 }
 
 static PyObject*
-lxcXCFunctional_CalculateFXC_FD_SpinPaired(lxcXCFunctionalObject *self, PyObject *args)
+lxcXCFunctional_set_omega(lxcXCFunctionalObject *self, PyObject *args)
 {
-  PyArrayObject* n_array;              /* rho */
-  PyArrayObject* v2rho2_array;         /* d2E/drho2 */
-  PyArrayObject* a2_array = 0;         /* |nabla rho|^2*/
-  PyArrayObject* v2rhosigma_array = 0; /* d2E/drhod|nabla rho|^2 */
-  PyArrayObject* v2sigma2_array = 0;   /* d2E/drhod|nabla rho|^2 */
-  if (!PyArg_ParseTuple(args, "OO|OOO", &n_array, &v2rho2_array, /* object | optional objects*/
-                        &a2_array, &v2rhosigma_array, &v2sigma2_array))
+  int success = 0; /* Assume we don't use sfat */
+  int i = 0;
+  float omega = 0.0;
+  XC(func_type) *test_functional;
+
+  if (!PyArg_ParseTuple(args, "f", &omega)) {
+    PyErr_SetString(PyExc_TypeError,
+                    "Gamma has to be float");
     return NULL;
+  }
 
-  /* find nspin */
-  int nspin = self->nspin;
-
-  assert(nspin == XC_UNPOLARIZED); /* we are spinpaired */
-  assert (self->functional[0]->info->family != XC_FAMILY_MGGA);
-
-  int ng = PyArray_DIMS(n_array)[0]; /* number of grid points */
-
-  const double* n_g = DOUBLEP(n_array); /* density on the grid */
-  double* v2rho2_g = DOUBLEP(v2rho2_array); /* v on the grid */
-
-  const double* a2_g = 0; /* a2 on the grid */
-  double* v2rhosigma_g = 0;    /* d2Ednda2 on the grid */
-  double* v2sigma2_g = 0;    /* d2Eda2da2 on the grid */
-
-  if ((self->functional[0]->info->family == XC_FAMILY_GGA) ||
-      (self->functional[0]->info->family == XC_FAMILY_HYB_GGA))
-    {
-      a2_g = DOUBLEP(a2_array);
-      v2rhosigma_g = DOUBLEP(v2rhosigma_array);
-      v2sigma2_g = DOUBLEP(v2sigma2_array);
-    }
-
-  self->get_fxc = get_fxc_fd_spinpaired;
-  /* ################################################################ */
-  for (int g = 0; g < ng; g++)
-    {
-      double n = n_g[g];
-      if (n < NMIN)
-        n = NMIN;
-      double a2 = 0.0; /* initialize for lda */
-      if ((self->functional[0]->info->family == XC_FAMILY_GGA) ||
-          (self->functional[0]->info->family == XC_FAMILY_HYB_GGA))
-        {
-          a2 = a2_g[g];
-        }
-
-      double point[7]; /* generalized point */
-      // from http://www.tddft.org/programs/octopus/wiki/index.php/Libxc:manual
-      // rhoa rhob sigmaaa sigmaab sigmabb taua taub
-      // \sigma[0] = \nabla n_\uparrow \cdot \nabla n_\uparrow \qquad
-      // \sigma[1] = \nabla n_\uparrow \cdot \nabla n_\downarrow \qquad
-      // \sigma[2] = \nabla n_\downarrow \cdot \nabla n_\downarrow \qquad
-
-      double derivative[5][5]; /* generalized derivative */
-      double v2rho2[3];
-      double v2rhosigma[6];
-      double v2sigma2[6];
-      // one that uses this: please add description of spin derivative order notation
-      // (see c/libxc/src/gga_perdew.c) MDTMP
-
-      for(int i=0; i<3; i++) v2rho2[i] = 0.0;
-      for(int i=0; i<6; i++){
-        v2rhosigma[i] = 0.0;
-        v2sigma2[i]    = 0.0;
+  if (self->functional[0]->info->family == XC_FAMILY_HYB_GGA) {
+    for (i=0; i<self->functional[0]->n_func_aux; i++) {
+      test_functional = self->functional[0]->func_aux[i];
+      if (test_functional->info->number == XC_GGA_X_SFAT) {
+        XC(gga_x_sfat_set_params)(test_functional, -1, omega);
+        success = 1;
       }
-
-      for(int j=0; j<7; j++)
-        {
-          point[j] = 0.0;
-        }
-
-      for(int i=0; i<5; i++)
-        {
-          for(int j=0; j<5; j++)
-            {
-              derivative[i][j] = 0.0;
-            }
-        }
-
-      point[0] = n;   /* -> rho */
-      point[2] = a2;  /* -> sigma */
-
-      for (int i=0; i<2; i++) {
-        XC(func_type) *func = self->functional[i];
-        if (func == NULL) continue;
-        self->get_fxc(func, point, derivative);
-        v2rho2[0] = derivative[0][0];
-        v2rho2[1] = derivative[0][1]; // XC_POLARIZED
-        v2rho2[2] = derivative[1][1]; // XC_POLARIZED
-        v2rhosigma[0] = derivative[0][2];
-        v2rhosigma[1] = derivative[0][3]; // XC_POLARIZED
-        v2rhosigma[2] = derivative[0][4]; // XC_POLARIZED
-        v2rhosigma[3] = derivative[1][2]; // XC_POLARIZED
-        v2rhosigma[4] = derivative[1][3]; // XC_POLARIZED
-        v2rhosigma[5] = derivative[1][4]; // XC_POLARIZED
-        v2sigma2[0] = derivative[2][2]; /* aa_aa */
-        v2sigma2[1] = derivative[2][3]; // XC_POLARIZED /* aa_ab */
-        v2sigma2[2] = derivative[2][4]; // XC_POLARIZED /* aa_bb */
-        v2sigma2[3] = derivative[3][3]; // XC_POLARIZED /* ab_ab */
-        v2sigma2[4] = derivative[3][4]; // XC_POLARIZED /* ab_bb */
-        v2sigma2[5] = derivative[4][4]; // XC_POLARIZED /* bb_bb */
-        switch(func->info->family)
-          {
-          case XC_FAMILY_HYB_GGA:
-          case XC_FAMILY_GGA:
-            v2rhosigma_g[g] += v2rhosigma[0];
-            v2sigma2_g[g] += v2sigma2[0];
-            // don't break here since we need LDA values as well
-          case XC_FAMILY_LDA:
-            v2rho2_g[g] += v2rho2[0];
-          }
-      }
-
     }
-  Py_RETURN_NONE;
+  }
+  if (!(success)) {
+    PyErr_SetString(PyExc_TypeError,
+                    "Gamma can only set for range separated functionals");
+    return NULL;
+  }
+  return Py_BuildValue("i", success);
 }
 
 // Below are changes made by cpo@slac.stanford.edu for libxc 1.2.0
@@ -823,8 +570,8 @@ static PyMethodDef lxcXCFunctional_Methods[] = {
    (PyCFunction)lxcXCFunctional_is_gga, METH_VARARGS, 0},
   {"is_mgga",
    (PyCFunction)lxcXCFunctional_is_mgga, METH_VARARGS, 0},
-  {"calculate_fxc_fd_spinpaired",
-   (PyCFunction)lxcXCFunctional_CalculateFXC_FD_SpinPaired, METH_VARARGS, 0},
+  {"set_omega",
+   (PyCFunction)lxcXCFunctional_set_omega, METH_VARARGS, 0},
   {"calculate",
    (PyCFunction)lxcXCFunctional_Calculate, METH_VARARGS, 0},
   {"calculate_fxc_spinpaired",
