@@ -26,6 +26,7 @@ intersphinx_mapping = {
     'python': ('https://docs.python.org/3.7', None),
     'ase': ('https://wiki.fysik.dtu.dk/ase', None),
     'numpy': ('https://docs.scipy.org/doc/numpy', None),
+    'scipy': ('https://docs.scipy.org/doc/scipy/reference', None),
     'mayavi': ('http://docs.enthought.com/mayavi/mayavi', None)}
 
 html_theme = 'sphinx_rtd_theme'
@@ -44,3 +45,9 @@ html_context = {
           'https://wiki.fysik.dtu.dk/gpaw/dev'),
          ('{} (latest stable)'.format(stable_version),
           'https://wiki.fysik.dtu.dk/gpaw')]}
+mathjax_config = {
+    'TeX': {
+        'Macros': {
+            'br': '{\\mathbf r}',
+            'bk': '{\\mathbf k}',
+            'bG': '{\\mathbf G}'}}}
