@@ -10,8 +10,8 @@ def create_tasks():
         task('spectrum.py@1:2m', deps='tdc.py'),
         task('td_fdm_replay.py@1:5m', deps='tdc.py'),
         task('ksd_init.py@1:5m', deps='gs.py'),
-        task('fdm_ind.py@1:2m', deps='td_fdm_replay.py'),
+        task('fdm_ind.py@1:2m', deps='td_fdm_replay.py,ksd_init.py'),
         task('spec_plot.py@1:2m', deps='spectrum.py'),
         task('tcm_plot.py@1:2m',
-            deps='ksd_init.py,td_fdm_replay.py,spectrum.py'),
+             deps='ksd_init.py,td_fdm_replay.py,spectrum.py'),
         task('ind_plot.py@1:2m', deps='fdm_ind.py')]
