@@ -1,6 +1,7 @@
+import os
+
 scalapack = True
 fftw = True
-platform_id = os.environ['CPU_ARCH'] + '-el7'
 
 # Clean out any autodetected things, we only want the EasyBuild
 # definitions to be used.
@@ -9,9 +10,7 @@ mpi_libraries = []
 include_dirs = []
 
 # Use EasyBuild scalapack from the active toolchain
-mpi_libraries += ['scalapack']
-mpi_define_macros += [('GPAW_NO_UNDERSCORE_CBLACS', '1')]
-mpi_define_macros += [('GPAW_NO_UNDERSCORE_CSCALAPACK', '1')]
+libraries += ['scalapack']
 
 # Use EasyBuild libxc
 libxc = os.getenv('EBROOTLIBXC')
@@ -29,7 +28,3 @@ if libvdwxc:
 
 # Now add a EasyBuild "cover-all-bases" library_dirs
 library_dirs = os.getenv('LD_LIBRARY_PATH').split(':')
-
-# Build separate gpaw-python
-mpicompiler = 'mpicc'
-mpilinker = mpicompiler
