@@ -9,20 +9,11 @@ if [ -z $ASE ]; then
     ASE=~/ase
 fi
 
-module load GPAW
+module load GPAW/1.4.0-foss-2018b-Python-3.6.6
 module unload ASE
-module load matplotlib
-PLATFORM=linux-x86_64-$CPU_ARCH-el7-3.6
-if [ $CPU_ARCH = broadwell ]; then
-    export GPAW_MPI_OPTIONS="-mca pml cm -mca mtl psm2"
-elif [ $CPU_ARCH = sandybridge ]; then
-    export GPAW_MPI_OPTIONS=""
-elif [ $CPU_ARCH = ivybridge ]; then
-    export GPAW_MPI_OPTIONS=""
-elif [ $CPU_ARCH = nehalem ]; then
-    export GPAW_MPI_OPTIONS=""
-fi
 
+export GPAW_MPI_OPTIONS=""
+PLATFORM=linux-x86_64-$CPU_ARCH-el7-3.6
 export PATH=$GPAW/tools:$GPAW/build/bin.$PLATFORM:$PATH
 export PYTHONPATH=$GPAW:$GPAW/build/lib.$PLATFORM:$PYTHONPATH
 export PATH=$ASE/bin:$PATH
