@@ -1,4 +1,4 @@
-# creates: energies.png
+# Creates: energies.png
 import numpy as np
 import matplotlib.pyplot as plt
 
@@ -18,7 +18,7 @@ plt.axhline(line[1], linestyle="dashed", color='C1')
 
 plt.xlabel('Supercell size', fontsize=18)
 plt.ylabel('Energy difference (eV)', fontsize=18)
-plt.xlim(xmin=0.06)
+plt.xlim(left=0.06)
 plt.xticks(1 / repeat, [str(x) for x in repeat])
 plt.legend(loc='lower left')
 plt.savefig('energies.png', bbox_inches='tight', dpi=300)
