@@ -22,10 +22,10 @@ extrap_gap, slope = np.linalg.solve([[1, 1. / 300.**(3. / 2)],
                                      [1, 1. / 400.**(3. / 2)]],
                                     [direct_gap[2], direct_gap[3]])
 xs = np.linspace(0, 1 / 400.**(3. / 2), 1000)
-plt.plot(xs, extrap_gap + slope*xs, 'k--')
+plt.plot(xs, extrap_gap + slope * xs, 'k--')
 
 plt.xticks([1. / 100**(3. / 2), 1. / 200**(3. / 2), 1. / 400**(3. / 2), 0],
-           [100, 200, 400, '$\infty$'])
+           [100, 200, 400, r'$\infty$'])
 plt.xlabel('Cutoff energy (eV)')
 plt.ylabel('Direct band gap (eV)')
 plt.title('non-selfconsistent G0W0@LDA')
