@@ -10,13 +10,14 @@ import numpy as np
 from ase.units import Hartree
 from ase.utils import devnull
 
-from gpaw.version import version
+from gpaw import __version__ as version
 from gpaw.utilities import divrl
 from gpaw.atom.generator import Generator
 from gpaw.atom.all_electron import AllElectron
 from gpaw.atom.configurations import parameters
-from gpaw.basis_data import Basis, BasisFunction
-from gpaw.atom.radialgd import AERadialGridDescriptor
+from gpaw.basis_data import Basis, BasisFunction, get_basis_name
+from gpaw.atom.radialgd import (AERadialGridDescriptor,
+                                EquidistantRadialGridDescriptor)
 
 
 def get_basis_l(f_j, l_j, Nv):
@@ -102,7 +103,9 @@ def rsplit_by_norm(rgd, l, u, tailnorm_squared, txt):
 class BasisMaker:
     """Class for creating atomic basis functions."""
     def __init__(self, generator, name=None, run=True, gtxt='-',
-                 non_relativistic_guess=False, xc='PBE'):
+                 non_relativistic_guess=False, xc='PBE',
+                 save_setup=False):
+
         if isinstance(generator, str):  # treat 'generator' as symbol
             generator = Generator(generator, scalarrel=True,
                                   xcname=xc, txt=gtxt,
@@ -113,6 +116,7 @@ class BasisMaker:
                                           1.0 / generator.N, generator.N,
                                           default_spline_points=100)
         self.name = name
+
         if run:
             if non_relativistic_guess:
                 ae0 = AllElectron(generator.symbol, scalarrel=False,
@@ -122,14 +126,23 @@ class BasisMaker:
                 ae0.run()
                 # Now files will be stored such that they can
                 # automagically be used by the next run()
-            generator.run(write_xml=False, use_restart_file=False,
-                          **parameters[generator.symbol])
+            setup = generator.run(write_xml=False, use_restart_file=False,
+                                  name=name,
+                                  **parameters[generator.symbol])
+
+            if save_setup:
+                setup.write_xml()
+        else:
+            if save_setup:
+                raise ValueError('cannot save setup here because setup '
+                                 'was already generated before basis '
+                                 'generation.')
 
     def smoothify(self, psi_mg, l):
-        """Generate pseudo wave functions from all-electron ones.
+        r"""Generate pseudo wave functions from all-electron ones.
 
         The pseudo wave function is::
-        
+
                                    ___
                ~                   \    /   ~             \    ~     ~
             | psi  > = | psi  > +   )  | | phi > - | phi > ) < p  | psi > ,
@@ -137,7 +150,7 @@ class BasisMaker:
                                     i
 
         where the scalar products are found by solving::
-        
+
                             ___
               ~             \     ~             ~     ~
             < p | psi  > =   )  < p  | phi  > < p  | psi  > .
@@ -174,7 +187,7 @@ class BasisMaker:
         w_g = np.ones(g.r.shape)
         w_g[0:gmerge] = (g.r[0:gmerge] / g.r[gmerge])**2.
         w_g = w_g[None]
-        
+
         psit_mg = psi_mg * w_g + np.dot(Qt_nm.T, s_ng - u_ng * w_g)
         return psit_mg
 
@@ -209,11 +222,11 @@ class BasisMaker:
         rmax = g.r[-1]
 
         de = e - e_base
-        #print '--------'
-        #print 'Start bisection'
-        #print'e_base =',e_base
-        #print 'e =',e
-        #print '--------'
+        # print '--------'
+        # print 'Start bisection'
+        # print'e_base =',e_base
+        # print 'e =',e
+        # print '--------'
         while de < de_min or de > de_max:
             if de < de_min:  # Move rc left -> smaller cutoff, higher energy
                 rmax = rc
@@ -225,12 +238,12 @@ class BasisMaker:
                 vconf = g.get_confinement_potential(amplitude, ri_rel * rc, rc)
             psi_g, e = g.solve_confined(j, rc, vconf)
             de = e - e_base
-            #print 'rc = %.03f :: e = %.03f :: de = %.03f' % (rc, e*Hartree,
-            #                                                 de*Hartree)
-            #if rmin - rmax < 1e-
+            # print 'rc = %.03f :: e = %.03f :: de = %.03f' % (rc, e*Hartree,
+            #                                                  de*Hartree)
+            # if rmin - rmax < 1e-
             if g.r2g(rmax) - g.r2g(rmin) <= 1:  # adjacent points
                 break  # cannot meet tolerance due to grid resolution
-        #print 'Done!'
+        # print 'Done!'
         return psi_g, e, de, vconf, rc
 
     def generate(self, zetacount=2, polarizationcount=1,
@@ -240,7 +253,7 @@ class BasisMaker:
                  rcharpol_rel=None,
                  vconf_args=(12.0, 0.6), txt='-',
                  include_energy_derivatives=False,
-                 #lvalues=None, # XXX clean up some of these!
+                 # lvalues=None, # XXX clean up some of these!
                  jvalues=None,
                  l_pol=None):
         """Generate an entire basis set.
@@ -280,16 +293,16 @@ class BasisMaker:
                 (max(polarizationcount, zetacount) - 1, len(tailnorm)))
 
         textbuffer = StringIO()
-        
+
         class TeeStream:  # quick hack to both write and save output
             def __init__(self, out1, out2):
                 self.out1 = out1
                 self.out2 = out2
-                
+
             def write(self, string):
                 self.out1.write(string)
                 self.out2.write(string)
-                
+
         txt = TeeStream(txt, textbuffer)
 
         if vconf_args is not None:
@@ -311,7 +324,7 @@ class BasisMaker:
                     continue
                 jvalues.append(j)
                 sortkeys.append(l_j[j])
-            
+
             # Now order jvalues by l
             #
             # Use a stable sort so the energy ordering within each
@@ -320,14 +333,14 @@ class BasisMaker:
             jvalues = np.array(jvalues)[args]
 
         fulljvalues = [njcore + j for j in jvalues]
-        
+
         if isinstance(energysplit, float):
             energysplit = [energysplit] * len(jvalues)
-        
+
         title = '%s Basis functions for %s' % (g.xcname, g.symbol)
         print(title, file=txt)
         print('=' * len(title), file=txt)
-        
+
         singlezetas = []
         energy_derivative_functions = []
         multizetas = [[] for i in range(zetacount - 1)]
@@ -349,7 +362,8 @@ class BasisMaker:
                 adverb = 'sharply'
             else:
                 adverb = 'softly'
-            print('Zeta 1: %s confined pseudo wave,' % adverb, end=' ', file=txt)
+            print('Zeta 1: %s confined pseudo wave,' % adverb, end=' ',
+                  file=txt)
 
             u, e, de, vconf, rc = self.rcut_by_energy(fullj, esplit,
                                                       tolerance,
@@ -364,13 +378,14 @@ class BasisMaker:
                 print('rc=%.02f Bohr' % rc, file=txt)
             else:
                 print('fixed energy shift', file=txt)
-                print('DE=%.03f eV :: rc=%.02f Bohr' % (de * Hartree,
-                                                                rc), file=txt)
+                print('DE=%.03f eV :: rc=%.02f Bohr'
+                      % (de * Hartree, rc), file=txt)
+
             if vconf is not None:
-                print(('Potential amp=%.02f :: ri/rc=%.02f' %
-                               (amplitude, ri_rel)), file=txt)
+                print('Potential amp=%.02f :: ri/rc=%.02f' %
+                      (amplitude, ri_rel), file=txt)
             phit_g = self.smoothify(u, l)
-            bf = BasisFunction(l, rc, phit_g,
+            bf = BasisFunction(n, l, rc, phit_g,
                                '%s-sz confined orbital' % orbitaltype)
             norm = np.dot(g.dr, phit_g * phit_g)**.5
             print('Norm=%.03f' % norm, file=txt)
@@ -385,13 +400,13 @@ class BasisMaker:
                 vconf2 = g.get_confinement_potential(amplitude,
                                                      ri_rel * rc * .99, rc)
                 u2, e2 = g.solve_confined(fullj, rc, vconf2)
-                
+
                 phit2_g = self.smoothify(u2, l)
                 dphit_g = phit2_g - phit_g
                 dphit_norm = np.dot(rgd.dr_g, dphit_g * dphit_g) ** .5
                 dphit_g /= dphit_norm
                 descr = '%s-dz E-derivative of sz' % orbitaltype
-                bf = BasisFunction(l, rc, dphit_g, descr)
+                bf = BasisFunction(None, l, rc, dphit_g, descr)
                 energy_derivative_functions.append(bf)
 
             for i, zeta in enumerate(zetacounter):
@@ -405,9 +420,9 @@ class BasisMaker:
                                                          txt)
                 descr = '%s-%sz split-valence wave' % (orbitaltype,
                                                        '0sdtq56789'[zeta])
-                bf = BasisFunction(l, rsplit, phit_g - splitwave, descr)
+                bf = BasisFunction(None, l, rsplit, phit_g - splitwave, descr)
                 multizetas[i].append(bf)
-            
+
         if polarizationcount > 0 or l_pol is not None:
             if l_pol is None:
                 # Now make up some properties for the polarization orbital
@@ -419,7 +434,7 @@ class BasisMaker:
                         l_pol = i
                         break
                 else:
-                        l_pol = max(lvalues) + 1
+                    l_pol = max(lvalues) + 1
 
             # Find the last state with l=l_pol - 1, which will be the state we
             # base the polarization function on
@@ -469,8 +484,8 @@ class BasisMaker:
             adjective = 'Gaussian'
             print(msg, file=txt)
             type = '%s-type %s polarization' % ('spdfg'[l_pol], adjective)
-            bf_pol = BasisFunction(l_pol, rcut, psi_pol, type)
-                                   
+            bf_pol = BasisFunction(None, l_pol, rcut, psi_pol, type)
+
             polarization_functions.append(bf_pol)
             for i in range(polarizationcount - 1):
                 npol = i + 2
@@ -483,17 +498,18 @@ class BasisMaker:
                                                          txt)
                 descr = ('%s-type split-valence polarization %d'
                          % ('spdfg'[l_pol], npol))
-                bf_pol = BasisFunction(l_pol, rsplit, psi_pol - splitwave,
+                bf_pol = BasisFunction(None, l_pol, rsplit,
+                                       psi_pol - splitwave,
                                        descr)
                 polarization_functions.append(bf_pol)
-        
+
         bf_j = []
         bf_j.extend(singlezetas)
         bf_j.extend(energy_derivative_functions)
         for multizeta_list in multizetas:
             bf_j.extend(multizeta_list)
         bf_j.extend(polarization_functions)
-        
+
         rcmax = max([bf.rc for bf in bf_j])
 
         # The non-equidistant grids are really only suited for AE WFs
@@ -504,18 +520,18 @@ class BasisMaker:
         for bf in bf_j:
             # We have been storing phit_g * r, but we just want phit_g
             bf.phit_g = divrl(bf.phit_g, 1, rgd.r_g)
-            
+
             gcut = min(int(1 + bf.rc / d), ng - 1)
-            
+
             assert equidistant_grid[gcut] >= bf.rc
             assert equidistant_grid[gcut - 1] <= bf.rc
-            
+
             bf.rc = equidistant_grid[gcut]
             # Note: bf.rc *must* correspond to a grid point (spline issues)
             bf.ng = gcut + 1
             # XXX all this should be done while building the basis vectors,
             # not here
-            
+
             # Quick hack to change to equidistant coordinates
             spline = rgd.spline(bf.phit_g, rgd.r_g[rgd.floor(bf.rc)], bf.l,
                                 points=100)
@@ -523,9 +539,14 @@ class BasisMaker:
                                   for r in equidistant_grid[:bf.ng]])
             bf.phit_g[-1] = 0.
 
-        basis = Basis(g.symbol, self.name, False)
-        basis.ng = ng
-        basis.d = d
+        basistype = get_basis_name(zetacount, polarizationcount)
+        if self.name is None:
+            compound_name = basistype
+        else:
+            compound_name = '%s.%s' % (self.name, basistype)
+
+        basis = Basis(g.symbol, compound_name, False,
+                      EquidistantRadialGridDescriptor(d, ng))
         basis.bf_j = bf_j
         basis.generatordata = textbuffer.getvalue().strip()
         basis.generatorattrs = {'version': version}
@@ -596,7 +617,7 @@ class QuasiGaussian:
         self.a = a
         self.b = b
         self.A = A
-        
+
     def __call__(self, r):
         """Evaluate function values at r, which is a numpy array."""
         condition = (r < self.rcut) & (self.alpha * r**2 < 700.)
