@@ -88,7 +88,7 @@ class RadialGridDescriptor:
                       (self.r_g**(2 + n) * self.dr_g)[1:]) * (4 * pi)
 
     def yukawa(self, n_g, l=0, gamma=1e-6):
-        """Calculates the radial grid yukawa integral.
+        r"""Calculates the radial grid yukawa integral.
 
         The the integral kernel for the Yukawa interaction:
 
