@@ -6,19 +6,9 @@
 
 from math import pi
 
-import numpy as np
-from numpy.fft import fftn, ifftn, fft2, ifft2
+from numpy.fft import fftn, ifftn
 
-from ase.parallel import parprint
-from gpaw.transformers import Transformer
-from gpaw.fd_operators import Laplace, LaplaceA, LaplaceB
-from gpaw import PoissonConvergenceError
-from gpaw.utilities.blas import axpy
-from gpaw.utilities.gauss import Gaussian
-from gpaw.utilities.ewald import madelung
 from gpaw.utilities.tools import construct_reciprocal
-import _gpaw
-
 from gpaw import poisson
 
 class PoissonSolver(poisson.FDPoissonSolver):
