@@ -12,11 +12,11 @@ import numbers
 from math import pi
 
 import numpy as np
+from scipy.ndimage import map_coordinates
 
 import _gpaw
 import gpaw.mpi as mpi
 from gpaw.domain import Domain
-from gpaw.utilities import mlsqr
 from gpaw.utilities.blas import rk, r2k, gemm
 
 
@@ -36,7 +36,7 @@ class BadGridError(ValueError):
 
 
 class GridDescriptor(Domain):
-    """Descriptor-class for uniform 3D grid
+    r"""Descriptor-class for uniform 3D grid
 
     A ``GridDescriptor`` object holds information on how functions, such
     as wave functions and electron densities, are discreticed in a
@@ -73,7 +73,7 @@ class GridDescriptor(Domain):
     ndim = 3  # dimension of ndarrays
 
     def __init__(self, N_c, cell_cv=[1, 1, 1], pbc_c=True,
-                 comm=None, parsize_c=None):
+                 comm=None, parsize_c=None, allow_empty_domains=False):
         """Construct grid-descriptor object.
 
         parameters:
@@ -88,6 +88,8 @@ class GridDescriptor(Domain):
             Communicator for domain-decomposition.
         parsize_c: tuple of 3 ints, a single int or None
             Number of domains.
+        allow_empty_domains: bool
+            Allow parallelization that would generate empty domains.
 
         Note that if pbc_c[c] is False, then the actual number of gridpoints
         along axis c is one less than N_c[c].
@@ -131,11 +133,16 @@ class GridDescriptor(Domain):
             if not self.pbc_c[c]:
                 n_p[0] = 1
 
-            if not np.all(n_p[1:] - n_p[:-1] > 0):
-                raise BadGridError('Grid {0} too small for {1} cores!'
-                                   .format('x'.join(str(n) for n in self.N_c),
-                                           'x'.join(str(n) for n
-                                                    in self.parsize_c)))
+            if np.any(n_p[1:] == n_p[:-1]):
+                if allow_empty_domains:
+                    # If there are empty domains, sort them to the end
+                    n_p[:] = (np.arange(self.parsize_c[c] + 1) +
+                              1 - self.pbc_c[c]).clip(0, self.N_c[c])
+                else:
+                    msg = ('Grid {0} too small for {1} cores!'
+                           .format('x'.join(str(n) for n in self.N_c),
+                                   'x'.join(str(n) for n in self.parsize_c)))
+                    raise BadGridError(msg)
 
             self.beg_c[c] = n_p[self.parpos_c[c]]
             self.end_c[c] = n_p[self.parpos_c[c] + 1]
@@ -164,7 +171,7 @@ class GridDescriptor(Domain):
                    self.comm.size, pcoords, self.parsize_c.tolist()))
 
     def new_descriptor(self, N_c=None, cell_cv=None, pbc_c=None,
-                       comm=None, parsize_c=None):
+                       comm=None, parsize_c=None, allow_empty_domains=False):
         """Create new descriptor based on this one.
 
         The new descriptor will use the same class (possibly a subclass)
@@ -180,7 +187,8 @@ class GridDescriptor(Domain):
             comm = self.comm
         if parsize_c is None and comm.size == self.comm.size:
             parsize_c = self.parsize_c
-        return self.__class__(N_c, cell_cv, pbc_c, comm, parsize_c)
+        return self.__class__(N_c, cell_cv, pbc_c, comm, parsize_c,
+                              allow_empty_domains)
 
     def coords(self, c, pad=True):
         """Return coordinates along one of the three axes.
@@ -450,9 +458,11 @@ class GridDescriptor(Domain):
             B_g = np.zeros_like(A_g)
             for s, op_cc in enumerate(op_scc):
                 if ft_sc is None:
-                    _gpaw.symmetrize(A_g, B_g, op_cc)
+                    _gpaw.symmetrize(A_g, B_g, op_cc, 1 - self.pbc_c)
                 else:
-                    _gpaw.symmetrize_ft(A_g, B_g, op_cc, ft_sc[s])
+                    t_c = (ft_sc[s] * self.N_c).round().astype(int)
+                    _gpaw.symmetrize_ft(A_g, B_g, op_cc, t_c,
+                                        1 - self.pbc_c)
         else:
             B_g = None
         self.distribute(B_g, a_g)
@@ -671,52 +681,22 @@ class GridDescriptor(Domain):
 
         return np.dot(s_Gc, cell_cv).T.copy()
 
-    def interpolate_grid_points(self, spos_nc, vt_g, target_n, use_mlsqr=True):
+    def interpolate_grid_points(self, spos_nc, vt_g):
         """Return interpolated values.
 
         Calculate interpolated values from array vt_g based on the
         scaled coordinates on spos_c.
 
-        Uses moving least squares algorithm by default, or otherwise
-        trilinear interpolation.
-
         This doesn't work in parallel, since it would require
-        communication between neighbouring grid.  """
+        communication between neighbouring grids."""
 
         assert self.comm.size == 1
 
-        if use_mlsqr:
-            mlsqr(3, 2.3, spos_nc, self.N_c, self.beg_c, vt_g, target_n)
-        else:
-            for n, spos_c in enumerate(spos_nc):
-                g_c = self.N_c * spos_c - self.beg_c
-
-                # The begin and end of the array slice
-                bg_c = np.floor(g_c).astype(int)
-                Bg_c = np.ceil(g_c).astype(int)
-
-                # The coordinate within the box (bottom left = 0,
-                # top right = h_c)
-                dg_c = g_c - bg_c
-                Bg_c %= self.N_c
-
-                target_n[n] = (
-                    vt_g[bg_c[0], bg_c[1], bg_c[2]] *
-                    (1.0 - dg_c[0]) * (1.0 - dg_c[1]) * (1.0 - dg_c[2]) +
-                    vt_g[Bg_c[0], bg_c[1], bg_c[2]] *
-                    (0.0 + dg_c[0]) * (1.0 - dg_c[1]) * (1.0 - dg_c[2]) +
-                    vt_g[bg_c[0], Bg_c[1], bg_c[2]] *
-                    (1.0 - dg_c[0]) * (0.0 + dg_c[1]) * (1.0 - dg_c[2]) +
-                    vt_g[Bg_c[0], Bg_c[1], bg_c[2]] *
-                    (0.0 + dg_c[0]) * (0.0 + dg_c[1]) * (1.0 - dg_c[2]) +
-                    vt_g[bg_c[0], bg_c[1], Bg_c[2]] *
-                    (1.0 - dg_c[0]) * (1.0 - dg_c[1]) * (0.0 + dg_c[2]) +
-                    vt_g[Bg_c[0], bg_c[1], Bg_c[2]] *
-                    (0.0 + dg_c[0]) * (1.0 - dg_c[1]) * (0.0 + dg_c[2]) +
-                    vt_g[bg_c[0], Bg_c[1], Bg_c[2]] *
-                    (1.0 - dg_c[0]) * (0.0 + dg_c[1]) * (0.0 + dg_c[2]) +
-                    vt_g[Bg_c[0], Bg_c[1], Bg_c[2]] *
-                    (0.0 + dg_c[0]) * (0.0 + dg_c[1]) * (0.0 + dg_c[2]))
+        vt_g = self.zero_pad(vt_g)
+        return map_coordinates(vt_g,
+                               (spos_nc * self.N_c).T,
+                               order=3,
+                               mode='wrap')
 
     def __eq__(self, other):
         # XXX Wait, should this not check the global distribution?  This
