@@ -1,12 +1,12 @@
 import pickle
 import numpy as np
 from os.path import isfile
-from ase.parallel import rank, barrier
+from gpaw.mpi import world
 from gpaw.utilities import unpack2
 from gpaw.lcao.projected_wannier import dots
 from gpaw.utilities.tools import tri2full
-from gpaw.lfc import NewLocalizedFunctionsCollection as LFC
-from ase.units import Bohr, Hartree
+from gpaw.lfc import LocalizedFunctionsCollection as LFC
+from ase.units import Bohr, Ha
 from gpaw.utilities.timing import StepTimer, nulltimer
 
 """This module is used to calculate the electron-phonon coupling matrix,
@@ -14,7 +14,7 @@ from gpaw.utilities.timing import StepTimer, nulltimer
 
 
 class ElectronPhononCouplingMatrix:
-    """Class for calculating the electron-phonon coupling matrix, defined
+    r"""Class for calculating the electron-phonon coupling matrix, defined
     by the electron phonon interaction.
 
     ::
@@ -62,13 +62,12 @@ class ElectronPhononCouplingMatrix:
 
             self.calc.calculate(self.atoms)
             Vt_G = self.calc.get_effective_potential(pad=False)
-            Vt_G = self.calc.wfs.gd.collect(Vt_G, broadcast=True) / Hartree
+            Vt_G = self.calc.wfs.gd.collect(Vt_G, broadcast=True) / Ha
             dH_asp = self.calc.hamiltonian.dH_asp
             setups = self.calc.wfs.setups
             nspins = self.calc.wfs.nspins
             gd_comm = self.calc.wfs.gd.comm
 
-
             alldH_asp = {}
             for a, setup in enumerate(setups):
                 ni = setup.ni
@@ -82,28 +81,31 @@ class ElectronPhononCouplingMatrix:
             forces = self.atoms.get_forces()
             self.calc.write('eq.gpw')
 
-            barrier()
-            if rank == 0:
+            world.barrier()
+            if world.rank == 0:
                 vd = open(self.name + '.eq.pckl', 'wb')
-                fd = open('vib.eq.pckl','wb')
-                pickle.dump((Vt_G, alldH_asp), vd,2)
-                pickle.dump(forces,fd)
+                fd = open('vib.eq.pckl', 'wb')
+                pickle.dump((Vt_G, alldH_asp), vd, 2)
+                pickle.dump(forces, fd)
                 vd.close()
                 fd.close()
-            barrier()
+            world.barrier()
 
         p = self.atoms.positions.copy()
         for a in self.indices:
             for j in range(3):
-                for sign in [-1,1]:
-                    for ndis in range(1,self.nfree/2+1):
-                        name = '.%d%s%s.pckl' % (a, 'xyz'[j], ndis * ' +-'[sign])
+                for sign in [-1, 1]:
+                    for ndis in range(1, self.nfree / 2 + 1):
+                        name = '.%d%s%s.pckl' % (a, 'xyz'[j],
+                                                 ndis * ' +-'[sign])
                         if isfile(self.name + name):
                             continue
-                        self.atoms.positions[a, j] = p[a, j] + sign * ndis * self.delta
+                        self.atoms.positions[a, j] = (p[a, j] +
+                                                      sign * ndis * self.delta)
                         self.calc.calculate(self.atoms)
                         Vt_G = self.calc.get_effective_potential(pad=False)
-                        Vt_G =self.calc.wfs.gd.collect(Vt_G, broadcast=True) / Hartree
+                        Vt_G = self.calc.wfs.gd.collect(Vt_G,
+                                                        broadcast=True) / Ha
                         dH_asp = self.calc.hamiltonian.dH_asp
 
                         alldH_asp = {}
@@ -117,15 +119,15 @@ class ElectronPhononCouplingMatrix:
                             alldH_asp[a2] = tmpdH_sp
 
                         forces = self.atoms.get_forces()
-                        barrier()
-                        if rank == 0:
-                            vd = open(self.name + name , 'wb')
+                        world.barrier()
+                        if world.rank == 0:
+                            vd = open(self.name + name, 'wb')
                             fd = open('vib' + name, 'wb')
                             pickle.dump((Vt_G, alldH_asp), vd)
                             pickle.dump(forces, fd)
                             vd.close()
                             fd.close()
-                        barrier()
+                        world.barrier()
                         self.atoms.positions[a, j] = p[a, j]
         self.atoms.set_positions(p)
 
@@ -142,33 +144,36 @@ class ElectronPhononCouplingMatrix:
         x = 0
         for a in self.indices:
             for i in range(3):
-                name = '%s.%d%s' % (self.name,a,'xyz'[i])
+                name = '%s.%d%s' % (self.name, a, 'xyz'[i])
                 vtm_G, dHm_asp = pickle.load(open(name + '-.pckl', 'rb'))
                 vtp_G, dHp_asp = pickle.load(open(name + '+.pckl', 'rb'))
 
-
-                if self.nfree==4:
-                    vtmm_G, dHmm_asp = pickle.load(open(name+'--.pckl', 'rb'))
-                    vtpp_G, dHpp_asp = pickle.load(open(name+'++.pckl', 'rb'))
-                    dvtdx_G = (-vtpp_G+8.0*vtp_G
-                                -8.0*vtm_G+vtmm_G)/(12.0*self.delta/Bohr)
-                    dvt_Gx[:,:,:,x] = dvtdx_G
+                if self.nfree == 4:
+                    vtmm_G, dHmm_asp = pickle.load(
+                        open(name + '--.pckl', 'rb'))
+                    vtpp_G, dHpp_asp = pickle.load(
+                        open(name + '++.pckl', 'rb'))
+                    dvtdx_G = (-vtpp_G + 8.0 * vtp_G -
+                               8 * vtm_G + vtmm_G) / (12 * self.delta / Bohr)
+                    dvt_Gx[:, :, :, x] = dvtdx_G
                     for atom, ddH_spx in ddH_aspx.items():
-                        ddH_aspx[atom][:,:,x] =(-dHpp_asp[atom]
-                                                +8.0 * dHp_asp[atom]
-                                                -8.0 * dHm_asp[atom]
-                                                +dHmm_asp[atom]) / (12 * self.delta / Bohr)
-                else: # nfree = 2
+                        ddH_aspx[atom][:, :, x] = (
+                            -dHpp_asp[atom]
+                            + 8.0 * dHp_asp[atom]
+                            - 8.0 * dHm_asp[atom]
+                            + dHmm_asp[atom]) / (12 * self.delta / Bohr)
+                else:  # nfree = 2
                     dvtdx_G = (vtp_G - vtm_G) / (2 * self.delta / Bohr)
                     dvt_Gx[..., x] = dvtdx_G
                     for atom, ddH_spx in ddH_aspx.items():
-                        ddH_aspx[atom][:, :, x] = (dHp_asp[atom]
-                                    -dHm_asp[atom]) / (2 * self.delta / Bohr)
-                x+=1
+                        ddH_aspx[atom][:, :, x] = (
+                            dHp_asp[atom]
+                            - dHm_asp[atom]) / (2 * self.delta / Bohr)
+                x += 1
         return dvt_Gx, ddH_aspx
 
     def get_M(self, modes, log=None, q=0):
-        """Calculate el-ph coupling matrix for given modes(s).
+        r"""Calculate el-ph coupling matrix for given modes(s).
 
         XXX:
         kwarg "q=0" is an ugly hack for k-points.
@@ -212,12 +217,12 @@ class ElectronPhononCouplingMatrix:
             timer = StepTimer(name='EPCM', out=open(log, 'w'))
 
         modes1 = modes.copy()
-        #convert to atomic units
-        amu = 1.6605402e-27 # atomic unit mass [Kg]
+        # convert to atomic units
+        amu = 1.6605402e-27  # atomic unit mass [Kg]
         me = 9.1093897e-31  # electron mass    [Kg]
         modes = {}
         for k in modes1.keys():
-            modes[k / Hartree] = modes1[k] / np.sqrt(amu / me)
+            modes[k / Ha] = modes1[k] / np.sqrt(amu / me)
 
         dvt_Gx, ddH_aspx = self.get_gradient()
 
@@ -231,7 +236,7 @@ class ElectronPhononCouplingMatrix:
         nao = wfs.setups.nao
         bfs = wfs.basis_functions
         dtype = wfs.dtype
-        spin = 0 # XXX
+        spin = 0  # XXX
 
         M_lii = {}
         timer.write_now('Starting gradient of pseudo part')
@@ -303,18 +308,17 @@ class ElectronPhononCouplingMatrix:
         M_lii = {}
 
         for f in M_lii_1.keys():
-            M_lii[f * Hartree] =  M_lii_1[f] * Hartree / np.sqrt(2 * f)
+            M_lii[f * Ha] = M_lii_1[f] * Ha / np.sqrt(2 * f)
 
         return M_lii
 
 
-
 #####################################################
 # XXX grid and grid 2 sometimes gives random numbers,
 # XXX sometimes even nan!
 #####################################################
 
-def get_grid_dP_aMix(spos_ac, wfs, q, timer=nulltimer): # XXXXXX q
+def get_grid_dP_aMix(spos_ac, wfs, q, timer=nulltimer):  # XXXXXX q
     nao = wfs.setups.nao
     C_MM = np.identity(nao, dtype=wfs.dtype)
     # XXX In the future use the New Two-Center integrals
@@ -344,7 +348,7 @@ def get_grid_dP_aMix(spos_ac, wfs, q, timer=nulltimer): # XXXXXX q
     return dP_aMix
 
 
-def get_grid2_dP_aMix(spos_ac, wfs, q, *args, **kwargs): # XXXXXX q
+def get_grid2_dP_aMix(spos_ac, wfs, q, *args, **kwargs):  # XXXXXX q
     nao = wfs.setups.nao
     C_MM = np.identity(nao, dtype=wfs.dtype)
     bfs = wfs.basis_functions
@@ -381,5 +385,5 @@ def get_tci_dP_aMix(spos_ac, wfs, q, *args, **kwargs):
 
     dP_aMix = {}
     for a in dP_aqxMi:
-        dP_aMix[a] = dP_aqxMi[a].transpose(0, 2, 3, 1).copy()[q] # XXX q
+        dP_aMix[a] = dP_aqxMi[a].transpose(0, 2, 3, 1).copy()[q]  # XXX q
     return dP_aMix
