@@ -6,8 +6,7 @@ from math import sqrt
 import numpy as np
 
 import gpaw.mpi as mpi
-from gpaw.output import get_txt
-from ase.units import A, m, s, Bohr, _aut, C
+from ase.utils import convert_string_to_fd
 
 
 class ExcitationList(list):
@@ -23,8 +22,8 @@ class ExcitationList(list):
 
         self.calculator = calculator
         if not txt and calculator:
-            txt = calculator.txt
-        self.txt = get_txt(txt, mpi.rank)
+            txt = calculator.log.fd
+        self.txt = convert_string_to_fd(txt, mpi.world)
 
     def get_calculator(self):
         return self.calculator
@@ -62,7 +61,7 @@ class ExcitationList(list):
         return self.__mul__(1. / x)
 
     __div__ = __truediv__
-    
+
     def __rmul__(self, x):
         return self.__mul__(x)
 
@@ -94,14 +93,6 @@ class ExcitationList(list):
             string += '#  ' + ex.__str__() + '\n'
         return string
 
-    def get_alpha(self, omega):
-        """Return the polarization tensor"""
-
-        alpha_cc = np.zeros((3, 3))
-        for ex in self:
-            alpha_cc += ex.get_alpha(omega)
-        return alpha_cc
-
 
 class Excitation:
 
@@ -123,9 +114,8 @@ class Excitation:
         else:
             raise RuntimeError('Unknown form >' + form + '<')
 
-    def get_oscillator_strength(self, form='r'):
-        """Return the excitations dipole oscillator strength.
-
+    def get_dipole_tensor(self, form='r'):
+        """Return the "oscillator strength tensor"
 
         self.me is assumed to be::
 
@@ -136,7 +126,6 @@ class Excitation:
         final states::
 
           |I>, |J>
-
         """
 
         if form == 'r':
@@ -147,14 +136,13 @@ class Excitation:
             me = self.muv * np.sqrt(self.fij * self.energy)
         else:
             raise RuntimeError('Unknown form >' + form + '<')
+        
+        return 2 * np.outer(me, me.conj())
 
-        osz = [0.]
-        for c in range(3):
-            val = 2. * (me[c].real ** 2 + me[c].imag ** 2)
-            osz.append(val)
-            osz[0] += val / 3.
-
-        return osz
+    def get_oscillator_strength(self, form='r'):
+        """Return the excitations dipole oscillator strength."""
+        me2_c = self.get_dipole_tensor(form).diagonal().real
+        return np.array([np.sum(me2_c) / 3.] + me2_c.tolist())
 
     def get_rotatory_strength(self, form='r', units='cgs'):
         """Return rotatory strength"""
@@ -170,7 +158,7 @@ class Excitation:
             # pre = 471.43
             # From TurboMole
             pre = 64604.8164
-        elif uints == 'a.u.':
+        elif units == 'a.u.':
             pre = 1.
         else:
             raise RuntimeError('Unknown units >' + units + '<')
@@ -189,14 +177,3 @@ class Excitation:
     def set_energy(self, E):
         """Set the excitations energy relative to the ground state energy"""
         self.energy = E
-
-    def get_alpha(self, omega):
-        """Return the polarization tensor"""
-        me = self.me
-
-        alpha_cc = np.zeros((3, 3))
-        for c1 in range(3):
-            for c2 in range(c1, 3):
-                alpha_cc[c1, c2] = alpha_cc[c2, c1] = me[c1] * me[c2]
-
-        return 2 * self.energy / (self.energy ** 2 - omega ** 2) * alpha_cc
