@@ -20,9 +20,9 @@ class Kmatrix:
         self.values = None
         self.K_matrix_ready = False
         self.deriv_scale = deriv_scale
-        self.file_format = 0 # 0 = 'Casida', 1 = 'K-matrix'
+        self.file_format = 0  # 0 = 'Casida', 1 = 'K-matrix'
 
-        self.dVxct_gip_2 = None       # temporary for finite difference
+        self.dVxct_gip_2 = None  # temporary for finite difference
 
         # for pros!!!
         self.fH_pre = 1.0
@@ -38,26 +38,28 @@ class Kmatrix:
         data = None
         if self.lr_comms.parent_comm.rank == 0:
             data = ''
-            ready_files = glob.glob(self.basefilename+'.ready_rows.*')
+            ready_files = glob.glob(self.basefilename + '.ready_rows.*')
             for ready_file in ready_files:
                 if os.path.isfile(ready_file):
-                    data += open(ready_file,'r',1024*1024).read()
+                    data += open(ready_file, 'r', 1024 * 1024).read()
 
-        data = gpaw.mpi.broadcast_string(data, root=0, comm=self.lr_comms.parent_comm)
+        data = gpaw.mpi.broadcast_string(data,
+                                         root=0,
+                                         comm=self.lr_comms.parent_comm)
         for line in data.splitlines():
             line = line.split()
-            self.ready_indices.append([int(line[0]),int(line[1])])
+            self.ready_indices.append([int(line[0]), int(line[1])])
 
     def read_values(self):
         """ Read K-matrix (not the Casida form) ready for 2D ScaLapack array"""
         # nrow = len(self.ks_singles.kss_list)  # total rows
-        nlrow = 0 # local rows
-        nlcol = 0 # local cols
+        nlrow = 0  # local rows
+        nlcol = 0  # local cols
 
         # Create indexing
-        self.lr_comms.index_map = {}        # (i,p) to matrix index map
+        self.lr_comms.index_map = {}  # (i,p) to matrix index map
         for (ip, kss) in enumerate(self.ks_singles.kss_list):
-            self.lr_comms.index_map[(kss.occ_ind,kss.unocc_ind)] = ip
+            self.lr_comms.index_map[(kss.occ_ind, kss.unocc_ind)] = ip
             if self.lr_comms.get_local_eh_index(ip) is not None:
                 nlrow += 1
             if self.lr_comms.get_local_dd_index(ip) is not None:
@@ -66,18 +68,18 @@ class Kmatrix:
         # ready rows list for different procs (read by this proc)
         elem_lists = {}
         for proc in range(self.lr_comms.parent_comm.size):
-           elem_lists[proc] = []
+            elem_lists[proc] = []
 
         self.lr_comms.parent_comm.barrier()
 
         #self.timer.start('Read K-matrix')
         # Read ALL ready_rows files but on different processors
-        for (k, K_fn) in enumerate(glob.glob(self.basefilename + '.K_matrix.*')):
+        for (k,
+             K_fn) in enumerate(glob.glob(self.basefilename + '.K_matrix.*')):
             # read every "parent comm size"th file, starting from parent comm rank
             if k % self.lr_comms.parent_comm.size != self.lr_comms.parent_comm.rank:
                 continue
 
-
             # for each file
             for line in open(K_fn, 'r', 1024 * 1024).read().splitlines():
                 #self.timer.start('Read K-matrix: elem')
@@ -94,27 +96,29 @@ class Kmatrix:
                 #self.timer.stop('Read K-matrix: elem')
 
                 #self.timer.start('Read K-matrix: index')
-                ip = self.lr_comms.index_map.get( (i,p) )
-                jq = self.lr_comms.index_map.get( (j,q) )
+                ip = self.lr_comms.index_map.get((i, p))
+                jq = self.lr_comms.index_map.get((j, q))
                 #self.timer.stop('Read K-matrix: index')
                 if ip is None or jq is None:
                     continue
 
                 # where to send
                 #self.timer.start('Read K-matrix: line')
-                (proc, ehproc, ddproc, lip, ljq) = self.lr_comms.get_matrix_elem_proc_and_index(ip, jq)
-                elem_lists[proc].append( line + '\n')
+                (proc, ehproc, ddproc, lip,
+                 ljq) = self.lr_comms.get_matrix_elem_proc_and_index(ip, jq)
+                elem_lists[proc].append(line + '\n')
                 #self.timer.stop('Read K-matrix: line')
 
-                if ip == jq: continue
+                if ip == jq:
+                    continue
 
                 # where to send transposed
                 #self.timer.start('Read K-matrix: line')
-                (proc, ehproc, ddproc, lip, ljq) = self.lr_comms.get_matrix_elem_proc_and_index(jq, ip)
-                elem_lists[proc].append( line + '\n')
+                (proc, ehproc, ddproc, lip,
+                 ljq) = self.lr_comms.get_matrix_elem_proc_and_index(jq, ip)
+                elem_lists[proc].append(line + '\n')
                 #self.timer.stop('Read K-matrix: line')
 
-
         #if self.parent_comm.rank == 0:
         #    print '-------------- READING K-MATRIX done --------------------', resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
         #    print 'elem_list sizes:',
@@ -122,7 +126,6 @@ class Kmatrix:
         #        print len(elem_lists[proc]),
         #    print
 
-
         #self.timer.start('Read K-matrix: join')
         for proc in range(self.lr_comms.parent_comm.size):
             elem_lists[proc] = ''.join(elem_lists[proc])
@@ -140,20 +143,18 @@ class Kmatrix:
 
         # send and receive elem_list
         #self.timer.start('Communicate K-matrix')
-        alltoall_dict = gpaw.mpi.alltoallv_string(elem_lists, self.lr_comms.parent_comm)
+        alltoall_dict = gpaw.mpi.alltoallv_string(elem_lists,
+                                                  self.lr_comms.parent_comm)
         # ready for garbage collection
         del elem_lists
         local_elem_list = ''.join(alltoall_dict.values())
         # ready for garbage collection
         del alltoall_dict
 
-
-
         #if self.parent_comm.rank == 0:
         #    print '-------------- communicating K-MATRIX done --------------------', resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
         #    print 'local elem list size: ', len(local_elem_list)
 
-
         #local_elem_list = ''
         #for sending_proc in range(self.parent_comm.size):
         #    for receiving_proc in range(self.parent_comm.size):
@@ -170,7 +171,6 @@ class Kmatrix:
         #            local_elem_list += elist
         #
 
-
         #print self.parent_comm.rank, '- local_elem_list -', local_elem_list[0:120].replace('\n', ' | ')
         #sys.stdout.flush()
         #sys.exit(0)
@@ -180,8 +180,8 @@ class Kmatrix:
         #self.timer.start('Build matrix')
 
         # Matrix build
-        K_matrix = np.zeros((nlrow,nlcol))
-        K_matrix[:,:] = np.NAN # fill with NaNs to detect problems
+        K_matrix = np.zeros((nlrow, nlcol))
+        K_matrix[:, :] = np.NAN  # fill with NaNs to detect problems
         # Read ALL K_matrix files
         for line in local_elem_list.splitlines():
             line = line.split()
@@ -193,7 +193,7 @@ class Kmatrix:
             jq = self.lr_comms.index_map.get(jqkey)
 
             # if not in index map, ignore
-            if ( ip is None or jq is None ):
+            if (ip is None or jq is None):
                 continue
 
             kss_ip = self.ks_singles.kss_list[ip]
@@ -205,9 +205,11 @@ class Kmatrix:
             if lip is not None and ljq is not None:
                 # add value to matrix
                 if self.file_format == 1:
-                    K_matrix[lip,ljq] = Kvalue
+                    K_matrix[lip, ljq] = Kvalue
                 elif self.file_format == 0:
-                    K_matrix[lip,ljq] = Kvalue / ( 2.* np.sqrt(kss_ip.energy_diff * kss_jq.energy_diff * kss_ip.pop_diff * kss_jq.pop_diff) )
+                    K_matrix[lip, ljq] = Kvalue / (
+                        2. * np.sqrt(kss_ip.energy_diff * kss_jq.energy_diff *
+                                     kss_ip.pop_diff * kss_jq.pop_diff))
                 else:
                     raise RuntimeError('Invalid K-matrix file format')
 
@@ -217,9 +219,11 @@ class Kmatrix:
             if lip is not None and ljq is not None:
                 # add value to matrix
                 if self.file_format == 1:
-                    K_matrix[ljq,lip] = Kvalue
+                    K_matrix[ljq, lip] = Kvalue
                 elif self.file_format == 0:
-                    K_matrix[ljq,lip] = Kvalue / ( 2.* np.sqrt(kss_ip.energy_diff * kss_jq.energy_diff * kss_ip.pop_diff * kss_jq.pop_diff) )
+                    K_matrix[ljq, lip] = Kvalue / (
+                        2. * np.sqrt(kss_ip.energy_diff * kss_jq.energy_diff *
+                                     kss_ip.pop_diff * kss_jq.pop_diff))
                 else:
                     raise RuntimeError('Invalid K-matrix file format')
 
@@ -231,10 +235,8 @@ class Kmatrix:
         #if self.parent_comm.rank == 0:
         #    print '-------------- building K-MATRIX done --------------------', resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
 
-
         #print K_matrix
 
-
         #for ((i,p), ip) in self.index_map.items():
         #    for ((j,q), jq) in self.index_map.items():
         #        lip = self.get_local_eh_index(ip)
@@ -242,10 +244,10 @@ class Kmatrix:
         #        if ( lip is not None and ljq is not None ):
         #            print 'proc #', self.parent_comm.rank, ' dd #', self.dd_comm.rank, ' eh #', self.eh_comm.rank, ': ',ip,'(', i, ',', p,') ',jq,'(', j, ',', q,')  = ', K_matrix[lip,ljq]
 
-
         # If any NaNs found, we did not read all matrix elements... BAD
         if np.isnan(np.sum(np.sum(K_matrix))):
-            raise RuntimeError('Not all required K-matrix elements could be found.')
+            raise RuntimeError(
+                'Not all required K-matrix elements could be found.')
 
         self.values = K_matrix
 
@@ -257,8 +259,8 @@ class Kmatrix:
 
         # Loop over all transitions
         self.K_matrix_ready = True  # mark done... if not, it's changed
-        nrows = 0                   # number of rows for timings
-        for (ip,kss_ip) in enumerate(self.ks_singles.kss_list):
+        nrows = 0  # number of rows for timings
+        for (ip, kss_ip) in enumerate(self.ks_singles.kss_list):
             i = kss_ip.occ_ind
             p = kss_ip.unocc_ind
 
@@ -266,7 +268,7 @@ class Kmatrix:
             if self.lr_comms.get_local_eh_index(ip) is None:
                 continue
             # if already calculated, skip it
-            if [i,p] in self.ready_indices:
+            if [i, p] in self.ready_indices:
                 continue
 
             self.K_matrix_ready = False  # something not calculated, must do it
@@ -276,7 +278,6 @@ class Kmatrix:
         if self.K_matrix_ready:
             return
 
-
         #self.timer.start('Calculate K matrix')
         #self.timer.start('Initialize')
 
@@ -284,15 +285,18 @@ class Kmatrix:
         #######################################################################
         # saving CORRECT K-matrix, not its "Casida form" like in alpha version
         #######################################################################
-        Kfn = self.basefilename + '.K_matrix.' + '%06dof%06d' % (self.lr_comms.eh_comm.rank, self.lr_comms.eh_comm.size)
-        rrfn = self.basefilename + '.ready_rows.' + '%06dof%06d' % (self.lr_comms.eh_comm.rank, self.lr_comms.eh_comm.size)
-        logfn = self.basefilename + '.log.' + '%06dof%06d' % (self.lr_comms.eh_comm.rank, self.lr_comms.eh_comm.size)
+        Kfn = self.basefilename + '.K_matrix.' + '%06dof%06d' % (
+            self.lr_comms.eh_comm.rank, self.lr_comms.eh_comm.size)
+        rrfn = self.basefilename + '.ready_rows.' + '%06dof%06d' % (
+            self.lr_comms.eh_comm.rank, self.lr_comms.eh_comm.size)
+        logfn = self.basefilename + '.log.' + '%06dof%06d' % (
+            self.lr_comms.eh_comm.rank, self.lr_comms.eh_comm.size)
 
         # Open only on dd_comm root
         if self.lr_comms.dd_comm.rank == 0:
             self.Kfile = open(Kfn, 'a+')
-            self.ready_file = open(rrfn,'a+')
-            self.log_file = open(logfn,'a+')
+            self.ready_file = open(rrfn, 'a+')
+            self.log_file = open(logfn, 'a+')
             self.Kfile.write('# K-matrix file\n')
 
         self.poisson = self.calc.hamiltonian.poisson
@@ -305,11 +309,12 @@ class Kmatrix:
         dnt_gjq = self.calc.density.finegd.empty()
         drhot_gjq = self.calc.density.finegd.empty()
 
-        self.nt_g = self.calc.density.finegd.zeros(self.calc.density.nt_sg.shape[0])
+        self.nt_g = self.calc.density.finegd.zeros(
+            self.calc.density.nt_sg.shape[0])
 
         dVht_gip = self.calc.density.finegd.empty()
-        dVxct_gip = self.calc.density.finegd.zeros(self.calc.density.nt_sg.shape[0])
-
+        dVxct_gip = self.calc.density.finegd.zeros(
+            self.calc.density.nt_sg.shape[0])
 
         #self.timer.stop('Initialize')
         # Init ETA
@@ -317,24 +322,26 @@ class Kmatrix:
 
         #################################################################
         # Outer loop over KS singles
-        for (ip,kss_ip) in enumerate(self.ks_singles.kss_list):
+        for (ip, kss_ip) in enumerate(self.ks_singles.kss_list):
 
             # if not mine, skip it
             if self.lr_comms.get_local_eh_index(ip) is None:
                 continue
             # if already calculated, skip it
-            if [kss_ip.occ_ind,kss_ip.unocc_ind] in self.ready_indices:
+            if [kss_ip.occ_ind, kss_ip.unocc_ind] in self.ready_indices:
                 continue
 
             # ETA
             if self.lr_comms.dd_comm.rank == 0:
                 self.matrix_eta.update()
                 # add 21% extra time (1.1**2 = 1.21)
-                eta = self.matrix_eta.eta( (nrows+1) * 1.1)
-                self.log_file.write('Calculating pair %5d => %5d  ( %s, ETA %9.1lfs )\n' % (kss_ip.occ_ind, kss_ip.unocc_ind, str(datetime.datetime.now()), eta))
+                eta = self.matrix_eta.eta((nrows + 1) * 1.1)
+                self.log_file.write(
+                    'Calculating pair %5d => %5d  ( %s, ETA %9.1lfs )\n' %
+                    (kss_ip.occ_ind, kss_ip.unocc_ind,
+                     str(datetime.datetime.now()), eta))
                 self.log_file.flush()
 
-
             # Pair density
             #self.timer.start('Pair density')
             dnt_Gip[:] = 0.0
@@ -343,7 +350,6 @@ class Kmatrix:
             kss_ip.calculate_pair_density(dnt_Gip, dnt_gip, drhot_gip)
             #self.timer.stop('Pair density')
 
-
             # Smooth Hartree "pair" potential
             # for compensated pair density drhot_gip
             #self.timer.start('Poisson')
@@ -356,18 +362,18 @@ class Kmatrix:
             # paw term of XC "pair" potential
             I_asp = self.calculate_paw_xc_pair_potentials(kss_ip)
 
-
             #################################################################
             # Inner loop over KS singles
-            K = [] # storage for row before writing to file
-            for (jq,kss_jq) in enumerate(self.ks_singles.kss_list):
+            K = []  # storage for row before writing to file
+            for (jq, kss_jq) in enumerate(self.ks_singles.kss_list):
                 i = kss_ip.occ_ind
                 p = kss_ip.unocc_ind
                 j = kss_jq.occ_ind
                 q = kss_jq.unocc_ind
 
                 # Only lower triangle
-                if ip < jq: continue
+                if ip < jq:
+                    continue
 
                 # Pair density dn_jq
                 #self.timer.start('Pair density')
@@ -377,7 +383,6 @@ class Kmatrix:
                 kss_jq.calculate_pair_density(dnt_Gjq, dnt_gjq, drhot_gjq)
                 #self.timer.stop('Pair density')
 
-
                 # integrate to get the final matrix element value
                 #self.timer.start('Integrate')
 
@@ -385,12 +390,13 @@ class Kmatrix:
                 Ig = 0.0
 
                 # Hartree smooth part, RHOT_JQ HERE???
-                Ig += self.fH_pre * self.calc.density.finegd.integrate(dVht_gip, drhot_gjq)
+                Ig += self.fH_pre * self.calc.density.finegd.integrate(
+                    dVht_gip, drhot_gjq)
                 # XC smooth part
-                Ig += self.fxc_pre * self.calc.density.finegd.integrate(dVxct_gip, dnt_gjq)
+                Ig += self.fxc_pre * self.calc.density.finegd.integrate(
+                    dVxct_gip, dnt_gjq)
                 #self.timer.stop('Integrate')
 
-
                 # Atomic corrections
                 #self.timer.start('Atomic corrections')
                 Ia = self.calculate_paw_fHXC_corrections(kss_ip, kss_jq, I_asp)
@@ -401,9 +407,8 @@ class Kmatrix:
                 # Total integral
                 Itot = Ig + Ia
 
-
                 # K_ip,jq += <ip|fHxc|jq>
-                K.append( [i,p,j,q, Itot] )
+                K.append([i, p, j, q, Itot])
 
             # Write  i p j q Kipjq
             # (format: -2345.789012345678)
@@ -413,21 +418,20 @@ class Kmatrix:
             if self.lr_comms.dd_comm.rank == 0:
 
                 # Write only lower triangle of K-matrix
-                for [i,p,j,q,Kipjq] in K:
-                    self.Kfile.write("%5d %5d %5d %5d %22.16lf\n" % (i,p,j,q,Kipjq))
-                self.Kfile.flush() # flush K-matrix before ready_rows
+                for [i, p, j, q, Kipjq] in K:
+                    self.Kfile.write("%5d %5d %5d %5d %22.16lf\n" %
+                                     (i, p, j, q, Kipjq))
+                self.Kfile.flush()  # flush K-matrix before ready_rows
 
                 # Write and flush ready rows
-                self.ready_file.write("%d %d\n" % (kss_ip.occ_ind,
-                                                   kss_ip.unocc_ind))
+                self.ready_file.write("%d %d\n" %
+                                      (kss_ip.occ_ind, kss_ip.unocc_ind))
                 self.ready_file.flush()
 
             #self.timer.stop('Write K')
 
             # Update ready rows before continuing
-            self.ready_indices.append([kss_ip.occ_ind,kss_ip.unocc_ind])
-
-
+            self.ready_indices.append([kss_ip.occ_ind, kss_ip.unocc_ind])
 
         # Close files on dd_comm root
         if self.lr_comms.dd_comm.rank == 0:
@@ -437,12 +441,12 @@ class Kmatrix:
 
         #self.timer.stop('Calculate K matrix')
 
-
     def calculate_smooth_xc_pair_potential(self, kss_ip, dnt_gip, dVxct_gip):
         # Smooth xc potential
         # (finite difference approximation from xc-potential)
-        if ( self.dVxct_gip_2 is None ):
-            self.dVxct_gip_2 = self.calc.density.finegd.zeros(self.calc.density.nt_sg.shape[0])
+        if (self.dVxct_gip_2 is None):
+            self.dVxct_gip_2 = self.calc.density.finegd.zeros(
+                self.calc.density.nt_sg.shape[0])
         dVxct_gip_2 = self.dVxct_gip_2
 
         s = kss_ip.spin_ind
@@ -462,10 +466,9 @@ class Kmatrix:
         dVxct_gip -= dVxct_gip_2
         # finite difference approx for fxc
         # vxc = (vxc+ - vxc-) / 2h
-        dVxct_gip *= 1./(2.*self.deriv_scale)
+        dVxct_gip *= 1. / (2. * self.deriv_scale)
         #self.timer.stop('Smooth XC')
 
-
     def calculate_paw_xc_pair_potentials(self, kss_ip):
         # XC corrections
         I_asp = {}
@@ -482,28 +485,27 @@ class Kmatrix:
 
             Pip_ni = self.calc.wfs.kpt_u[kss_ip.spin_ind].P_ani[a]
             Dip_ii = np.outer(Pip_ni[i], Pip_ni[p])
-            Dip_p  = pack(Dip_ii)
+            Dip_p = pack(Dip_ii)
 
             # finite difference plus
             D_sp = self.calc.density.D_asp[a].copy()
             D_sp[kss_ip.spin_ind] += self.deriv_scale * Dip_p
-            self.xc.calculate_paw_correction(self.calc.wfs.setups[a],
-                                             D_sp, I_sp)
+            self.xc.calculate_paw_correction(self.calc.wfs.setups[a], D_sp,
+                                             I_sp)
 
             # finite difference minus
             D_sp_2 = self.calc.density.D_asp[a].copy()
             D_sp_2[kss_ip.spin_ind] -= self.deriv_scale * Dip_p
-            self.xc.calculate_paw_correction(self.calc.wfs.setups[a],
-                                             D_sp_2, I_sp_2)
+            self.xc.calculate_paw_correction(self.calc.wfs.setups[a], D_sp_2,
+                                             I_sp_2)
 
             # finite difference
-            I_asp[a] = (I_sp - I_sp_2) / (2.*self.deriv_scale)
+            I_asp[a] = (I_sp - I_sp_2) / (2. * self.deriv_scale)
 
         #self.timer.stop('Atomic XC')
 
         return I_asp
 
-
     def calculate_paw_fHXC_corrections(self, kss_ip, kss_jq, I_asp):
         i = kss_ip.occ_ind
         p = kss_ip.unocc_ind
