@@ -3,6 +3,7 @@ import numpy as np
 from gpaw.blacs import BlacsGrid, Redistributor
 import _gpaw
 
+
 class LrDiagonalizeLayout:
     """BLACS layout for distributed Omega matrix in linear response
        time-dependet DFT calculations"""
@@ -12,13 +13,13 @@ class LrDiagonalizeLayout:
         self.lr_comms = lr_comms
 
         # original grid, ie, how matrix is stored
-        self.matrix_grid = BlacsGrid( self.lr_comms.parent_comm,
-                                      self.lr_comms.dd_comm.size,
-                                      self.lr_comms.eh_comm.size )
+        self.matrix_grid = BlacsGrid(self.lr_comms.parent_comm,
+                                     self.lr_comms.dd_comm.size,
+                                     self.lr_comms.eh_comm.size)
 
         # diagonalization grid
-        self.diag_grid = BlacsGrid(self.lr_comms.parent_comm, self.mprocs, self.nprocs)
-
+        self.diag_grid = BlacsGrid(self.lr_comms.parent_comm, self.mprocs,
+                                   self.nprocs)
 
         # -----------------------------------------------------------------
         # for SCALAPACK we need TRANSPOSED MATRIX (and vector)
@@ -33,14 +34,12 @@ class LrDiagonalizeLayout:
         bs = self.block_size
         self.diag_descr = self.diag_grid.new_descriptor(N, M, bs, bs)
 
-        self.diag_in_redist  = Redistributor( self.lr_comms.parent_comm,
-                                              self.matrix_descr,
-                                              self.diag_descr )
-
-        self.diag_out_redist = Redistributor( self.lr_comms.parent_comm,
-                                              self.diag_descr,
-                                              self.matrix_descr )
+        self.diag_in_redist = Redistributor(self.lr_comms.parent_comm,
+                                            self.matrix_descr, self.diag_descr)
 
+        self.diag_out_redist = Redistributor(self.lr_comms.parent_comm,
+                                             self.diag_descr,
+                                             self.matrix_descr)
 
     def diagonalize(self, eigenvectors, eigenvalues):
         """Diagonalize symmetric distributed Casida matrix using Scalapack.
@@ -56,7 +55,7 @@ class LrDiagonalizeLayout:
         if self.matrix_descr.blacsgrid.is_active():
             O_orig = eigenvectors
         else:
-            O_orig = np.empty((0,0), dtype=float)
+            O_orig = np.empty((0, 0), dtype=float)
 
         self.diag_in_redist.redistribute(O_orig, O_diag)
 
@@ -69,7 +68,6 @@ class LrDiagonalizeLayout:
         self.lr_comms.parent_comm.broadcast(eigenvalues, 0)
 
 
-
 class LrTDDFPTSolveLayout:
     """BLACS layouts for distributed TD-DFPT"""
     def __init__(self, sl_lrtddft, nrows, lr_comms):
@@ -83,57 +81,60 @@ class LrTDDFPTSolveLayout:
         # matrix
 
         # original grid, ie, how matrix is stored
-        self.orig_matrix_grid = BlacsGrid( self.lr_comms.parent_comm,
-                                           self.lr_comms.dd_comm.size,
-                                           self.lr_comms.eh_comm.size )
+        self.orig_matrix_grid = BlacsGrid(self.lr_comms.parent_comm,
+                                          self.lr_comms.dd_comm.size,
+                                          self.lr_comms.eh_comm.size)
 
         # solve grid
-        self.solve_matrix_grid = BlacsGrid(self.lr_comms.parent_comm, self.mprocs, self.nprocs)
+        self.solve_matrix_grid = BlacsGrid(self.lr_comms.parent_comm,
+                                           self.mprocs, self.nprocs)
 
         # M = rows, N = cols
-        M = nrows*4
-        N = nrows*4
+        M = nrows * 4
+        N = nrows * 4
         mb = 4
         nb = 4
-        self.orig_matrix_descr = self.orig_matrix_grid.new_descriptor(N, M, nb, mb)
+        self.orig_matrix_descr = self.orig_matrix_grid.new_descriptor(
+            N, M, nb, mb)
 
         bs = self.block_size
-        self.solve_matrix_descr = self.solve_matrix_grid.new_descriptor(N, M, bs, bs)
+        self.solve_matrix_descr = self.solve_matrix_grid.new_descriptor(
+            N, M, bs, bs)
 
-        self.matrix_in_redist  = Redistributor( self.lr_comms.parent_comm,
-                                                self.orig_matrix_descr,
-                                                self.solve_matrix_descr )
+        self.matrix_in_redist = Redistributor(self.lr_comms.parent_comm,
+                                              self.orig_matrix_descr,
+                                              self.solve_matrix_descr)
 
         # -----------------------------------------------------------------
         # vector
 
         # original grid, ie, how vector is stored
-        self.orig_vector_grid = BlacsGrid( self.lr_comms.parent_comm,
-                                           1,
-                                           ( self.lr_comms.dd_comm.size *
-                                             self.lr_comms.eh_comm.size ) )
+        self.orig_vector_grid = BlacsGrid(
+            self.lr_comms.parent_comm, 1,
+            (self.lr_comms.dd_comm.size * self.lr_comms.eh_comm.size))
 
         # solve grid
         #self.solve_vector_grid = BlacsGrid(self.lr_comms.parent_comm, self.mprocs, self.nprocs)
 
         # M = rows, N = cols
-        M = nrows*4
+        M = nrows * 4
         Nrhs = 1
         mb = 4
         nb = 1
-        self.orig_vector_descr = self.orig_vector_grid.new_descriptor(Nrhs, M, nb, mb)
+        self.orig_vector_descr = self.orig_vector_grid.new_descriptor(
+            Nrhs, M, nb, mb)
 
         bs = self.block_size
-        self.solve_vector_descr = self.solve_matrix_grid.new_descriptor(Nrhs, M, 1, bs)
+        self.solve_vector_descr = self.solve_matrix_grid.new_descriptor(
+            Nrhs, M, 1, bs)
 
-        self.vector_in_redist  = Redistributor( self.lr_comms.parent_comm,
-                                                self.orig_vector_descr,
-                                                self.solve_vector_descr )
-
-        self.vector_out_redist = Redistributor( self.lr_comms.parent_comm,
-                                                self.solve_vector_descr,
-                                                self.orig_vector_descr )
+        self.vector_in_redist = Redistributor(self.lr_comms.parent_comm,
+                                              self.orig_vector_descr,
+                                              self.solve_vector_descr)
 
+        self.vector_out_redist = Redistributor(self.lr_comms.parent_comm,
+                                               self.solve_vector_descr,
+                                               self.orig_vector_descr)
 
     def solve(self, A_orig, b_orig):
         """Solve TD-DFPT equation using Scalapack.
@@ -141,13 +142,13 @@ class LrTDDFPTSolveLayout:
 
         A_solve = self.solve_matrix_descr.empty(dtype=float)
         if not self.orig_matrix_descr.blacsgrid.is_active():
-            A_orig = np.empty((0,0), dtype=float)
+            A_orig = np.empty((0, 0), dtype=float)
 
         self.matrix_in_redist.redistribute(A_orig, A_solve)
 
         b_solve = self.solve_vector_descr.empty(dtype=float)
         if not self.orig_vector_descr.blacsgrid.is_active():
-            b_orig = np.empty((0,0), dtype=float)
+            b_orig = np.empty((0, 0), dtype=float)
 
         self.vector_in_redist.redistribute(b_orig, b_solve)
 
@@ -172,14 +173,13 @@ class LrTDDFPTSolveLayout:
 
         info = 0
         if self.solve_matrix_descr.blacsgrid.is_active():
-            _gpaw.scalapack_solve(A_solve, self.solve_matrix_descr.asarray(), b_solve, self.solve_vector_descr.asarray())
+            _gpaw.scalapack_solve(A_solve, self.solve_matrix_descr.asarray(),
+                                  b_solve, self.solve_vector_descr.asarray())
             if info != 0:
                 raise RuntimeError('scalapack_solve error: %d' % info)
 
-
         self.vector_out_redist.redistribute(b_solve, b_orig)
 
-
         #if False:
         #    for i in range(self.lr_comms.parent_comm.size):
         #        if ( self.lr_comms.parent_comm.rank == i ):
@@ -201,7 +201,6 @@ class LrTDDFPTSolveLayout:
 class LrTDDFTLayouts:
     """BLACS layout for distributed Omega matrix in linear response
        time-dependet DFT calculations"""
-
     def __init__(self, sl_lrtddft, nkq, dd_comm, eh_comm):
         mcpus, ncpus, blocksize = tuple(sl_lrtddft)
         self.world = eh_comm.parent
@@ -217,17 +216,13 @@ class LrTDDFTLayouts:
         self.eh_grid = BlacsGrid(self.eh_comm2, eh_comm.size, 1)
         self.eh_descr = self.eh_grid.new_descriptor(nkq, nkq, 1, nkq)
         self.diag_grid = BlacsGrid(self.world, mcpus, ncpus)
-        self.diag_descr = self.diag_grid.new_descriptor(nkq, nkq,
-                                                        blocksize,
-                                                        blocksize)
+        self.diag_descr = self.diag_grid.new_descriptor(
+            nkq, nkq, blocksize, blocksize)
 
-        self.redistributor_in = Redistributor(self.world,
-                                              self.eh_descr,
+        self.redistributor_in = Redistributor(self.world, self.eh_descr,
                                               self.diag_descr)
-        self.redistributor_out = Redistributor(self.world,
-                                               self.diag_descr,
+        self.redistributor_out = Redistributor(self.world, self.diag_descr,
                                                self.eh_descr)
-
         """
         # -----------------------------------------------------------------
         # for SCALAPACK we need TRANSPOSED MATRIX (and vector)
@@ -261,13 +256,12 @@ class LrTDDFTLayouts:
                                                  self.eh_descr2b)
         """
 
-
         # -----------------------------------------------------------------
         # for SCALAPACK we need TRANSPOSED MATRIX (and vector)
         # -----------------------------------------------------------------
         # M = rows, N = cols
-        M = nkq*4
-        N = nkq*4
+        M = nkq * 4
+        N = nkq * 4
         mb = 4
         nb = 4
         Nrhs = 1
@@ -275,19 +269,16 @@ class LrTDDFTLayouts:
         self.eh_grid2a = BlacsGrid(self.world, dd_comm.size, eh_comm.size)
         # Vector, mp=eh_comm.size, np=1
         self.eh_grid2b = BlacsGrid(self.world, 1, dd_comm.size * eh_comm.size)
-        self.eh_descr2a = self.eh_grid2a.new_descriptor(N,    M,  nb,   mb)
-        self.eh_descr2b = self.eh_grid2b.new_descriptor(Nrhs, N,  Nrhs, nb)
-        self.solve_descr2a =self.diag_grid.new_descriptor(N, M,
-                                                          blocksize, blocksize)
-        self.solve_descr2b =self.diag_grid.new_descriptor(Nrhs, N,
-                                                          Nrhs, blocksize)
+        self.eh_descr2a = self.eh_grid2a.new_descriptor(N, M, nb, mb)
+        self.eh_descr2b = self.eh_grid2b.new_descriptor(Nrhs, N, Nrhs, nb)
+        self.solve_descr2a = self.diag_grid.new_descriptor(
+            N, M, blocksize, blocksize)
+        self.solve_descr2b = self.diag_grid.new_descriptor(
+            Nrhs, N, Nrhs, blocksize)
 
-
-        self.redist_solve_in_2a = Redistributor(self.world,
-                                                self.eh_descr2a,
+        self.redist_solve_in_2a = Redistributor(self.world, self.eh_descr2a,
                                                 self.solve_descr2a)
-        self.redist_solve_in_2b = Redistributor(self.world,
-                                                self.eh_descr2b,
+        self.redist_solve_in_2b = Redistributor(self.world, self.eh_descr2b,
                                                 self.solve_descr2b)
 
         self.redist_solve_out_2a = Redistributor(self.world,
@@ -297,8 +288,6 @@ class LrTDDFTLayouts:
                                                  self.solve_descr2b,
                                                  self.eh_descr2b)
 
-
-
     def solve(self, A, b):
         #if 0:
         #    print 'edescr2a', rank, self.eh_descr2a.asarray()
@@ -324,17 +313,16 @@ class LrTDDFTLayouts:
         if self.eh_descr2a.blacsgrid.is_active():
             A_Nn = A
         else:
-            A_Nn = np.empty((0,0), dtype=float)
+            A_Nn = np.empty((0, 0), dtype=float)
         self.redist_solve_in_2a.redistribute(A_Nn, A_nn)
 
         b_n = self.solve_descr2b.empty(dtype=float)
         if self.eh_descr2b.blacsgrid.is_active():
-            b_N = b.reshape(1,len(b))
+            b_N = b.reshape(1, len(b))
         else:
-            b_N = np.empty((A_Nn.shape[0],0), dtype=float)
+            b_N = np.empty((A_Nn.shape[0], 0), dtype=float)
         self.redist_solve_in_2b.redistribute(b_N, b_n)
 
-
         #if 0:
         #    print 'A_Nn ', rank, A_Nn.shape
         #    print 'b_N  ', rank, b_N.shape
@@ -362,12 +350,12 @@ class LrTDDFTLayouts:
 
         info = 0
         if self.solve_descr2a.blacsgrid.is_active():
-            _gpaw.scalapack_solve(A_nn, self.solve_descr2a.asarray(), b_n, self.solve_descr2b.asarray())
+            _gpaw.scalapack_solve(A_nn, self.solve_descr2a.asarray(), b_n,
+                                  self.solve_descr2b.asarray())
             if info != 0:
                 raise RuntimeError('scalapack_solve error: %d' % info)
         self.redist_solve_out_2b.redistribute(b_n, b_N)
 
-
         if self.eh_descr2b.blacsgrid.is_active():
             b_N = b_N.flatten()
         else:
@@ -377,14 +365,13 @@ class LrTDDFTLayouts:
 
         b[:] = b_N
 
-
     def diagonalize(self, Om, eps_n):
 
         O_nn = self.diag_descr.empty(dtype=float)
         if self.eh_descr.blacsgrid.is_active():
             O_nN = Om
         else:
-            O_nN = np.empty((0,0), dtype=float)
+            O_nN = np.empty((0, 0), dtype=float)
 
         self.redistributor_in.redistribute(O_nN, O_nn)
         self.diag_descr.diagonalize_dc(O_nn.copy(), O_nn, eps_n, 'L')
