@@ -1,14 +1,13 @@
 import numpy as np
-
 import ase.units
+from scipy.linalg import eigh
 
-import gpaw.utilities.lapack
-
+from gpaw.mpi import world
 from gpaw.lrtddft2.lr_layouts import LrDiagonalizeLayout
 
 
 class LrtddftTransitions:
-    def __init__(self, ks_singles, K_matrix, sl_lrtddft = None):
+    def __init__(self, ks_singles, K_matrix, sl_lrtddft=None):
         self.ks_singles = ks_singles
         self.K_matrix = K_matrix
         self.lr_comms = self.ks_singles.lr_comms
@@ -48,7 +47,7 @@ class LrtddftTransitions:
         nrows = len(self.ks_singles.kss_list)
 
         # build local part of the full omega matrix
-        omega_matrix = np.zeros((nrows,nrows), dtype=float)
+        omega_matrix = np.zeros((nrows, nrows), dtype=float)
         for (ip, kss_ip) in enumerate(self.ks_singles.kss_list):
             for (jq, kss_jq) in enumerate(self.ks_singles.kss_list):
                 lip = self.lr_comms.get_local_eh_index(ip)
@@ -58,7 +57,9 @@ class LrtddftTransitions:
 
                 # K-matrix
                 #if self.K_matrix.file_format == 1:
-                omega_matrix[ip,jq] = 2.* np.sqrt(kss_ip.energy_diff * kss_jq.energy_diff * kss_ip.pop_diff * kss_jq.pop_diff) * self.K_matrix.values[lip,ljq]
+                omega_matrix[ip, jq] = 2. * np.sqrt(
+                    kss_ip.energy_diff * kss_jq.energy_diff * kss_ip.pop_diff *
+                    kss_jq.pop_diff) * self.K_matrix.values[lip, ljq]
                 # old Casida format ... doing this already in k_matrix.py
                 #elif self.K_matrix.file_format == 0:
                 #    omega_matrix[ip,jq] = self.K_matrix.values[lip,ljq]
@@ -66,8 +67,9 @@ class LrtddftTransitions:
                 #else:
                 #    raise RuntimeError('Invalid K-matrix file format')
 
-                if ( ip == jq ):
-                    omega_matrix[ip,jq] += kss_ip.energy_diff * kss_jq.energy_diff
+                if (ip == jq):
+                    omega_matrix[ip,
+                                 jq] += kss_ip.energy_diff * kss_jq.energy_diff
 
         # full omega matrix to each process
         self.lr_comms.parent_comm.sum(omega_matrix)
@@ -76,7 +78,6 @@ class LrtddftTransitions:
         #    print omega_matrix
 
         # solve eigensystem
-        self.eigenvalues = np.zeros(nrows)
 
         # debug
         #omega_matrix[:] = 0
@@ -85,11 +86,7 @@ class LrtddftTransitions:
         #        if i == j: omega_matrix[i,j] = -2.
         #        if i+1 == j: omega_matrix[i,j] = omega_matrix[j,i] = 1.
 
-
-        gpaw.utilities.lapack.diagonalize(omega_matrix, self.eigenvalues)
-
-        # make columns have eigenvectors (not rows)
-        omega_matrix = np.transpose(omega_matrix)
+        self.eigenvalues, omega_matrix = eigh(omega_matrix)
 
         # convert eigenvector back to local version
         nlrows = self.K_matrix.values.shape[0]
@@ -102,14 +99,15 @@ class LrtddftTransitions:
         # 20 21 22 23
         # 30 31 32 33
 
-        self.eigenvectors = np.zeros((nlrows,nlcols), dtype=float)
+        self.eigenvectors = np.zeros((nlrows, nlcols), dtype=float)
         for (ip, kss) in enumerate(self.ks_singles.kss_list):
             for (jq, kss) in enumerate(self.ks_singles.kss_list):
                 lip = self.lr_comms.get_local_eh_index(ip)
                 ljq = self.lr_comms.get_local_dd_index(jq)
                 if lip is None or ljq is None:
                     continue
-                self.eigenvectors[lip,ljq] = omega_matrix[ip,jq] # debug: ip*10 + jq
+                self.eigenvectors[lip, ljq] = omega_matrix[
+                    ip, jq]  # debug: ip*10 + jq
 
         #debug
         #if 0:
@@ -130,12 +128,15 @@ class LrtddftTransitions:
         nlcols = self.K_matrix.values.shape[1]
 
         # create BLACS layout
-        layout = LrDiagonalizeLayout( self.sl_lrtddft, nrows, self.lr_comms )
-        if ( nrows < np.max([layout.mprocs,layout.nprocs]) * layout.block_size ):
-            raise RuntimeError('Linear response matrix is not large enough for the given number of processes (or block size) in sl_lrtddft. Please, use less processes (or smaller block size).')
+        layout = LrDiagonalizeLayout(self.sl_lrtddft, nrows, self.lr_comms)
+        if (nrows <
+                np.max([layout.mprocs, layout.nprocs]) * layout.block_size):
+            raise RuntimeError(
+                'Linear response matrix is not large enough for the given number of processes (or block size) in sl_lrtddft. Please, use less processes (or smaller block size).'
+            )
 
         # build local part
-        omega_matrix = np.zeros((nlrows,nlcols), dtype=float)
+        omega_matrix = np.zeros((nlrows, nlcols), dtype=float)
         for (ip, kss_ip) in enumerate(self.ks_singles.kss_list):
             for (jq, kss_jq) in enumerate(self.ks_singles.kss_list):
                 lip = self.lr_comms.get_local_eh_index(ip)
@@ -144,22 +145,26 @@ class LrtddftTransitions:
                     continue
 
                 #if self.K_matrix.file_format == 1:
-                omega_matrix[lip,ljq] = 2.* np.sqrt(kss_ip.energy_diff * kss_jq.energy_diff * kss_ip.pop_diff * kss_jq.pop_diff) * self.K_matrix.values[lip,ljq]
+                omega_matrix[lip, ljq] = 2. * np.sqrt(
+                    kss_ip.energy_diff * kss_jq.energy_diff * kss_ip.pop_diff *
+                    kss_jq.pop_diff) * self.K_matrix.values[lip, ljq]
                 # old Casida format ... doing this already in k_matrix.py
                 #elif self.K_matrix.file_format == 0:
                 #    omega_matrix[lip,ljq] = self.K_matrix.values[lip,ljq]
                 #else:
                 #    raise RuntimeError('Invalid K-matrix file format')
 
-                if ( ip == jq ):
-                    omega_matrix[lip,ljq] += kss_ip.energy_diff * kss_jq.energy_diff
+                if (ip == jq):
+                    omega_matrix[
+                        lip, ljq] += kss_ip.energy_diff * kss_jq.energy_diff
 
         # solve eigen system (transpose for scalapack)
         self.eigenvalues = np.zeros(nrows, dtype=float)
-        self.eigenvectors = np.zeros((omega_matrix.shape[1],omega_matrix.shape[0]),dtype=float)
-        self.eigenvectors[:,:] = np.transpose(omega_matrix)
+        self.eigenvectors = np.zeros(
+            (omega_matrix.shape[1], omega_matrix.shape[0]), dtype=float)
+        self.eigenvectors[:, :] = np.transpose(omega_matrix)
         layout.diagonalize(self.eigenvectors, self.eigenvalues)
-        omega_matrix[:,:] = np.transpose(self.eigenvectors)
+        omega_matrix[:, :] = np.transpose(self.eigenvectors)
         self.eigenvectors = omega_matrix
 
     def calculate_properties(self):
@@ -176,9 +181,9 @@ class LrtddftTransitions:
         nleigs = self.eigenvectors.shape[1]
 
         sqrtwloc = np.zeros(nleigs)
-        dmxloc  = np.zeros(nleigs)
-        dmyloc  = np.zeros(nleigs)
-        dmzloc  = np.zeros(nleigs)
+        dmxloc = np.zeros(nleigs)
+        dmyloc = np.zeros(nleigs)
+        dmzloc = np.zeros(nleigs)
         magnxloc = np.zeros(nleigs)
         magnyloc = np.zeros(nleigs)
         magnzloc = np.zeros(nleigs)
@@ -187,7 +192,6 @@ class LrtddftTransitions:
 
         #print self.lr_comms.parent_comm.rank, self.lr_comms.eh_comm.rank, self.lr_comms.dd_comm.rank, nlrows, nlcols
 
-
         # see Autschbach et al., J. Chem. Phys., 116, 6930 (2002)
         # see also Varsano et al., Phys.Chem.Chem.Phys. 11, 4481 (2009)
         #
@@ -221,11 +225,12 @@ class LrtddftTransitions:
 
         # sqrt(omega_kloc)
         for kloc in range(nleigs):
-            sqrtwloc[kloc] = np.sqrt( np.sqrt(self.eigenvalues[self.lr_comms.get_global_dd_index(kloc)]) )
+            sqrtwloc[kloc] = np.sqrt(
+                np.sqrt(
+                    self.eigenvalues[self.lr_comms.get_global_dd_index(kloc)]))
 
         #print self.lr_comms.parent_comm.rank, self.lr_comms.eh_comm.rank, self.lr_comms.dd_comm.rank, nlrows, nleigs, sqrtwloc
 
-
         # loop over ks singles
         for (ip, kss_ip) in enumerate(self.ks_singles.kss_list):
 
@@ -243,66 +248,68 @@ class LrtddftTransitions:
             # a continuous copy of ROW of eigenvectors
             # i.e. a "ip"th element of each eigenvector
             # (NOT the "jq"th eigenvector)
-            cloc_dm[:]   = self.eigenvectors[lip,:]
-            cloc_magn[:] = self.eigenvectors[lip,:]
+            cloc_dm[:] = self.eigenvectors[lip, :]
+            cloc_magn[:] = self.eigenvectors[lip, :]
 
             #print self.lr_comms.parent_comm.rank, i,p, ip, lip, cloc_dm, sqrtwloc, cloc_dm * sqrtwloc
 
             # c1 * c2 * F = sqrt(fdiff_ip * ediff_ip) / sqrt(omega_k) F^(k)_ip
-            cloc_dm   *= np.sqrt(kss_ip.pop_diff * kss_ip.energy_diff)
-            cloc_dm   /= sqrtwloc
+            cloc_dm *= np.sqrt(kss_ip.pop_diff * kss_ip.energy_diff)
+            cloc_dm /= sqrtwloc
 
             # c2 / c1 * F = sqrt(fdiff_ip / ediff_ip) * sqrt(omega_k) F^(k)_ip
             cloc_magn *= np.sqrt(kss_ip.pop_diff / kss_ip.energy_diff)
             cloc_magn *= sqrtwloc
 
             if self.custom_axes is None:
-                dmxloc  += kss_ip.dip_mom_r[0] * cloc_dm
-                dmyloc  += kss_ip.dip_mom_r[1] * cloc_dm
-                dmzloc  += kss_ip.dip_mom_r[2] * cloc_dm
+                dmxloc += kss_ip.dip_mom_r[0] * cloc_dm
+                dmyloc += kss_ip.dip_mom_r[1] * cloc_dm
+                dmzloc += kss_ip.dip_mom_r[2] * cloc_dm
 
                 magnxloc += kss_ip.magn_mom[0] * cloc_magn
                 magnyloc += kss_ip.magn_mom[1] * cloc_magn
                 magnzloc += kss_ip.magn_mom[2] * cloc_magn
             else:
-                dmxloc += np.dot(kss_ip.dip_mom_r, self.custom_axes[0]) * cloc_dm
-                dmyloc += np.dot(kss_ip.dip_mom_r, self.custom_axes[1]) * cloc_dm
-                dmzloc += np.dot(kss_ip.dip_mom_r, self.custom_axes[2]) * cloc_dm
-
-                magnxloc += np.dot(kss_ip.magn_mom, self.custom_axes[0]) * cloc_magn
-                magnyloc += np.dot(kss_ip.magn_mom, self.custom_axes[1]) * cloc_magn
-                magnzloc += np.dot(kss_ip.magn_mom, self.custom_axes[2]) * cloc_magn
+                dmxloc += np.dot(kss_ip.dip_mom_r,
+                                 self.custom_axes[0]) * cloc_dm
+                dmyloc += np.dot(kss_ip.dip_mom_r,
+                                 self.custom_axes[1]) * cloc_dm
+                dmzloc += np.dot(kss_ip.dip_mom_r,
+                                 self.custom_axes[2]) * cloc_dm
 
+                magnxloc += np.dot(kss_ip.magn_mom,
+                                   self.custom_axes[0]) * cloc_magn
+                magnyloc += np.dot(kss_ip.magn_mom,
+                                   self.custom_axes[1]) * cloc_magn
+                magnzloc += np.dot(kss_ip.magn_mom,
+                                   self.custom_axes[2]) * cloc_magn
 
         # global properties, but local eigs
         # sum over iploc dmx_iploc[kloc] to dmx[kloc]
-        props = np.array([ dmxloc,   dmyloc,   dmzloc,
-                           magnxloc, magnyloc, magnzloc ])
+        props = np.array(
+            [dmxloc, dmyloc, dmzloc, magnxloc, magnyloc, magnzloc])
         self.lr_comms.eh_comm.sum(props.ravel())
-        [ dmxloc,   dmyloc,   dmzloc,
-          magnxloc, magnyloc, magnzloc ] = props
-
+        [dmxloc, dmyloc, dmzloc, magnxloc, magnyloc, magnzloc] = props
 
         # global properties and eigs
         # create local part of the global eigs
         nrows = len(self.ks_singles.kss_list)
-        self.transition_properties = np.zeros([nrows,1+3+3])
+        self.transition_properties = np.zeros([nrows, 1 + 3 + 3])
         for k in range(nrows):
             kloc = self.lr_comms.get_local_dd_index(k)
             if kloc is None:
                 continue
-            self.transition_properties[k,0] = sqrtwloc[kloc] * sqrtwloc[kloc]
-            self.transition_properties[k,1] = dmxloc[kloc]
-            self.transition_properties[k,2] = dmyloc[kloc]
-            self.transition_properties[k,3] = dmzloc[kloc]
-            self.transition_properties[k,4] = magnxloc[kloc]
-            self.transition_properties[k,5] = magnyloc[kloc]
-            self.transition_properties[k,6] = magnzloc[kloc]
+            self.transition_properties[k, 0] = sqrtwloc[kloc] * sqrtwloc[kloc]
+            self.transition_properties[k, 1] = dmxloc[kloc]
+            self.transition_properties[k, 2] = dmyloc[kloc]
+            self.transition_properties[k, 3] = dmzloc[kloc]
+            self.transition_properties[k, 4] = magnxloc[kloc]
+            self.transition_properties[k, 5] = magnyloc[kloc]
+            self.transition_properties[k, 6] = magnzloc[kloc]
 
         # sum over kloc dmx[...kloc...] to dmx[k]
         self.lr_comms.dd_comm.sum(self.transition_properties.ravel())
 
-
         #print self.lr_comms.parent_comm.rank, self.transition_properties[:,1]
         #return
 
@@ -336,7 +343,6 @@ class LrtddftTransitions:
         else:
             raise RuntimeError('Unknown units.')
 
-
     def get_oscillator_strength(self, k):
         """Get oscillator strength for an interacting transition
 
@@ -357,11 +363,10 @@ class LrtddftTransitions:
 
         oscx = 2. * omega * dmx * dmx
         oscy = 2. * omega * dmy * dmy
-        oscz = 2. * omega * dmz  *dmz
+        oscz = 2. * omega * dmz * dmz
         osc = (oscx + oscy + oscz) / 3.
         return osc, np.array([oscx, oscy, oscz])
 
-
     def get_rotatory_strength(self, k, units='au'):
         """Get rotatory strength for an interacting transition
 
@@ -388,7 +393,7 @@ class LrtddftTransitions:
         magnz = self.transition_properties[k][6]
 
         if units == 'au':
-            return - ( dmx * magnx + dmy * magny + dmz * magnz )
+            return -(dmx * magnx + dmy * magny + dmz * magnz)
         elif units == 'cgs' or units == 'eVcgs':
             # 10^-40 esu cm erg / G
             # = 3.33564095 * 10^-15 A^2 m^3 s
@@ -401,11 +406,15 @@ class LrtddftTransitions:
             # 64604.8164/471.43 = 137.040
             # is the inverse of fine-structure constant
             # OR it must be speed of light in atomic units
-            return - 64604.8164 * ( dmx * magnx + dmy * magny + dmz * magnz )
+            return -64604.8164 * (dmx * magnx + dmy * magny + dmz * magnz)
         else:
             raise RuntimeError('Unknown units.')
 
-    def get_transitions(self, filename=None, min_energy=0.0, max_energy=30.0, units='eVcgs'):
+    def get_transitions(self,
+                        filename=None,
+                        min_energy=0.0,
+                        max_energy=30.0,
+                        units='eVcgs'):
         """Get transitions: energy, dipole strength and rotatory strength.
 
         Returns transitions as (w,S,R, Sx,Sy,Sz) where w is an array of frequencies,
@@ -444,7 +453,7 @@ class LrtddftTransitions:
             Sx.append(Sc[0])
             Sy.append(Sc[1])
             Sz.append(Sc[2])
-            R.append(self.get_rotatory_strength(k,units))
+            R.append(self.get_rotatory_strength(k, units))
 
         w = np.array(w)
         S = np.array(S)
@@ -453,18 +462,26 @@ class LrtddftTransitions:
         Sy = np.array(Sy)
         Sz = np.array(Sz)
 
-
-        if filename is not None and gpaw.mpi.world.rank == 0:
-            sfile = open(filename,'w')
-            sfile.write("# %12s  %12s  %12s     %12s  %12s  %12s    %s\n" % ('energy','osc str','rot str','osc str x', 'osc str y', 'osc str z', 'units: ' + units))
-            for (ww,SS,RR,SSx,SSy,SSz) in zip(w,S,R,Sx,Sy,Sz):
-                sfile.write("  %12.8lf  %12.8lf  %12.8lf     %12.8lf  %12.8lf  %12.8lf\n" % (ww,SS,RR,SSx,SSy,SSz))
+        if filename is not None and world.rank == 0:
+            sfile = open(filename, 'w')
+            sfile.write("# %12s  %12s  %12s     %12s  %12s  %12s    %s\n" %
+                        ('energy', 'osc str', 'rot str', 'osc str x',
+                         'osc str y', 'osc str z', 'units: ' + units))
+            for (ww, SS, RR, SSx, SSy, SSz) in zip(w, S, R, Sx, Sy, Sz):
+                sfile.write(
+                    "  %12.8lf  %12.8lf  %12.8lf     %12.8lf  %12.8lf  %12.8lf\n"
+                    % (ww, SS, RR, SSx, SSy, SSz))
             sfile.close()
 
-        return (w,S,R,Sx,Sy,Sz)
+        return (w, S, R, Sx, Sy, Sz)
 
-    def get_spectrum(self, filename=None, min_energy=0.0, max_energy=30.0,
-                     energy_step=0.01, width=0.1, units='eVcgs'):
+    def get_spectrum(self,
+                     filename=None,
+                     min_energy=0.0,
+                     max_energy=30.0,
+                     energy_step=0.01,
+                     width=0.1,
+                     units='eVcgs'):
         """Get spectrum for dipole and rotatory strength.
 
         Returns folded spectrum as (w,S,R) where w is an array of frequencies,
@@ -492,9 +509,10 @@ class LrtddftTransitions:
         if not self.trans_prop_ready:
             self.calculate()
 
-        (ww, SS, RR, SSx, SSy, SSz) = self.get_transitions(min_energy=min_energy-5*width,
-                                                           max_energy=max_energy+5*width,
-                                                           units=units)
+        (ww, SS, RR, SSx, SSy,
+         SSz) = self.get_transitions(min_energy=min_energy - 5 * width,
+                                     max_energy=max_energy + 5 * width,
+                                     units=units)
 
         if units == 'eVcgs':
             pass  # convf = 1/ase.units.Hartree
@@ -504,42 +522,41 @@ class LrtddftTransitions:
             raise RuntimeError('Invalid units')
 
         w = np.arange(min_energy, max_energy, energy_step)
-        S  = np.zeros_like(w)
+        S = np.zeros_like(w)
         Sx = np.zeros_like(w)
         Sy = np.zeros_like(w)
         Sz = np.zeros_like(w)
-        R  = np.zeros_like(w)
-
+        R = np.zeros_like(w)
 
         for (k, www) in enumerate(ww):
 
-            c = SS[k] / width / np.sqrt(2*np.pi)
-            S += c * np.exp( (-.5/width/width) * np.power(w-ww[k],2) )
+            c = SS[k] / width / np.sqrt(2 * np.pi)
+            S += c * np.exp((-.5 / width / width) * np.power(w - ww[k], 2))
 
-            c = SSx[k] / width / np.sqrt(2*np.pi)
-            Sx += c * np.exp( (-.5/width/width) * np.power(w-ww[k],2) )
+            c = SSx[k] / width / np.sqrt(2 * np.pi)
+            Sx += c * np.exp((-.5 / width / width) * np.power(w - ww[k], 2))
 
-            c = SSy[k] / width / np.sqrt(2*np.pi)
-            Sy += c * np.exp( (-.5/width/width) * np.power(w-ww[k],2) )
+            c = SSy[k] / width / np.sqrt(2 * np.pi)
+            Sy += c * np.exp((-.5 / width / width) * np.power(w - ww[k], 2))
 
-            c = SSz[k] / width / np.sqrt(2*np.pi)
-            Sz += c * np.exp( (-.5/width/width) * np.power(w-ww[k],2) )
+            c = SSz[k] / width / np.sqrt(2 * np.pi)
+            Sz += c * np.exp((-.5 / width / width) * np.power(w - ww[k], 2))
 
+            c = RR[k] / width / np.sqrt(2 * np.pi)
+            R += c * np.exp((-.5 / width / width) * np.power(w - ww[k], 2))
 
-            c = RR[k] / width / np.sqrt(2*np.pi)
-            R += c * np.exp( (-.5/width/width) * np.power(w-ww[k],2) )
-
-
-        if filename is not None and gpaw.mpi.world.rank == 0:
-            sfile = open(filename,'w')
-            sfile.write("# %12s  %12s  %12s     %12s  %12s  %12s    %s\n" % ('energy','osc str','rot str','osc str x','osc str y','osc str z', 'units: ' + units))
-            for (ww,SS,RR,SSx,SSy,SSz) in zip(w,S,R,Sx,Sy,Sz):
-                sfile.write("  %12.8lf  %12.8lf  %12.8lf     %12.8lf  %12.8lf  %12.8lf\n" % (ww,SS,RR,SSx,SSy,SSz))
+        if filename is not None and world.rank == 0:
+            sfile = open(filename, 'w')
+            sfile.write("# %12s  %12s  %12s     %12s  %12s  %12s    %s\n" %
+                        ('energy', 'osc str', 'rot str', 'osc str x',
+                         'osc str y', 'osc str z', 'units: ' + units))
+            for (ww, SS, RR, SSx, SSy, SSz) in zip(w, S, R, Sx, Sy, Sz):
+                sfile.write(
+                    "  %12.8lf  %12.8lf  %12.8lf     %12.8lf  %12.8lf  %12.8lf\n"
+                    % (ww, SS, RR, SSx, SSy, SSz))
             sfile.close()
 
-        return (w,S,R, Sx,Sy,Sz)
-
-
+        return (w, S, R, Sx, Sy, Sz)
 
     def get_transition_contributions(self, index_of_transition):
         """Get contributions of Kohn-Sham singles to a given transition.
@@ -558,9 +575,12 @@ class LrtddftTransitions:
         f2 = np.zeros(neigs)
 
         if index_of_transition < 0:
-            raise RuntimeError('Error in get_transition_contributions: Index < zero.')
+            raise RuntimeError(
+                'Error in get_transition_contributions: Index < zero.')
         if index_of_transition >= neigs:
-            raise RuntimeError('Error in get_transition_contributions: Index >= number of transitions')
+            raise RuntimeError(
+                'Error in get_transition_contributions: Index >= number of transitions'
+            )
 
         k = index_of_transition
         # local k index
@@ -568,7 +588,7 @@ class LrtddftTransitions:
 
         if kloc is not None:
 
-            for (ip,kss_ip) in enumerate(self.ks_singles.kss_list):
+            for (ip, kss_ip) in enumerate(self.ks_singles.kss_list):
                 # local ip index
                 lip = self.lr_comms.get_local_eh_index(ip)
                 if lip is None:
@@ -577,9 +597,9 @@ class LrtddftTransitions:
                 # self.eigenvectors[iploc,kloc]
                 # is the "iploc"th local element of
                 # the "kloc"th local eigenvector
-                f2[ip] = self.eigenvectors[lip,kloc] * self.eigenvectors[lip,kloc] * kss_ip.pop_diff
+                f2[ip] = self.eigenvectors[lip, kloc] * self.eigenvectors[
+                    lip, kloc] * kss_ip.pop_diff
 
         self.lr_comms.parent_comm.sum(f2)
 
         return f2
-
