@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import functools
 from time import time, ctime
 from datetime import timedelta
@@ -11,6 +9,7 @@ import numpy as np
 from ase.units import Hartree, Bohr
 from ase.utils import devnull
 from ase.dft import monkhorst_pack
+from scipy.linalg import eigh
 
 from gpaw import GPAW
 from gpaw.kpt_descriptor import KPointDescriptor
@@ -258,8 +257,8 @@ class BSE:
         Ns = self.spins
         rhoex_KsmnG = np.zeros((nK, Ns, Nv, Nc, len(v_G)), complex)
         # rhoG0_Ksmn = np.zeros((nK, Ns, Nv, Nc), complex)
-        df_Ksmn = np.zeros((nK, Ns, Nv, Nc), float) # -(ev - ec)
-        deps_ksmn = np.zeros((myKsize, Ns, Nv, Nc), float) # -(fv - fc)
+        df_Ksmn = np.zeros((nK, Ns, Nv, Nc), float)  # -(ev - ec)
+        deps_ksmn = np.zeros((myKsize, Ns, Nv, Nc), float)  # -(fv - fc)
         if np.allclose(self.q_c, 0.0):
             optical_limit = True
         else:
@@ -356,7 +355,7 @@ class BSE:
                                               cf_s[s1])
                 rho1_mnG = rhoex_KsmnG[iK1, s1]
 
-                #rhoG0_Ksmn[iK1, s1] = rho1_mnG[:, :, 0]
+                # rhoG0_Ksmn[iK1, s1] = rho1_mnG[:, :, 0]
                 rho1ccV_mnG = rho1_mnG.conj()[:, :] * v_G
                 for s2 in range(Ns):
                     for Q_c in self.qd.bzk_kc:
@@ -385,8 +384,10 @@ class BSE:
                                 rho_1mnG = np.dot(vec1_nm.T.conj(),
                                                   np.dot(vec3_nm.T, rho3_mmG))
                                 rho3_mmG = rho_0mnG + rho_1mnG
-                                vec0_nm = v_knm[ikq_k[iK1]][::2][ni:nf, mci:mcf]
-                                vec1_nm = v_knm[ikq_k[iK1]][1::2][ni:nf,mci:mcf]
+                                vec0_nm = v_knm[ikq_k[iK1]][::2][ni:nf,
+                                                                 mci:mcf]
+                                vec1_nm = v_knm[ikq_k[iK1]][1::2][ni:nf,
+                                                                  mci:mcf]
                                 vec2_nm = v_knm[ikq][::2][ni:nf, mci:mcf]
                                 vec3_nm = v_knm[ikq][1::2][ni:nf, mci:mcf]
                                 rho_0mnG = np.dot(vec0_nm.T.conj(),
@@ -409,17 +410,17 @@ class BSE:
                        timedelta(seconds=round(dt)),
                        timedelta(seconds=round(tleft))), file=self.fd)
 
-        #if self.mode == 'BSE':
-        #    del self.Q_qaGii, self.W_qGG, self.pd_q
+        # if self.mode == 'BSE':
+        #     del self.Q_qaGii, self.W_qGG, self.pd_q
 
         H_ksmnKsmn /= self.vol
 
         mySsize = myKsize * Nv * Nc * Ns
         if myKsize > 0:
-            iS0 = myKrange[0] *  Nv * Nc * Ns
+            iS0 = myKrange[0] * Nv * Nc * Ns
 
-        #world.sum(rhoG0_Ksmn)
-        #self.rhoG0_S = np.reshape(rhoG0_Ksmn, -1)
+        # world.sum(rhoG0_Ksmn)
+        # self.rhoG0_S = np.reshape(rhoG0_Ksmn, -1)
         self.df_S = np.reshape(df_Ksmn, -1)
         if not self.td:
             self.excludef_S = np.where(np.abs(self.df_S) < 0.001)[0]
@@ -504,7 +505,7 @@ class BSE:
                 self.pd_q = data['pd']
                 print('Reading screened potential from % s' % self.wfile,
                       file=self.fd)
-            except:
+            except FileNotFoundError:
                 self.calculate_screened_potential(ac)
                 print('Saving screened potential to % s' % self.wfile,
                       file=self.fd)
@@ -677,16 +678,14 @@ class BSE:
         else:
             if world.size == 1:
                 print('  Using lapack...', file=self.fd)
-                from gpaw.utilities.lapack import diagonalize
-                self.w_T = np.zeros(self.nS)
-                diagonalize(self.H_sS, self.w_T)
-                self.v_St = self.H_sS.conj().T
+                self.w_T, self.v_St = eigh(self.H_sS)
             else:
                 print('  Using scalapack...', file=self.fd)
                 nS = self.nS
-                ns = -(-self.kd.nbzkpts // world.size) * (self.nv * self.nc *
-                                                          self.spins *
-                                                          (self.spinors + 1)**2)
+                ns = -(-self.kd.nbzkpts // world.size) * (
+                    self.nv * self.nc *
+                    self.spins *
+                    (self.spinors + 1)**2)
                 grid = BlacsGrid(world, world.size, 1)
                 desc = grid.new_descriptor(nS, nS, ns, nS)
 
@@ -739,7 +738,7 @@ class BSE:
     def get_vchi(self, w_w=None, eta=0.1, q_c=[0.0, 0.0, 0.0],
                  direction=0, ac=1.0, readfile=None, optical=True,
                  write_eig=None):
-        """Returns v * \chi where v is the bare Coulomb interaction"""
+        """Returns v * chi where v is the bare Coulomb interaction"""
 
         self.get_bse_matrix(q_c=q_c, direction=direction, ac=ac,
                             readfile=readfile, optical=optical,
@@ -908,7 +907,7 @@ class BSE:
                            q_c=[0.0, 0.0, 0.0], direction=0,
                            filename='pol_bse.csv', readfile=None, pbc=None,
                            write_eig='eig.dat'):
-        """Calculate the polarizability alpha.
+        r"""Calculate the polarizability alpha.
         In 3D the imaginary part of the polarizability is related to the
         dielectric function by Im(eps_M) = 4 pi * Im(alpha). In systems
         with reduced dimensionality the converged value of alpha is
@@ -959,7 +958,7 @@ class BSE:
                           q_c=[0.0, 0.0, 0.0], direction=0,
                           filename='abs_bse.csv', readfile=None, pbc=None,
                           write_eig='eig.dat'):
-        """Calculate the dimensionless absorption for 2d materials.
+        r"""Calculate the dimensionless absorption for 2d materials.
         It is essentially related to the 2D polarizability \alpha_2d as
 
               ABS = 4 * np.pi * \omega * \alpha_2d / c
@@ -1123,8 +1122,10 @@ class BSE:
             p('Valence bands                  :', self.val_sn[0])
             p('Conduction bands               :', self.con_sn[0])
         else:
-            p('Valence bands                  :', self.val_sn[0],self.val_sn[1])
-            p('Conduction bands               :', self.con_sn[0],self.con_sn[1])
+            p('Valence bands                  :', self.val_sn[0],
+              self.val_sn[1])
+            p('Conduction bands               :', self.con_sn[0],
+              self.con_sn[1])
         if eshift is not None:
             p('Scissors operator              :', eshift * Hartree, 'eV')
         p('Tamm-Dancoff approximation     :', td)
