@@ -1,4 +1,3 @@
-from __future__ import print_function, division
 import numbers
 from time import ctime
 
@@ -9,15 +8,14 @@ from ase.utils.timing import timer, Timer
 
 import gpaw.mpi as mpi
 from gpaw import extra_parameters
-from gpaw.blacs import (BlacsGrid, BlacsDescriptor, Redistributor,
-                        DryRunBlacsGrid)
+from gpaw.blacs import BlacsGrid, BlacsDescriptor, Redistributor
 from gpaw.kpt_descriptor import KPointDescriptor
 from gpaw.response.pair import PairDensity
 from gpaw.utilities.memory import maxrss
 from gpaw.utilities.blas import gemm
 from gpaw.wavefunctions.pw import PWDescriptor
 from gpaw.response.pair import PWSymmetryAnalyzer
-from gpaw.response.integrators import (PointIntegrator, TetrahedronIntegrator)
+from gpaw.response.integrators import PointIntegrator, TetrahedronIntegrator
 from gpaw.bztools import convex_hull_volume
 
 from functools import partial
@@ -127,10 +125,10 @@ class Chi0:
                  nblocks=1, gate_voltage=None,
                  disable_point_group=False, disable_time_reversal=False,
                  disable_non_symmorphic=True,
-                 scissor=None, integrationmode=None,
+                 integrationmode=None,
                  pbc=None, rate=0.0, eshift=0.0):
         """Construct Chi0 object.
-        
+
         Parameters
         ----------
         calc : str
@@ -189,8 +187,6 @@ class Chi0:
             Do not use time reversal symmetry.
         disable_non_symmorphic : bool
             Do no use non symmorphic symmetry operators.
-        scissor : tuple ([bands], shift [eV])
-            Use scissor operator on bands.
         integrationmode : str
             Integrator for the kpoint integration.
             If == 'tetrahedron integration' then the kpoint integral is
@@ -199,6 +195,13 @@ class Chi0:
             Periodic directions of the system. Defaults to [True, True, True].
         eshift : float
             Shift unoccupied bands
+        rate : float,str
+            Phenomenological scattering rate to use in optical limit Drude term
+            (in eV). If rate='eta', then use input artificial broadening eta as
+            rate. Note, for consistency with the formalism the rate is
+            implemented as omegap^2 / (omega + 1j * rate)^2 which differ from
+            some literature by a factor of 2.
+            
 
         Attributes
         ----------
@@ -206,9 +209,9 @@ class Chi0:
             Class for calculating matrix elements of pairs of wavefunctions.
 
         """
-        
+
         self.response = response
-        
+
         self.timer = timer or Timer()
 
         self.pair = PairDensity(calc, ecut, self.response,
@@ -249,18 +252,12 @@ class Chi0:
 
         self.nblocks = nblocks
 
-        if world.rank != 0:
-            txt = devnull
-        elif isinstance(txt, str):
-            txt = open(txt, 'w')
-        self.fd = txt
-
         if ecut is not None:
             ecut /= Hartree
 
         self.ecut = ecut
         self.gammacentered = gammacentered
-        
+
         self.eta = eta / Hartree
         if rate == 'eta':
             self.rate = self.eta
@@ -273,7 +270,7 @@ class Chi0:
         self.include_intraband = intraband
 
         omax = self.find_maximum_frequency()
-        
+
         if frequencies is None:
             if self.omegamax is None:
                 self.omegamax = omax
@@ -315,7 +312,7 @@ class Chi0:
                   file=self.fd)
         else:
             print('Using integration method: PointIntegrator', file=self.fd)
-    
+
     def find_maximum_frequency(self):
         """Determine the maximum electron-hole pair transition energy."""
         self.epsmin = 10000.0
@@ -341,7 +338,7 @@ class Chi0:
         spin : str or int
             If 'all' then include all spins.
             If 0 or 1, only include this specific spin.
-            (not used in transverse reponse functions)
+            (not used in transverse response functions)
         A_x : ndarray
             Output array. If None, the output array is created.
 
@@ -398,7 +395,7 @@ class Chi0:
             chi0_wGG[:] = 0.0
         else:
             chi0_wGG = np.zeros((nw, self.Gb - self.Ga, nG), complex)
-            
+
         if optical_limit:
             chi0_wxvG = np.zeros((len(self.omega_w), 2, 3, nG), complex)
             chi0_wvv = np.zeros((len(self.omega_w), 3, 3), complex)
@@ -408,13 +405,12 @@ class Chi0:
             chi0_wvv = None
             self.plasmafreq_vv = None
 
-        if self.response == 'density':
-            # Do all empty bands:
-            m1 = self.nocc1
-        else:
+        if self.response in ['+-', '-+']:
             # Do all bands
             m1 = 0
-        
+        else:
+            # Do all empty bands:
+            m1 = self.nocc1
         m2 = self.nbands
 
         pd, chi0_wGG, chi0_wxvG, chi0_wvv = self._calculate(pd,
@@ -422,14 +418,14 @@ class Chi0:
                                                             chi0_wxvG,
                                                             chi0_wvv,
                                                             m1, m2, spins)
-        
+
         return pd, chi0_wGG, chi0_wxvG, chi0_wvv
 
     @timer('Calculate CHI_0')
     def _calculate(self, pd, chi0_wGG, chi0_wxvG, chi0_wvv, m1, m2, spins,
                    extend_head=True):
         """In-place calculation of the response function.
-        
+
         Parameters
         ----------
         q_c : list or ndarray
@@ -448,8 +444,7 @@ class Chi0:
             Upper band cutoff for band summation
         spins : str or list(ints)
             If 'all' then include all spins.
-            If [0] or [1], only include this specific spin (and flip it,
-            if calculating the transverse magnetic response).
+            If [0] or [1], only include this specific spin.
         extend_head : bool
             If True: Extend the wings and head of chi in the optical limit to
             take into account the non-analytic nature of chi. Effectively
@@ -458,15 +453,11 @@ class Chi0:
             for parts of the code that do not support this feature i.e., GW
             RPA total energy and RALDA.
         """
-        
+
         # Parse spins
         wfs = self.calc.wfs
         if spins == 'all':
             spins = range(wfs.nspins)
-        elif spins == 'pm':
-            spins = [0]
-        elif spins == 'mp':
-            spins = [1]
         else:
             for spin in spins:
                 assert spin in range(wfs.nspins)
@@ -475,6 +466,12 @@ class Chi0:
         optical_limit = np.allclose(pd.kd.bzk_kc[0], 0.0) and \
             self.response == 'density'
 
+        # Use wings in optical limit, if head cannot be extended
+        if optical_limit and not extend_head:
+            wings = True
+        else:
+            wings = False
+        
         # Reset PAW correction in case momentum has change
         self.Q_aGii = self.pair.initialize_paw_corrections(pd)
         A_wxx = chi0_wGG  # Change notation
@@ -537,7 +534,7 @@ class Chi0:
 
         prefactor = (2 * factor * PWSA.how_many_symmetries() /
                      (wfs.nspins * (2 * np.pi)**3))  # Remember prefactor
-        
+
         if self.integrationmode is None:
             if self.calc.wfs.kd.refine_info is not None:
                 nbzkpts = self.calc.wfs.kd.refine_info.mhnbzkpts
@@ -545,24 +542,21 @@ class Chi0:
                 nbzkpts = self.calc.wfs.kd.nbzkpts
             prefactor *= len(bzk_kv) / nbzkpts
 
+        A_wxx /= prefactor
+        if wings:
+            chi0_wxvG /= prefactor
+            chi0_wvv /= prefactor
+        
         # The functions that are integrated are defined in the bottom
         # of this file and take a number of constant keyword arguments
         # which the integrator class accepts through the use of the
         # kwargs keyword.
         kd = self.calc.wfs.kd
-        mat_kwargs = {'kd': kd, 'pd': pd, 'n1': 0,
-                      'm1': m1, 'm2': m2,
+        mat_kwargs = {'kd': kd, 'pd': pd,
                       'symmetry': PWSA,
                       'integrationmode': self.integrationmode}
-        eig_kwargs = {'kd': kd, 'm1': m1, 'm2': m2,
-                      'n1': 0, 'pd': pd}
-        if self.response == 'density':
-            mat_kwargs['n2'] = self.nocc2
-            eig_kwargs['n2'] = self.nocc2
-        else:
-            mat_kwargs['n2'] = self.nbands
-            eig_kwargs['n2'] = self.nbands
-        
+        eig_kwargs = {'kd': kd, 'pd': pd}
+
         if not extend_head:
             mat_kwargs['extend_head'] = False
 
@@ -589,18 +583,18 @@ class Chi0:
             extraargs['eta'] = self.eta
             extraargs['timeordered'] = self.timeordered
 
-        if optical_limit and not extend_head:
-            wings = True
-        else:
-            wings = False
-
-        A_wxx /= prefactor
-        if wings:
-            chi0_wxvG /= prefactor
-            chi0_wvv /= prefactor
-        
         # Integrate response function
         print('Integrating response function.', file=self.fd)
+        # Define band summation
+        if self.response == 'density':
+            bandsum = {'n1': 0, 'n2': self.nocc2, 'm1': m1, 'm2': m2}
+            mat_kwargs.update(bandsum)
+            eig_kwargs.update(bandsum)
+        else:
+            bandsum = {'n1': 0, 'n2': self.nbands, 'm1': m1, 'm2': m2}
+            mat_kwargs.update(bandsum)
+            eig_kwargs.update(bandsum)
+
         integrator.integrate(kind=kind,  # Kind of integral
                              domain=domain,  # Integration domain
                              integrand=(self.get_matrix_element,  # Integrand
@@ -724,7 +718,7 @@ class Chi0:
         # calculated above is normalized by the number of symmetries (as seen
         # below) and then symmetrized.
         A_wxx *= prefactor
-        
+
         tmpA_wxx = self.redistribute(A_wxx)
         if extend_head:
             PWSA.symmetrize_wxx(tmpA_wxx,
@@ -838,9 +832,9 @@ class Chi0:
 
         where s and s' are spins, n and m are band indices, k is
         the kpoint and q is the momentum transfer. For dielectric
-        reponse s'=s, for the transverse magnetic reponse
+        response s'=s, for the transverse magnetic response
         s' is flipped with respect to s.
-        
+
         Parameters
         ----------
         k_v : ndarray
@@ -902,10 +896,10 @@ class Chi0:
 
         n_nmG = self.pair.get_pair_density(pd, kptpair, n_n, m_m,
                                            Q_aGii=self.Q_aGii, block=block)
-        
+
         if integrationmode is None:
             n_nmG *= weight
-        
+
         df_nm = kptpair.get_occupation_differences(n_n, m_m)
         if not self.response == 'density':
             df_nm = np.abs(df_nm)
@@ -917,7 +911,7 @@ class Chi0:
             nq_nm = np.dot(n_nmG[:, :, :3], q_v)
             n_nmG = n_nmG[:, :, 2:]
             n_nmG[:, :, 0] = nq_nm
-        
+
         if not extend_head and optical_limit:
             n_nmG = np.copy(n_nmG[:, :, 2:])
             optical_limit = False
@@ -1078,7 +1072,8 @@ class Chi0:
             bg1 = BlacsGrid(comm, 1, comm.size)
             in_wGG = chi0_wGG.reshape((nw, -1))
         else:
-            bg1 = DryRunBlacsGrid(mpi.serial_comm, 1, 1)
+            bg1 = BlacsGrid(None, 1, 1)
+            # bg1 = DryRunBlacsGrid(mpi.serial_comm, 1, 1)
             in_wGG = np.zeros((0, 0), complex)
         md1 = BlacsDescriptor(bg1, nw, nG**2, nw, mynG * nG)
 
@@ -1091,15 +1086,16 @@ class Chi0:
         r.redistribute(in_wGG, out_wGG.reshape((wb - wa, nG**2)))
 
         return out_wGG
-    
+
     def print_chi(self, pd):
         calc = self.calc
         gd = calc.wfs.gd
 
         if extra_parameters.get('df_dry_run'):
-            from gpaw.mpi import DryRunCommunicator
+            from gpaw.mpi import SerialCommunicator
             size = extra_parameters['df_dry_run']
-            world = DryRunCommunicator(size)
+            world = SerialCommunicator()
+            world.size = size
         else:
             world = self.world
 
