@@ -1,5 +1,3 @@
-from __future__ import division, print_function
-
 import functools
 import itertools
 import os
@@ -1210,8 +1208,7 @@ class G0W0(PairDensity):
             vxc_skn = vxc(self.calc, self.calc.hamiltonian.xc) / Ha
             n1, n2 = self.bands
             self.vxc_skn = vxc_skn[:, self.kpts, n1:n2]
-            if fd is not devnull:
-                np.save(fd, self.vxc_skn)
+            np.save(fd, self.vxc_skn)
 
     @timer('EXX')
     def calculate_exact_exchange(self):
@@ -1223,8 +1220,7 @@ class G0W0(PairDensity):
                       txt=self.filename + '.exx.txt', timer=self.timer)
             exx.calculate()
             self.exx_skn = exx.get_eigenvalue_contributions() / Ha
-            if fd is not devnull:
-                np.save(fd, self.exx_skn)
+            np.save(fd, self.exx_skn)
 
     def read_contribution(self, filename):
         fd = opencew(filename)  # create, exclusive, write
