@@ -4,10 +4,9 @@ from __future__ import print_function
 import hashlib
 import os
 import re
-import sys
 import xml.sax
 from glob import glob
-from math import sqrt, pi, factorial as fac
+from math import sqrt, pi
 from distutils.version import LooseVersion
 
 import numpy as np
@@ -15,10 +14,11 @@ from ase.data import atomic_names
 from ase.units import Bohr, Hartree
 
 from gpaw import setup_paths, extra_parameters
-from gpaw.spline import Spline
 from gpaw.xc.pawcorrection import PAWXCCorrection
 from gpaw.mpi import broadcast
-from gpaw.atom.radialgd import AERadialGridDescriptor
+from gpaw.atom.radialgd import (AERadialGridDescriptor,
+                                AbinitRadialGridDescriptor)
+from gpaw.atom.shapefunc import shape_functions
 
 try:
     import gzip
@@ -61,7 +61,9 @@ class SetupData:
         self.e_kin_jj = None  # <phi | T | phi> - <phit | T | phit>
 
         self.rgd = None
-        self.rcgauss = None  # For compensation charge expansion functions
+
+        # Parameters for compensation charge expansion functions:
+        self.shape_function = {'type': 'undefined', 'rc': np.nan}
 
         # State identifier, like "X-2s" or "X-p1", where X is chemical symbol,
         # for bound and unbound states
@@ -160,13 +162,13 @@ class SetupData:
             text('  Hubbard U: %f eV (l=%d, scale=%s)' %
                  (setup.HubU * Hartree, setup.Hubl, bool(setup.Hubs)))
         text('  file:', self.filename)
-        text(('  cutoffs: %4.2f(comp), %4.2f(filt), %4.2f(core),'
-              ' lmax=%d' % (sqrt(10) * self.rcgauss * Bohr,
-                            # XXX is this really true?  I don't think this is
-                            # actually the cutoff of the compensation charges
-                            setup.rcutfilter * Bohr,
-                            setup.rcore * Bohr,
-                            setup.lmax)))
+        text('  compensation charges: {}, rc={:.2f}, lmax={}'
+             .format(self.shape_function['type'],
+                     self.shape_function['rc'] * Bohr,
+                     setup.lmax))
+        text(('  cutoffs: {:.2f}(filt), {:.2f}(core),'
+              .format(setup.rcutfilter * Bohr,
+                      setup.rcore * Bohr)))
         text('  valence states:')
         text('                energy  radius')
         j = 0
@@ -182,16 +184,8 @@ class SetupData:
         text()
 
     def create_compensation_charge_functions(self, lmax):
-        """Create Gaussians used to expand compensation charges."""
-        rcgauss = self.rcgauss
-        g_lg = self.rgd.zeros(lmax + 1)
-        r_g = self.rgd.r_g
-        g_lg[0] = 4 / rcgauss**3 / sqrt(pi) * np.exp(-(r_g / rcgauss)**2)
-        for l in range(1, lmax + 1):
-            g_lg[l] = 2.0 / (2 * l + 1) / rcgauss**2 * r_g * g_lg[l - 1]
-
-        for l in range(lmax + 1):
-            g_lg[l] /= self.rgd.integrate(g_lg[l], l) / (4 * pi)
+        """Create shape functions used to expand compensation charges."""
+        g_lg = shape_functions(self.rgd, **self.shape_function, lmax=lmax)
         return g_lg
 
     def get_smooth_core_density_integral(self, Delta0):
@@ -210,15 +204,6 @@ class SetupData:
         K_p = sqrt(4 * pi) * np.dot(K_q, T0_qp)
         return K_p
 
-    def get_ghat(self, lmax, alpha, r, rcut):
-        d_l = [fac(l) * 2**(2 * l + 2) / sqrt(pi) / fac(2 * l + 1)
-               for l in range(lmax + 1)]
-        g = alpha**1.5 * np.exp(-alpha * r**2)
-        g[-1] = 0.0
-        ghat_l = [Spline(l, rcut, d_l[l] * alpha**l * g)
-                  for l in range(lmax + 1)]
-        return ghat_l
-
     def find_core_density_cutoff(self, nc_g):
         if self.Nc == 0:
             return 1.0
@@ -247,8 +232,8 @@ class SetupData:
             self.e_xc,
             phicorehole_g,
             self.fcorehole,
-            self.tauc_g[:gcut2].copy(),
-            self.tauct_g[:gcut2].copy())
+            None if self.tauc_g is None else self.tauc_g[:gcut2].copy(),
+            None if self.tauct_g is None else self.tauct_g[:gcut2].copy())
 
         return xc_correction
 
@@ -257,7 +242,9 @@ class SetupData:
         xml = open(self.stdfilename, 'w')
 
         print('<?xml version="1.0"?>', file=xml)
-        print('<paw_setup version="0.6">', file=xml)
+        print('<paw_dataset version="{version}">'
+              .format(version=self.version),
+              file=xml)
         name = atomic_names[self.Z].title()
         comment1 = name + ' setup for the Projector Augmented Wave method.'
         comment2 = 'Units: Hartree and Bohr radii.'
@@ -303,8 +290,8 @@ class SetupData:
 
         print(self.rgd.xml('g1'), file=xml)
 
-        print(('  <shape_function type="gauss" rc="%r"/>' %
-               self.rcgauss), file=xml)
+        print('  <shape_function type="{type}" rc="{rc}"/>'
+              .format(**self.shape_function), file=xml)
 
         if self.r0 is None:
             # Old setups:
@@ -382,7 +369,7 @@ class SetupData:
                 print('%r' % x, end=' ', file=xml)
             print('\n  </yukawa_exchange_X_matrix>', file=xml)
             print('  <yukawa_exchange gamma="%r"/>' % self.X_gamma, file=xml)
-        print('</paw_setup>', file=xml)
+        print('</paw_dataset>', file=xml)
 
     def build(self, xcfunc, lmax, basis, filter=None):
         from gpaw.setup import Setup
@@ -464,17 +451,18 @@ class PAWXMLParser(xml.sax.handler.ContentHandler):
             setup.e_xc = 0.0
 
     def startElement(self, name, attrs):
-        if sys.version_info[0] < 3:
-            attrs.__contains__ = attrs.has_key
-
         setup = self.setup
-        if name == 'paw_setup':
+        if name == 'paw_setup' or name == 'paw_dataset':
             setup.version = attrs['version']
             assert LooseVersion(setup.version) >= '0.4'
         if name == 'atom':
-            setup.Z = int(attrs['Z'])
+            Z = float(attrs['Z'])
+            setup.Z = int(Z)
+            assert setup.Z == Z
             setup.Nc = float(attrs['core'])
-            setup.Nv = int(attrs['valence'])
+            Nv = float(attrs['valence'])
+            setup.Nv = int(Nv)
+            assert setup.Nv == Nv
         elif name == 'xc_functional':
             if attrs['type'] == 'LDA':
                 setup.xcname = 'LDA'
@@ -511,15 +499,19 @@ class PAWXMLParser(xml.sax.handler.ContentHandler):
                 b = float(attrs['b'])
                 N = int(attrs['n'])
                 setup.rgd = AERadialGridDescriptor(a, b, N)
+            elif attrs['eq'] == 'r=a*(exp(d*i)-1)':
+                a = float(attrs['a'])
+                d = float(attrs['d'])
+                istart = int(attrs['istart'])
+                iend = int(attrs['iend'])
+                assert istart == 0
+                setup.rgd = AbinitRadialGridDescriptor(a, d, iend + 1)
             else:
                 raise ValueError('Unknown grid:' + attrs['eq'])
         elif name == 'shape_function':
-            if 'rc' in attrs:
-                assert attrs['type'] == 'gauss'
-                setup.rcgauss = float(attrs['rc'])
-            else:
-                # Old style: XXX
-                setup.rcgauss = max(setup.rcut_j) / sqrt(float(attrs['alpha']))
+            assert attrs['type'] in {'gauss', 'sinc', 'bessel'}
+            setup.shape_function = {'type': attrs['type'],
+                                    'rc': float(attrs['rc'])}
         elif name in ['ae_core_density', 'pseudo_core_density',
                       'localized_potential', 'yukawa_exchange_X_matrix',
                       'kinetic_energy_differences', 'exact_exchange_X_matrix',
