@@ -22,7 +22,8 @@ calc_b = GPAW(h = 0.2,
               nbands = 4,
               mixer = Mixer(beta=0.25, nmaxold=3, weight=100.0),
               txt='He2+_final_%3.2f.txt' % distance,
-              convergence={'eigenstates':1.0e-4,'density':1.0e-1, 'energy':1e-1,'bands':4})
+              convergence={'eigenstates':1.0e-4,'density':1.0e-1,
+                           'energy':1e-1,'bands':4})
 
 
 cdft_b = CDFT(calc = calc_b,
