@@ -1,4 +1,3 @@
-from __future__ import print_function
 from ase import Atom, Atoms
 from gpaw import GPAW
 from gpaw.test import equal
@@ -7,11 +6,11 @@ a = 4.05
 d = a / 2**0.5
 bulk = Atoms([Atom('Al', (0, 0, 0)),
               Atom('Al', (0, 0, d))],
-             cell=(4*d, 4*d, 2*d),
+             cell=(4 * d, 4 * d, 2 * d),
              pbc=1)
 n = 16
-calc = GPAW(gpts=(2*n, 2*n, 1*n),
-            nbands=1*8,
+calc = GPAW(gpts=(2 * n, 2 * n, 1 * n),
+            nbands=1 * 8,
             kpts=(1, 1, 4),
             convergence={'eigenstates': 2.3e-9},
             xc='LDA')
@@ -21,7 +20,9 @@ niter2 = calc.get_number_of_iterations()
 
 bulk = bulk.repeat((1, 1, 2))
 bulk.set_calculator(calc)
-calc.set(nbands=16, kpts=(1, 1, 2), gpts=(2*n, 2*n, 2*n))
+calc.set(nbands=16,
+         kpts=(1, 1, 2),
+         gpts=(2 * n, 2 * n, 2 * n))
 e4 = bulk.get_potential_energy()
 niter4 = calc.get_number_of_iterations()
 
