@@ -10,7 +10,10 @@ mol = Atoms('OHH',
              (b, 0.7633 + b, -0.4876 + b),
              (b, -0.7633 + b, -0.4876 + b)],
             pbc=False, cell=[a, a, a])
-calc = GPAW(gpts=(32, 32, 32), nbands=4, mode='lcao', poissonsolver=FDPoissonSolver())
+calc = GPAW(gpts=(32, 32, 32),
+            nbands=4,
+            mode='lcao',
+            poissonsolver=FDPoissonSolver())
 mol.set_calculator(calc)
 e = mol.get_potential_energy()
 niter = calc.get_number_of_iterations()
@@ -19,7 +22,10 @@ equal(e, -10.271, 2e-3)
 equal(niter, 8, 1)
 
 # Check that complex wave functions are allowed with gamma point calculations
-calc = GPAW(gpts=(32, 32, 32), nbands=4, mode=LCAO(force_complex_dtype=True), poissonsolver=FDPoissonSolver())
+calc = GPAW(gpts=(32, 32, 32),
+            nbands=4,
+            mode=LCAO(force_complex_dtype=True),
+            poissonsolver=FDPoissonSolver())
 mol.set_calculator(calc)
 ec = mol.get_potential_energy()
 equal(e, ec, 1e-5)
