@@ -36,21 +36,21 @@ if 0:
     from gpaw.test import print_reference
     print_reference(data, 'ref', '%.12le')
 
-ref = [4.786589735249e-15,
-       6.509942495725e-15,
-       3.836848815869e-14,
-       4.429061708370e-15,
-       7.320865686028e-15,
-       2.877243538173e-14,
-       1.960742479669e-05,
-       1.960742479842e-05,
-       1.804029540200e-05,
-       3.761996854449e-05,
-       3.761996854564e-05,
-       3.596679132063e-05,
-       5.257366852049e-05,
-       5.257366852232e-05,
-       5.366659968830e-05]
+ref = [-9.383700894739e-16,
+       -9.338586948130e-16,
+       2.131582675483e-14,
+       8.679923327633e-15,
+       7.529517689096e-15,
+       2.074867751820e-14,
+       1.960742702185e-05,
+       1.960742702128e-05,
+       1.804030746475e-05,
+       3.761997205571e-05,
+       3.761997205562e-05,
+       3.596681520068e-05,
+       5.257367158160e-05,
+       5.257367158104e-05,
+       5.366663490365e-05]
 
-tol = 1e-12
+tol = 1e-9
 equal(data, ref, tol)
