@@ -38,23 +38,23 @@ if 0:
     from gpaw.test import print_reference
     print_reference(data_i, 'ref_i', '%.12le')
 
-ref_i = [4.786589735249e-15,
-         6.509942495725e-15,
-         3.836848815869e-14,
-         4.429061708370e-15,
-         7.320865686028e-15,
-         2.877243538173e-14,
-         1.967175332445e-05,
-         1.967175332505e-05,
-         1.805003047148e-05,
-         3.799528613595e-05,
-         3.799528613766e-05,
-         3.602504333467e-05,
-         5.371491630029e-05,
-         5.371491629857e-05,
-         5.385043148270e-05]
+ref_i = [-9.383700894739e-16,
+         -9.338586948130e-16,
+         2.131582675483e-14,
+         8.679923327633e-15,
+         7.529517689096e-15,
+         2.074867751820e-14,
+         1.967175558125e-05,
+         1.967175557952e-05,
+         1.805004256446e-05,
+         3.799528978877e-05,
+         3.799528978943e-05,
+         3.602506734201e-05,
+         5.371491974467e-05,
+         5.371491974534e-05,
+         5.385046706407e-05]
 
-tol = 1e-12
+tol = 1e-10
 equal(data_i, ref_i, tol)
 
 # Test spectrum
@@ -68,29 +68,29 @@ ref_i = [0.000000000000e+00,
          0.000000000000e+00,
          0.000000000000e+00,
          5.000000000000e+00,
-         4.500226506100e-03,
-         4.500226505900e-03,
-         4.408376617800e-03,
+         4.500226856200e-03,
+         4.500226856200e-03,
+         4.408379542600e-03,
          1.000000000000e+01,
-         1.659425994100e-02,
-         1.659425994100e-02,
-         1.623811179300e-02,
+         1.659426124300e-02,
+         1.659426124300e-02,
+         1.623812256800e-02,
          1.500000000000e+01,
-         3.244686580500e-02,
-         3.244686580400e-02,
-         3.168680387500e-02,
+         3.244686838800e-02,
+         3.244686838800e-02,
+         3.168682490900e-02,
          2.000000000000e+01,
-         4.684883362500e-02,
-         4.684883362300e-02,
-         4.559686832900e-02,
+         4.684883744600e-02,
+         4.684883744600e-02,
+         4.559689861200e-02,
          2.500000000000e+01,
-         5.466780758300e-02,
-         5.466780758100e-02,
-         5.290167692700e-02,
+         5.466781222200e-02,
+         5.466781222200e-02,
+         5.290171209500e-02,
          3.000000000000e+01,
-         5.231585754700e-02,
-         5.231585754600e-02,
-         5.008658428800e-02]
+         5.231586230700e-02,
+         5.231586230700e-02,
+         5.008661764300e-02]
 
-tol = 1e-9
+tol = 1e-7
 equal(data_i, ref_i, tol)
