@@ -1,7 +1,8 @@
 from __future__ import print_function
 import numpy as np
 from ase.units import Hartree
-from gpaw.occupations import FermiDirac, MethfesselPaxton
+from gpaw.occupations import (FermiDirac, MethfesselPaxton,
+                              MarzariVanderbilt, occupation_numbers)
 
 
 class KPoint:
@@ -9,7 +10,8 @@ class KPoint:
     f_n = np.empty(1)
     weight = 0.2
     s = 0
-    
+
+
 k = KPoint()
 
 
@@ -18,7 +20,7 @@ def f(occ, x):
     n, dnde, x, S = occ.distribution(k, 0.0)
     return n, dnde, S
 
-    
+
 def test(occ):
     print(occ)
     for e in [-0.3 / Hartree, 0, 0.1 / Hartree, 1.2 / Hartree]:
@@ -27,13 +29,26 @@ def test(occ):
         np, dp, Sp = f(occ, e + x)
         nm, dm, Sm = f(occ, e - x)
         d = -(np - nm) / (2 * x)
-        dS = Sp - Sm
+        dS = Sm - Sp
         dn = np - nm
         print(d - d0, dS - e * dn)
         assert abs(d - d0) < 3e-5
         assert abs(dS - e * dn) < 1e-13
 
+
 for w in [0.1, 0.5]:
     test(FermiDirac(w))
     for n in range(4):
         test(MethfesselPaxton(w, n))
+    test(MarzariVanderbilt(w))
+
+
+occ = {'name': 'fermi-dirac', 'width': 0.1}
+
+for eps_skn, weight_k, n in [
+    ([[[0.0, 1.0]]], [1.0], 2),
+    ([[[0.0, 1.0]], [[0.0, 2.0]]], [1.0], 3),
+    ([[[0.0, 1.0, 2.0], [0.0, 2.0, 2.0]]], [0.5, 0.5], 2)]:
+    f_skn, fl, m, s = occupation_numbers(occ, eps_skn, weight_k, n)
+    print(f_skn, fl, m, s)
+    assert abs(f_skn.sum() - n) < 1e-14, f_skn
