@@ -1,4 +1,4 @@
-
+# flake8: noqa
 import sys
 import numpy as np
 
@@ -17,7 +17,7 @@ from gpaw.xc import XC
 from gpaw.setup import SetupData, Setups
 from gpaw.wavefunctions.base import WaveFunctions
 from gpaw.wavefunctions.fd import FDWaveFunctions
-from gpaw.fd_operators import Laplace # required but not really used
+from gpaw.fd_operators import Laplace  # required but not really used
 from gpaw.pair_overlap import GridPairOverlap, ProjectorPairOverlap
 
 from gpaw.test.ut_common import shapeopt, TestCase, \
@@ -26,11 +26,11 @@ from gpaw.test.ut_common import shapeopt, TestCase, \
 
 mpl = None
 
-
 p = InputParameters(spinpol=False)
 xc = XC(p.xc)
 p.setups = dict([(symbol, SetupData(symbol, xc.name)) for symbol in 'HO'])
 
+
 class UTDomainParallelSetup(TestCase):
     """
     Setup a simple domain parallel calculation."""
@@ -51,12 +51,14 @@ class UTDomainParallelSetup(TestCase):
 
     def setUp(self):
         for virtvar in ['boundaries']:
-            assert getattr(self,virtvar) is not None, 'Virtual "%s"!' % virtvar
+            assert getattr(self,
+                           virtvar) is not None, 'Virtual "%s"!' % virtvar
 
-        parsize_domain, parsize_bands = create_parsize_minbands(self.nbands, world.size)
+        parsize_domain, parsize_bands = create_parsize_minbands(
+            self.nbands, world.size)
         assert self.nbands % np.prod(parsize_bands) == 0
-        comms = distribute_cpus(parsize_domain,
-                                parsize_bands, self.nspins, self.nibzkpts)
+        comms = distribute_cpus(parsize_domain, parsize_bands, self.nspins,
+                                self.nibzkpts)
         domain_comm, kpt_comm, band_comm, block_comm = \
             [comms[name] for name in 'dkbK']
 
@@ -71,7 +73,8 @@ class UTDomainParallelSetup(TestCase):
         pbc_c = {'zero'    : False, \
                  'periodic': True, \
                  'mixed'   : (True, False, True)}[self.boundaries]
-        self.gd = GridDescriptor(ngpts, cell_c, pbc_c, domain_comm, parsize_domain)
+        self.gd = GridDescriptor(ngpts, cell_c, pbc_c, domain_comm,
+                                 parsize_domain)
 
         # What to do about kpoints?
         self.kpt_comm = kpt_comm
@@ -86,35 +89,38 @@ class UTDomainParallelSetup(TestCase):
             return
         comm_sizes = tuple([comm.size for comm in [world, self.bd.comm, \
                                                    self.gd.comm, self.kpt_comm]])
-        self._parinfo =  '%d world, %d band, %d domain, %d kpt' % comm_sizes
+        self._parinfo = '%d world, %d band, %d domain, %d kpt' % comm_sizes
         self.assertEqual(self.nbands % self.bd.comm.size, 0)
-        self.assertEqual((self.nspins*self.nibzkpts) % self.kpt_comm.size, 0)
+        self.assertEqual((self.nspins * self.nibzkpts) % self.kpt_comm.size, 0)
 
 
 class UTDomainParallelSetup_Zero(UTDomainParallelSetup):
     __doc__ = UTDomainParallelSetup.__doc__
     boundaries = 'zero'
 
+
 class UTDomainParallelSetup_Periodic(UTDomainParallelSetup):
     __doc__ = UTDomainParallelSetup.__doc__
     boundaries = 'periodic'
 
+
 class UTDomainParallelSetup_Mixed(UTDomainParallelSetup):
     __doc__ = UTDomainParallelSetup.__doc__
     boundaries = 'mixed'
 
+
 # -------------------------------------------------------------------
 
 # Helper functions/classes here
 
-class FDWFS(FDWaveFunctions):
 
-    def __init__(self, gd, bd, kd, setups, block_comm, dtype): # override constructor
+class FDWFS(FDWaveFunctions):
+    def __init__(self, gd, bd, kd, setups, block_comm,
+                 dtype):  # override constructor
 
         assert kd.comm.size == 1
 
-        WaveFunctions.__init__(self, gd, 1, setups, bd, dtype, world,
-                               kd, None)
+        WaveFunctions.__init__(self, gd, 1, setups, bd, dtype, world, kd, None)
         self.kin = Laplace(gd, -0.5, dtype=dtype)
         self.diagksl = None
         self.orthoksl = BandLayouts(gd, bd, block_comm, dtype)
@@ -122,7 +128,7 @@ class FDWFS(FDWaveFunctions):
         self.overlap = None
         self.rank_a = None
 
-    def allocate_arrays_for_projections(self, my_atom_indices): # no alloc
+    def allocate_arrays_for_projections(self, my_atom_indices):  # no alloc
         pass
 
     def collect_projections(self, P_ani):
@@ -140,8 +146,10 @@ class FDWFS(FDWaveFunctions):
         self.world.broadcast(P_In, 0)
         return P_In
 
+
 # -------------------------------------------------------------------
 
+
 class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
     __doc__ = UTDomainParallelSetup.__doc__ + """
     The pseudo wavefunctions are moving gaussians centered around each atom."""
@@ -150,35 +158,35 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
     dtype = None
 
     # Default arguments for scaled Gaussian wave
-    _sigma0 = 2.0 #0.75
-    _k0_c = 2*np.pi*np.array([1/5., 1/3., 0.])
+    _sigma0 = 2.0  #0.75
+    _k0_c = 2 * np.pi * np.array([1 / 5., 1 / 3., 0.])
 
     def setUp(self):
         UTDomainParallelSetup.setUp(self)
 
         for virtvar in ['dtype']:
-            assert getattr(self,virtvar) is not None, 'Virtual "%s"!' % virtvar
+            assert getattr(self,
+                           virtvar) is not None, 'Virtual "%s"!' % virtvar
 
         # Create randomized atoms
-        self.atoms = create_random_atoms(self.gd, 5) # also tested: 10xNH3/BDA
+        self.atoms = create_random_atoms(self.gd, 5)  # also tested: 10xNH3/BDA
 
         # XXX DEBUG START
         if False:
             from ase import view
-            view(self.atoms*(1+2*self.gd.pbc_c))
+            view(self.atoms * (1 + 2 * self.gd.pbc_c))
         # XXX DEBUG END
 
         # Do we agree on the atomic positions?
         pos_ac = self.atoms.get_positions()
-        pos_rac = np.empty((world.size,)+pos_ac.shape, pos_ac.dtype)
+        pos_rac = np.empty((world.size, ) + pos_ac.shape, pos_ac.dtype)
         world.all_gather(pos_ac, pos_rac)
-        if (pos_rac-pos_rac[world.rank,...][np.newaxis,...]).any():
+        if (pos_rac - pos_rac[world.rank, ...][np.newaxis, ...]).any():
             raise RuntimeError('Discrepancy in atomic positions detected.')
 
         # Create setups for atoms
         self.Z_a = self.atoms.get_atomic_numbers()
-        self.setups = Setups(self.Z_a, p.setups, p.basis,
-                             p.lmax, xc)
+        self.setups = Setups(self.Z_a, p.setups, p.basis, p.lmax, xc)
 
         # K-point descriptor
         bzk_kc = np.array([[0, 0, 0]], dtype=float)
@@ -192,7 +200,7 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
 
         spos_ac = self.atoms.get_scaled_positions() % 1.0
         self.wfs.set_positions(spos_ac)
-        self.pt = self.wfs.pt # XXX shortcut
+        self.pt = self.wfs.pt  # XXX shortcut
 
         ## Also create pseudo partial waveves
         #from gpaw.lfc import LFC
@@ -215,24 +223,27 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
     def allocate(self):
         self.r_cG = self.gd.get_grid_point_coordinates()
         cell_cv = self.atoms.get_cell() / Bohr
-        assert np.abs(cell_cv-self.gd.cell_cv).max() < 1e-9
-        center_c = 0.5*cell_cv.diagonal()
+        assert np.abs(cell_cv - self.gd.cell_cv).max() < 1e-9
+        center_c = 0.5 * cell_cv.diagonal()
 
         self.buf_G = self.gd.empty(dtype=self.dtype)
         self.psit_nG = self.gd.empty(self.bd.mynbands, dtype=self.dtype)
 
-        for myn,psit_G in enumerate(self.psit_nG):
+        for myn, psit_G in enumerate(self.psit_nG):
             n = self.bd.global_index(myn)
-            psit_G[:] = self.get_scaled_gaussian_wave(center_c, scale=10+2j*n)
+            psit_G[:] = self.get_scaled_gaussian_wave(center_c,
+                                                      scale=10 + 2j * n)
 
-            k_c = 2*np.pi*np.array([1/2., -1/7., 0.])
+            k_c = 2 * np.pi * np.array([1 / 2., -1 / 7., 0.])
             for pos_c in self.atoms.get_positions() / Bohr:
-                sigma = self._sigma0/(1+np.sum(pos_c**2))**0.5
-                psit_G += self.get_scaled_gaussian_wave(pos_c, sigma, k_c, n+5j)
+                sigma = self._sigma0 / (1 + np.sum(pos_c**2))**0.5
+                psit_G += self.get_scaled_gaussian_wave(
+                    pos_c, sigma, k_c, n + 5j)
 
         self.allocated = True
 
-    def get_scaled_gaussian_wave(self, pos_c, sigma=None, k_c=None, scale=None):
+    def get_scaled_gaussian_wave(self, pos_c, sigma=None, k_c=None,
+                                 scale=None):
         if sigma is None:
             sigma = self._sigma0
 
@@ -244,9 +255,10 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
         else:
             # 4*pi*int(exp(-r^2/(2*w^2))^2*r^2, r=0...infinity)= w^3*pi^(3/2)
             # = scale/A^2 -> A = scale*(sqrt(Pi)*w)^(-3/2) hence int -> scale^2
-            A = scale/(sigma*(np.pi)**0.5)**1.5
+            A = scale / (sigma * (np.pi)**0.5)**1.5
 
-        return gaussian_wave(self.r_cG, pos_c, sigma, k_c, A, self.dtype, self.buf_G)
+        return gaussian_wave(self.r_cG, pos_c, sigma, k_c, A, self.dtype,
+                             self.buf_G)
 
     def check_and_plot(self, P_ani, P0_ani, digits, keywords=''):
         # Collapse into viewable matrices
@@ -254,8 +266,9 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
         P0_In = self.wfs.collect_projections(P0_ani)
 
         # Construct fingerprint of input matrices for comparison
-        fingerprint = np.array([md5_array(P_In, numeric=True),
-                                md5_array(P0_In, numeric=True)])
+        fingerprint = np.array(
+            [md5_array(P_In, numeric=True),
+             md5_array(P0_In, numeric=True)])
 
         # Compare fingerprints across all processors
         fingerprints = np.empty((world.size, 2), np.int64)
@@ -265,14 +278,14 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
 
         # If assertion fails, catch temporarily while plotting, then re-raise
         try:
-            self.assertAlmostEqual(np.abs(P_In-P0_In).max(), 0, digits)
+            self.assertAlmostEqual(np.abs(P_In - P0_In).max(), 0, digits)
         except AssertionError:
             if world.rank == 0 and mpl is not None:
                 from matplotlib.figure import Figure
                 fig = Figure()
                 ax = fig.add_axes([0.0, 0.1, 1.0, 0.83])
                 ax.set_title(self.__class__.__name__)
-                im = ax.imshow(np.abs(P_In-P0_In), interpolation='nearest')
+                im = ax.imshow(np.abs(P_In - P0_In), interpolation='nearest')
                 fig.colorbar(im)
                 fig.text(0.5, 0.05, 'Keywords: ' + keywords, \
                     horizontalalignment='center', verticalalignment='top')
@@ -293,7 +306,7 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
         for Q_ni in Q_ani.values():
             self.assertTrue(Q_ni.dtype == self.dtype)
 
-        P0_ani = dict([(a,Q_ni.copy()) for a,Q_ni in Q_ani.items()])
+        P0_ani = dict([(a, Q_ni.copy()) for a, Q_ni in Q_ani.items()])
         self.pt.add(self.psit_nG, Q_ani, q=kpt.q)
         self.pt.integrate(self.psit_nG, P0_ani, q=kpt.q)
 
@@ -316,18 +329,21 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
         if fingerprints.ptp(0).any():
             raise RuntimeError('Distributed matrices are not identical!')
 
-        P_ani = dict([(a,Q_ni.copy()) for a,Q_ni in Q_ani.items()])
+        P_ani = dict([(a, Q_ni.copy()) for a, Q_ni in Q_ani.items()])
         for a1 in range(len(self.atoms)):
             if a1 in P_ani.keys():
                 P_ni = P_ani[a1]
             else:
                 # Atom a1 is not in domain so allocate a temporary buffer
-                P_ni = np.zeros((self.bd.mynbands,self.setups[a1].ni,),
-                                 dtype=self.dtype)
+                P_ni = np.zeros((
+                    self.bd.mynbands,
+                    self.setups[a1].ni,
+                ),
+                                dtype=self.dtype)
             for a2, Q_ni in Q_ani.items():
                 # B_aa are the projector overlaps across atomic pairs
                 B_ii = gpo.extract_atomic_pair_matrix(B_aa, a1, a2)
-                P_ni += np.dot(Q_ni, B_ii.T) #sum over a2 and last i in B_ii
+                P_ni += np.dot(Q_ni, B_ii.T)  #sum over a2 and last i in B_ii
             self.gd.comm.sum(P_ni)
 
         self.check_and_plot(P_ani, P0_ani, 8, 'projection,linearity')
@@ -388,7 +404,7 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
 
         work_nG = np.empty_like(self.psit_nG)
         self.pt.integrate(self.psit_nG, kpt.P_ani, kpt.q)
-        P0_ani = dict([(a,P_ni.copy()) for a,P_ni in kpt.P_ani.items()])
+        P0_ani = dict([(a, P_ni.copy()) for a, P_ni in kpt.P_ani.items()])
         ppo.apply(self.psit_nG, work_nG, self.wfs, kpt, calculate_P_ani=False)
 
         res_nG = np.empty_like(self.psit_nG)
@@ -423,8 +439,12 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
 
         work_nG = np.empty_like(self.psit_nG)
         self.pt.integrate(self.psit_nG, kpt.P_ani, kpt.q)
-        P0_ani = dict([(a,P_ni.copy()) for a,P_ni in kpt.P_ani.items()])
-        ppo.apply_inverse(self.psit_nG, work_nG, self.wfs, kpt, calculate_P_ani=False)
+        P0_ani = dict([(a, P_ni.copy()) for a, P_ni in kpt.P_ani.items()])
+        ppo.apply_inverse(self.psit_nG,
+                          work_nG,
+                          self.wfs,
+                          kpt,
+                          calculate_P_ani=False)
 
         res_nG = np.empty_like(self.psit_nG)
         ppo.apply(work_nG, res_nG, self.wfs, kpt, calculate_P_ani=True)
@@ -444,21 +464,30 @@ class UTGaussianWavefunctionSetup(UTDomainParallelSetup):
 
         self.check_and_plot(P_ani, P0_ani, 10, 'overlap,inverse,before')
 
+
 # -------------------------------------------------------------------
 
+
 def UTGaussianWavefunctionFactory(boundaries, dtype):
     sep = '_'
-    classname = 'UTGaussianWavefunctionSetup' \
-    + sep + {'zero':'Zero', 'periodic':'Periodic', 'mixed':'Mixed'}[boundaries] \
-    + sep + {float:'Float', complex:'Complex'}[dtype]
+    classname = ('UTGaussianWavefunctionSetup' + sep + {
+        'zero': 'Zero',
+        'periodic': 'Periodic',
+        'mixed': 'Mixed'
+    }[boundaries] + sep + {
+        float: 'Float',
+        complex: 'Complex'
+    }[dtype])
 
     class MetaPrototype(UTGaussianWavefunctionSetup, object):
         __doc__ = UTGaussianWavefunctionSetup.__doc__
         boundaries = boundaries
         dtype = dtype
+
     MetaPrototype.__name__ = classname
     return MetaPrototype
 
+
 # -------------------------------------------------------------------
 
 if __name__ in ['__main__', '__builtin__']:
@@ -495,4 +524,3 @@ if __name__ in ['__main__', '__builtin__']:
         # Provide feedback on failed tests if imported by test.py
         if __name__ == '__builtin__' and not testresult.wasSuccessful():
             raise SystemExit('Test failed. Check ut_invops.log for details.')
-
