@@ -1,5 +1,5 @@
 from ase import Atoms
-from gpaw import GPAW
+from gpaw import GPAW, PW
 from gpaw.mpi import world, serial_comm
 
 a = Atoms('H2',
@@ -7,10 +7,10 @@ a = Atoms('H2',
           cell=(3, 3, 3),
           pbc=1)
 
-a.calc = GPAW(mode='pw',
+a.calc = GPAW(mode=PW(force_complex_dtype=True),
               eigensolver='rmm-diis',
               nbands=8,
-              dtype=complex,
+              parallel={'domain': 1},
               basis='dzp', txt=None)
 
 a.get_potential_energy()
@@ -28,7 +28,7 @@ a.calc.diagonalize_full_hamiltonian(nbands=120, scalapack=scalapack)
 w2 = a.calc.get_pseudo_wave_function(0)
 e2 = a.calc.get_eigenvalues()
 
-calc = GPAW('H2', txt=None)
+calc = GPAW('H2', txt=None, parallel={'domain': 1})
 calc.diagonalize_full_hamiltonian(nbands=120, scalapack=scalapack)
 w3 = calc.get_pseudo_wave_function(0)
 e3 = calc.get_eigenvalues()
@@ -40,8 +40,11 @@ w4 = calc.get_pseudo_wave_function(0)
 e4 = calc.get_eigenvalues()
 
 for w in [w2, w3, w4]:
-    assert abs(abs(w[1, 2, 3]) - abs(w[1, 2, 3])) < 1e-10
+    err = abs(abs(w[1, 2, 3]) - abs(w[1, 2, 3]))
+    assert err < 1e-10, err
 
 for e in [e2, e3, e4]:
-    assert abs(e[1] - e1[1]) < 1e-9
-    assert abs(e[-1] - e2[-1]) < 1e-10
+    err = abs(e[1] - e1[1])
+    assert err < 1e-9, err
+    err = abs(e[-1] - e2[-1])
+    assert err < 1e-10, err
