@@ -35,12 +35,12 @@ if not os.path.exists('graphene.gpw'):
 pbc = system.pbc
 
 df = DielectricFunction('graphene.gpw', eta=25e-3, domega0=0.01)
-alpha0x_w, alphax_w = df.get_polarizability(q_c=[1. / (nk * nkrefine), 0, 0])
+alpha0x_w, alphax_w = df.get_polarizability(q_c=[1 / (nk * nkrefine), 0, 0])
 omega_w = df.get_frequencies()
 analyticalalpha_w = 1j / (8 * omega_w[1:] / Hartree)
 
 # Just some hardcoded test for alpha at omega=0
-equal(alphax_w[0].real, 6.705, tolerance=0.02,
+equal(alphax_w[0].real, 6.69, tolerance=0.04,
       msg='Polarizability at omega=0 is wrong')
 
 if 0:
