@@ -35,7 +35,8 @@ calc_plus = get_paw()
 calc_plus.set(txt='Be_plus_LCY_PBE_083.log', charge=1)
 o_plus.set_calculator(calc_plus)
 e_o_plus = o_plus.get_potential_energy()
-calc_plus.set(xc='LCY-PBE:omega=0.83:unocc=True', experimental={'niter_fixdensity': 2})
+calc_plus.set(xc='LCY-PBE:omega=0.83:unocc=True',
+              experimental={'niter_fixdensity': 2})
 e_o_plus = o_plus.get_potential_energy()
 lr = LrTDDFT(calc_plus, txt='LCY_TDDFT_Be.log', istart=0, jend=1)
 equal(lr.xc.omega, 0.83)
