@@ -12,6 +12,6 @@ result = test(verbose=10)
 sys.stdout = _stdout
 sys.stderr = _stderr
 if not result.wasSuccessful():
-    print("scipy_test%02d.out" % rank, result.errors, result.failures, file=sys.stderr)
+    print("scipy_test%02d.out" % rank, result.errors, result.failures,
+          file=sys.stderr)
 assert result.wasSuccessful()
-
