@@ -9,7 +9,7 @@ a = 5.475
 cell_cv = .5 * a * np.array([(1, 1, 0), (1, 0, 1), (0, 1, 1)])
 spos_ac = np.array([(.00, .00, .00),
                     (.25, .25, .25)])
-id_a = [1, 1] # Two identical atoms
+id_a = [1, 1]  # two identical atoms
 pbc_c = np.ones(3, bool)
 bzk_kc = monkhorst_pack((4, 4, 4))
 
@@ -48,11 +48,11 @@ assert not symm.op_scc.sum(0).any()
 
 # Linear chain of four atoms, with H lattice parameter
 cell_cv = np.diag((8., 5., 5.))
-spos_ac = np.array([[ 0.125,  0.5  ,  0.5  ],
-                    [ 0.375,  0.5  ,  0.5  ],
-                    [ 0.625,  0.5  ,  0.5  ],
-                    [ 0.875,  0.5  ,  0.5  ]])
-id_a = [1, 1, 1, 1] # Four identical atoms
+spos_ac = np.array([[0.125, 0.5, 0.5],
+                    [0.375, 0.5, 0.5],
+                    [0.625, 0.5, 0.5],
+                    [0.875, 0.5, 0.5]])
+id_a = [1, 1, 1, 1]  # four identical atoms
 pbc_c = np.array([1, 0, 0], bool)
 bzk_kc = monkhorst_pack((3, 1, 1))
 
@@ -60,18 +60,21 @@ bzk_kc = monkhorst_pack((3, 1, 1))
 symm = Symmetry(id_a, cell_cv, pbc_c)
 symm.analyze(spos_ac)
 ibzk_kc, w_k = symm.reduce(bzk_kc)[:2]
-assert len(symm.op_scc) == 2
+assert len(symm.op_scc) == 16
 assert len(w_k) == 2
 assert np.all(w_k == [1 / 3., 2 / 3.])
 
 # Rocksalt Ni2O2
 a = 7.92
-x = 2. * np.sqrt(1./3.)
-y = np.sqrt(1./8.)
-z1 = np.sqrt(1./24.)
-z2 = np.sqrt(1./6.)
+x = 2. * np.sqrt(1. / 3.)
+y = np.sqrt(1. / 8.)
+z1 = np.sqrt(1. / 24.)
+z2 = np.sqrt(1. / 6.)
 cell_cv = a * np.array([(x, y, -z1), (x, -y, -z1), (x, 0., z2)])
-spos_ac = np.array([[0., 0. ,0.], [1./2., 1./2., 1./2.], [1./4., 1./4., 1./4.], [3./4., 3./4., 3./4.]])
+spos_ac = np.array([[0., 0., 0.],
+                    [1. / 2., 1. / 2., 1. / 2.],
+                    [1. / 4., 1. / 4., 1. / 4.],
+                    [3. / 4., 3. / 4., 3. / 4.]])
 id_a = [1, 2, 3, 3]
 pbc_c = np.array([1, 1, 1], bool)
 bzk_kc = monkhorst_pack((2, 2, 2))
@@ -82,4 +85,4 @@ symm.analyze(spos_ac)
 ibzk_kc, w_k = symm.reduce(bzk_kc)[:2]
 assert len(symm.op_scc) == 12
 assert len(w_k) == 2
-assert np.all(w_k == [3/4., 1/4.])
+assert np.all(w_k == [3 / 4, 1 / 4])
