@@ -1,13 +1,12 @@
 # Copyright (C) 2003  CAMP
 # Please see the accompanying LICENSE file for further information.
-from __future__ import print_function
 from gpaw.grid_descriptor import GridDescriptor
 from gpaw.transformers import Transformer
-import time
+from time import perf_counter as clock
 
 
 n = 6
-gda = GridDescriptor((n,n,n))
+gda = GridDescriptor((n, n, n))
 gdb = gda.refine()
 gdc = gdb.refine()
 a = gda.zeros()
@@ -17,12 +16,12 @@ c = gdc.zeros()
 inter = Transformer(gdb, gdc, 2).apply
 restr = Transformer(gdb, gda, 2).apply
 
-t = time.clock()
-for i in range(8*300):
+t = clock()
+for i in range(8 * 300):
     inter(b, c)
-print(time.clock() - t)
+print(clock() - t)
 
-t = time.clock()
-for i in range(8*3000):
+t = clock()
+for i in range(8 * 3000):
     restr(b, a)
-print(time.clock() - t)
+print(clock() - t)
