@@ -4,7 +4,7 @@ from ase.lattice.compounds import L1_2
 
 name = 'Cu3Au'
 ecut = 300
-kpts = (2,2,2)
+kpts = (2, 2, 2)
 
 QNA = {'alpha': 2.0,
        'name': 'QNA',
@@ -13,23 +13,25 @@ QNA = {'alpha': 2.0,
        'setup_name': 'PBE',
        'type': 'qna-gga'}
 
-atoms = L1_2(['Au','Cu'],latticeconstant=3.74)
+atoms = L1_2(['Au', 'Cu'], latticeconstant=3.74)
 
 calc = GPAW(mode=PW(ecut),
-            xc = QNA,
+            xc=QNA,
             kpts=kpts,
+            parallel={'domain': 1},
             txt='gs.txt')
 
 atoms.set_calculator(calc)
 atoms.get_potential_energy()
-eigs = calc.wfs.kpt_u[0].eps_n[:24]
+eigs = calc.get_eigenvalues(kpt=0)[:24]
 calc.write('gs.gpw')
 
-print(calc.wfs.kpt_u[0])
-print(calc.wfs.kpt_u[0])
-atoms, calc = restart('gs.gpw', fixdensity=True, kpts=[ [-0.25, 0.25, -0.25] ])
+atoms, calc = restart('gs.gpw',
+                      parallel={'domain': 1},
+                      fixdensity=True,
+                      kpts=[[-0.25, 0.25, -0.25]])
 atoms.get_potential_energy()
-eigs_new = calc.wfs.kpt_u[0].eps_n[:24]
+eigs_new = calc.get_eigenvalues(kpt=0)[:24]
 for eold, enew in zip(eigs, eigs_new):
-    print("%.7f %.7f %.7f" % (eold, enew, eold-enew))
-    assert(abs(eold-enew) < 1e-6)
+    print(eold, enew, eold - enew)
+    assert abs(eold - enew) < 27e-6
