@@ -14,13 +14,14 @@ except ImportError:  # python2.6 compatibility
 
 import numpy as np
 from ase.data import atomic_numbers
-from ase.utils import basestring
 
 from gpaw.atom.atompaw import AtomPAW
+from gpaw.atom.radialgd import EquidistantRadialGridDescriptor
 from gpaw.setup_data import search_for_file
 from gpaw.basis_data import Basis, BasisFunction
-from gpaw.pseudopotential import PseudoPotential, screen_potential, \
-    figure_out_valence_states
+from gpaw.pseudopotential import (PseudoPotential, screen_potential,
+                                  figure_out_valence_states,
+                                  get_radial_hartree_energy)
 from gpaw.spline import Spline
 from gpaw.utilities import pack2, divrl
 
@@ -146,12 +147,12 @@ def parse_upf(fname):
     mesh_element = root.find('PP_MESH')
     pp['r'] = toarray(mesh_element.find('PP_R'))
     pp['rab'] = toarray(mesh_element.find('PP_RAB'))
-    
+
     # Convert to Hartree from Rydberg.
     pp['vlocal'] = 0.5 * toarray(root.find('PP_LOCAL'))
-    
+
     non_local = root.find('PP_NONLOCAL')
-    
+
     pp['projectors'] = []
     for element in non_local:
         if element.tag.startswith('PP_BETA'):
@@ -168,7 +169,7 @@ def parse_upf(fname):
                 tokens = element.text.split()
                 metadata = tokens[:5]
                 values = map(float, tokens[5:])
-                
+
                 npts = int(metadata[4])
                 assert npts == len(values), (npts, len(values))
                 while values[-1] == 0.0:
@@ -233,26 +234,47 @@ def parse_upf(fname):
     return pp
 
 
+sg15_special_valence_states = {
+    'Re': ([5, 5, 6, 5], [0, 1, 0, 2], [2., 6., 2., 5.]),
+    'Os': ([5, 5, 6, 5], [0, 1, 0, 2], [2., 6., 2., 6.]),
+    'Ir': ([5, 5, 6, 5], [0, 1, 0, 2], [2., 6., 2., 7.])}
+
+
+def read_sg15(fname):
+    data = parse_upf(fname)
+    symbol = data['header']['element']
+    valence_states = None
+
+    states_nlf = sg15_special_valence_states.get(symbol)
+    if states_nlf is not None:
+        valence_states = [UPFStateSpec(index=None, label=None, n=n, l=l,
+                                       values=None, occupation=f)
+                          for n, l, f in zip(*states_nlf)]
+
+    data = UPFSetupData(data, filename=fname, valence_states=valence_states)
+    return data
+
+
 class UPFSetupData:
-    def __init__(self, data):
+    def __init__(self, data, valence_states=None, filename=None):
         # data can be string (filename)
         # or dict (that's what we are looking for).
         # Maybe just a symbol would also be fine if we know the
         # filename to look for.
-        if isinstance(data, basestring):
-            self.filename = data
+        if isinstance(data, str):
+            filename = data
             data = parse_upf(data)
-        else:
-            self.filename = '[N/A]'
-        
+        elif filename is None:
+            filename = '[N/A]'
+
+        self.filename = filename
+
         assert isinstance(data, dict)
         self.data = data  # more or less "raw" data from the file
 
         self.name = 'upf'
 
         header = data['header']
-        
-        keys = sorted(header)
 
         self.symbol = header['element']
         self.Z = atomic_numbers[self.symbol]
@@ -267,11 +289,11 @@ class UPFSetupData:
         # This is "stolen" from hgh.  Figure out something reasonable
         #rgd = AERadialGridDescriptor(beta / N, 1.0 / N, N,
         #                             default_spline_points=100)
-        
+
         from gpaw.atom.radialgd import EquidistantRadialGridDescriptor
         rgd = EquidistantRadialGridDescriptor(0.02)
         self.rgd = rgd
-        
+
         # Whyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy???
         # What abominable part of the code requires the states
         # to be ordered like this?
@@ -289,7 +311,7 @@ class UPFSetupData:
                 pt_g = self._interp(val) #* np.sqrt(4.0 * np.pi)
                 #sqrnorm = (pt_g**2 * self.rgd.dr_g).sum()
                 self.pt_jg.append(pt_g)
-        
+
         else:
             self.l_j = [0]
             gcut = self.rgd.r2g(1.0)
@@ -302,16 +324,14 @@ class UPFSetupData:
         self.HubU = None # XXX
         self.lq = None # XXX
 
-        #if data['states']:
-        #    states_lmax = max([state.l for state in data['states']])
-        #else:
-        #    states_lmax = 1 # XXXX
+        if valence_states is None:
+            valence_states = data['states']
 
-        if data['states']:
-            states_lmax = max([state.l for state in data['states']])
+        if valence_states:
+            states_lmax = max([state.l for state in valence_states])
             f_ln = [[] for _ in range(1 + states_lmax)]
             electroncount = 0.0
-            for state in data['states']:
+            for state in valence_states:
                 # Where should the electrons be in the inner list??
                 # This is probably wrong and will lead to bad initialization
                 f_ln[state.l].append(state.occupation)
@@ -319,9 +339,9 @@ class UPFSetupData:
                 # The Cl.pz-hgh.UPF from quantum espresso has only 6
                 # but should have 7 electrons.  Oh well....
             #err = abs(electroncount - self.Nv)
-            self.f_j = [state.occupation for state in data['states']]
-            self.n_j = [state.n for state in data['states']]
-            self.l_orb_j = [state.l for state in data['states']]
+            self.f_j = [state.occupation for state in valence_states]
+            self.n_j = [state.n for state in valence_states]
+            self.l_orb_j = [state.l for state in valence_states]
             self.f_ln = f_ln
         else:
             self.n_j, self.l_orb_j, self.f_j, self.f_ln = \
@@ -346,16 +366,16 @@ class UPFSetupData:
 
         vbar_g, ghat_g = screen_potential(data['r'], vlocal_unscreened,
                                           self.Nv)
-        
+        self.Eh_compcharge = get_radial_hartree_energy(data['r'][:len(ghat_g)],
+                                                       ghat_g)
         self.vbar_g = self._interp(vbar_g) * np.sqrt(4.0 * np.pi)
         self.ghat_lg = [4.0 * np.pi / self.Nv * self._interp(ghat_g)]
 
-        # XXX Subtract Hartree energy of compensation charge as reference
 
     def get_jargs(self):
         projectors = list(self.data['projectors'])
         jargs = []
-        
+
         for n in range(4):
             for l in range(4):
                 for i, proj in enumerate(projectors):
@@ -368,7 +388,7 @@ class UPFSetupData:
     def tostring(self):
         lines = []
         indent = 0
-        
+
         def add(line):
             lines.append(indent * ' ' + line)
 
@@ -392,7 +412,7 @@ class UPFSetupData:
                 add('l=%d f=%s' % (state.l, state.occupation))
             indent -= 2
         add('Local potential cutoff: %s'
-            % self.get_local_potential().get_cutoff())
+            % self.rgd.r_g[len(self.vbar_g) - 1])
         add('Comp charge cutoff:     %s'
             % self.rgd.r_g[len(self.ghat_lg[0]) - 1])
         add('File: %s' % self.filename)
@@ -411,7 +431,7 @@ class UPFSetupData:
         H_ii = np.zeros((ni, ni))
         if len(self.data['DIJ']) == 0:
             return pack2(H_ii)
-        
+
         # Multiply by 4.
         # I think the factor of 4 compensates for the fact that the projectors
         # all had square norms of 4, but we brought them back down to 1
@@ -434,12 +454,12 @@ class UPFSetupData:
                 m2start = m2stop
             m1start = m1stop
         return pack2(H_ii)
-    
+
     def get_local_potential(self):
         vbar = Spline(0, self.rgd.r_g[len(self.vbar_g) - 1], self.vbar_g)
         return vbar
 
-    # XXXXXXXXXXXXXXXXX stolen from hghsetupdata
+    # XXXXXXXXXXXXXXXXX stolen from hghsetupdataf
     def get_projectors(self):
         # XXX equal-range projectors still required for some reason
         maxlen = max([len(pt_g) for pt_g in self.pt_jg])
@@ -476,34 +496,36 @@ class UPFSetupData:
         else:
             from gpaw.pseudopotential import generate_basis_functions
             return generate_basis_functions(self)
-    
+
     def get_stored_basis_functions(self, ):
-        b = Basis(self.symbol, 'upf', readxml=False)
-        b.generatordata = 'upf-pregenerated'
-        
         states = self.data['states']
         maxlen = max([len(state.values) for state in states])
         orig_r = self.data['r']
         rcut = min(orig_r[maxlen - 1], 12.0)  # XXX hardcoded 12 max radius
-        
-        b.d = 0.02
-        b.ng = int(1 + rcut / b.d)
-        rgd = b.get_grid_descriptor()
-        
+
+        d = 0.02
+        ng = int(1 + rcut / d)
+        rgd = EquidistantRadialGridDescriptor(d, ng)
+
+        b = Basis(self.symbol, 'upf', readxml=False, rgd=rgd)
+        b.generatordata = 'upf-pregenerated'
+
         for j, state in enumerate(states):
             val = state.values
             phit_g = np.interp(rgd.r_g, orig_r, val)
             phit_g = divrl(phit_g, 1, rgd.r_g)
             icut = len(phit_g) - 1  # XXX correct or off-by-one?
             rcut = rgd.r_g[icut]
-            bf = BasisFunction(state.l, rcut, phit_g, 'pregenerated')
+            bf = BasisFunction(None, state.l, rcut, phit_g, 'pregenerated')
             b.bf_j.append(bf)
         return b
 
     def build(self, xcfunc, lmax, basis, filter=None):
+        # XXX better to create basis functions after filtering?
+        # Although basis functions are not meant for same grid
         if basis is None:
             basis = self.create_basis_functions()
-        return PseudoPotential(self, basis)
+        return PseudoPotential(self, basis, filter)
 
 
 def main_plot():
@@ -548,7 +570,7 @@ def upfplot(setup, show=True, calculate=False):
         r = r0[:len(array)]
         arr = divrl(array, rdividepower, r)
         return r, arr
-    
+
     import pylab as pl
     fig = pl.figure()
     fig.canvas.set_window_title('%s - UPF setup for %s' % (pp['fname'],
@@ -560,7 +582,7 @@ def upfplot(setup, show=True, calculate=False):
     wfsax = fig.add_subplot(224)
 
     r, v = rtrunc(pp['vlocal'])
-    
+
     vax.plot(r, v, label='vloc')
 
     vscreened, rhocomp = screen_potential(r, v, setup.Nv)
@@ -589,7 +611,7 @@ def upfplot(setup, show=True, calculate=False):
     if calculate:
         calc = AtomPAW(setup.symbol,
                        [setup.f_ln],
-                       #xc='PBE', # XXX does not support GGAs :( :( :(
+                       # xc='PBE', # XXX does not support GGAs :( :( :(
                        setups={setup.symbol: setup},
                        h=0.08,
                        rcut=10.0)
