@@ -7,24 +7,19 @@
 import re
 import sys
 import time
-from math import sqrt, exp
+from math import sqrt
 from contextlib import contextmanager
 from typing import Union
 from pathlib import Path
 
 from ase.utils import devnull
 import numpy as np
-from numpy import linalg
 
 import _gpaw
 import gpaw.mpi as mpi
 from gpaw import debug
 
 
-utilities_vdot = _gpaw.utilities_vdot
-utilities_vdot_self = _gpaw.utilities_vdot_self
-
-
 erf = np.vectorize(_gpaw.erf, (float,), 'Error function')
 # XXX should we unify double and complex erf ???
 cerf = np.vectorize(_gpaw.cerf, (complex,), 'Complex error function')
@@ -170,6 +165,7 @@ corrections to the Hamiltonian, are constructed according to pack2 / unpack.
 def unpack(M):
     """Unpack 1D array to 2D, assuming a packing as in ``pack2``."""
     assert is_contiguous(M)
+    assert M.ndim == 1
     n = int(sqrt(0.25 + 2.0 * len(M)))
     M2 = np.zeros((n, n), M.dtype.char)
     if M.dtype == complex:
@@ -317,80 +313,6 @@ if not debug:
     pack = _gpaw.pack
 
 
-def mlsqr(order, cutoff, coords_nc, N_c, beg_c, data_g, target_n):
-    """Interpolate a point using moving least squares algorithm.
-
-    Python wrapper for a c-function. See c/mlsqr.c.
-
-    order:       Polynomial order (1 or 2)
-    coords_nc:   List of scaled coordinates
-    N_c:         Total number of grid points
-    beg_c:       The start of grid points
-    data_g:      3D-data to be interpolated
-    target_n:    Output array
-    """
-
-    assert is_contiguous(coords_nc, float)
-    assert is_contiguous(data_g, float)
-    N_c = np.ascontiguousarray(N_c, float)
-    beg_c = np.ascontiguousarray(beg_c, float)
-    assert is_contiguous(target_n, float)
-
-    return _gpaw.mlsqr(order, cutoff, coords_nc, N_c, beg_c, data_g, target_n)
-
-
-def interpolate_mlsqr(dg_c, vt_g, order):
-    """Interpolate a point using moving least squares algorithm.
-
-    dg_c:    The grid point index (from (0,0,0) to (Bg_g - bg_g)
-    vt_g:    The array to be interpolated
-    order:   Polynomial order
-    """
-
-    # Define the weight function
-    def lsqr_weight(r2):
-        return exp(-r2)
-
-    # Define the polynomial basis
-    if order == 1:
-        def b(x):
-            return np.array([1, x[0], x[1], x[2]])
-    elif order == 2:
-        def b(x):
-            return np.array([1, x[0], x[1], x[2],
-                             x[0] * x[1], x[1] * x[2], x[2] * x[0],
-                             x[0]**2, x[1]**2, x[2]**2])
-    else:
-        raise NotImplementedError
-
-    def fill_X(x, y, z):
-        result = None
-        for i, j, k in zip(x.ravel(), y.ravel(), z.ravel()):
-            r = b(np.array([i, j, k])) * lsqr_weight(
-                np.sum((dg_c - np.array([i, j, k]))**2))
-            if result is None:
-                result = r
-            else:
-                result = np.vstack((result, r))
-        return result
-
-    def fill_w(x, y, z):
-        result = []
-        for i, j, k in zip(x.ravel(), y.ravel(), z.ravel()):
-            weight = lsqr_weight(np.sum((dg_c - np.array([i, j, k]))**2))
-            result.append(weight * vt_g[i][j][k])
-        return np.array(result)
-
-    X = np.fromfunction(fill_X, vt_g.shape)
-    y = np.fromfunction(fill_w, vt_g.shape)
-
-    X2 = np.dot(X.transpose(), X)
-    y2 = np.dot(X.transpose(), y)
-    c = linalg.solve(X2, y2)
-    a = np.dot(b(dg_c), c)
-    return a
-
-
 def unlink(path: Union[str, Path], world=None):
     """Safely unlink path (delete file or symbolic link)."""
 
