@@ -199,7 +199,8 @@ def raw_spinorbit_orbital_LDOS(paw, a, spin, angular='spdf', theta=0, phi=0):
             weights_xi[x:x + nb, :] = w * np.absolute(P_ami[a][:, spin::2])**2
         else:
             weights_xi[x:x + nb, :] = w * np.absolute(P_ami[a][:, 0::2])**2 / 2
-            weights_xi[x:x + nb, :] += w * np.absolute(P_ami[a][:, 1::2])**2  / 2
+            weights_xi[x:x + nb, :] += (w *
+                                        np.absolute(P_ami[a][:, 1::2])**2 / 2)
         x += nb
 
     if angular is None:
