@@ -3,6 +3,7 @@ from math import pi, sqrt
 import numpy as np
 from ase.units import Bohr, Ha
 
+from gpaw.atom.shapefunc import shape_functions
 from gpaw.fftw import get_efficient_fft_size
 from gpaw.grid_descriptor import GridDescriptor
 from gpaw.lfc import LFC
@@ -23,12 +24,6 @@ class Interpolator:
 POINTS = 200
 
 
-def gauss(rgd, alpha):
-    r_g = rgd.r_g
-    g_g = 4 / sqrt(pi) * alpha**1.5 * np.exp(-alpha * r_g**2)
-    return g_g
-
-
 class PS2AE:
     """Transform PS to AE wave functions.
 
@@ -129,12 +124,11 @@ class PS2AE:
         v_R = interpolator.interpolate(v_r)
 
         if ae:
-            alpha = 1 / (rcgauss / Bohr)**2
-            self.add_potential_correction(v_R, alpha)
+            self.add_potential_correction(v_R, rcgauss / Bohr)
 
         return v_R * Ha
 
-    def add_potential_correction(self, v_R, alpha):
+    def add_potential_correction(self, v_R, rcgauss: float) -> None:
         dens = self.calc.density
         dens.D_asp.redistribute(dens.atom_partition.as_serial())
         dens.Q_aL.redistribute(dens.atom_partition.as_serial())
@@ -144,8 +138,9 @@ class PS2AE:
             setup = dens.setups[a]
             c = setup.xc_correction
             rgd = c.rgd
-            ghat_g = gauss(rgd, 1 / setup.rcgauss**2)
-            Z_g = gauss(rgd, alpha) * setup.Z
+            ghat_g = shape_functions(rgd,
+                                     **setup.data.shape_function, lmax=0)[0]
+            Z_g = shape_functions(rgd, 'gauss', rcgauss, lmax=0)[0] * setup.Z
             D_q = np.dot(D_sp.sum(0), c.B_pqL[:, :, 0])
             dn_g = np.dot(D_q, (c.n_qg - c.nt_qg)) * sqrt(4 * pi)
             dn_g += 4 * pi * (c.nc_g - c.nct_g)
@@ -165,3 +160,24 @@ class PS2AE:
             dv.set_positions(self.calc.spos_ac)
             dv.add(v_R)
         dens.gd.comm.broadcast(v_R, 0)
+
+
+def interpolate_weight(calc, weight, h=0.05, n=2):
+    """interpolates cdft weight function, gd is the fine grid."""
+    gd = calc.density.finegd
+
+    weight = gd.collect(weight, broadcast=True)
+    weight = gd.zero_pad(weight)
+
+    w = np.zeros_like(weight)
+    gd1 = GridDescriptor(gd.N_c, gd.cell_cv, comm=serial_comm)
+    gd1.distribute(weight, w)
+
+    N_c = h2gpts(h / Bohr, gd.cell_cv)
+    N_c = np.array([get_efficient_fft_size(N, n) for N in N_c])
+    gd2 = GridDescriptor(N_c, gd.cell_cv, comm=serial_comm)
+
+    interpolator = Interpolator(gd1, gd2)
+    W = interpolator.interpolate(w)
+
+    return W
