@@ -80,8 +80,8 @@ def construct_reciprocal(gd, q_c=None):
     # Avoid future divide-by-zero by setting k2_Q[G=(0,0,0)] = 1.0 if needed
     if k2_Q[0, 0, 0] < 1e-10:
         k2_Q[0, 0, 0] = 1.0           # Only make sense iff
-        assert gd.comm.rank == 0      #  * on rank 0 (G=(0,0,0) is only there)
-        assert abs(q_c).sum() < 1e-8  #  * q_c is (almost) zero
+        assert gd.comm.rank == 0      # * on rank 0 (G=(0,0,0) is only there)
+        assert abs(q_c).sum() < 1e-8  # * q_c is (almost) zero
 
     assert k2_Q.min() > 0.0       # Now there should be no zero left
 
@@ -276,15 +276,15 @@ def tridiag(a, b, c, r, u):
     u[0] = r[0] / beta
     for i in range(1, n):
         # Decompose and forward substitution
-        tmp[i-1] = c[i-1] / beta
-        beta = b[i] - a[i-1] * tmp[i-1]
+        tmp[i - 1] = c[i - 1] / beta
+        beta = b[i] - a[i - 1] * tmp[i - 1]
         if beta == 0:
             raise RuntimeError('Method failure')
-        u[i] = (r[i] - a[i-1] * u[i-1]) / beta
+        u[i] = (r[i] - a[i - 1] * u[i - 1]) / beta
 
-    for i in range(n-1, 0, -1):
+    for i in range(n - 1, 0, -1):
         # Backward substitution
-        u[i-1] -= tmp[i-1] * u[i]
+        u[i - 1] -= tmp[i - 1] * u[i]
 
 
 def signtrim(data, decimals=None):
@@ -294,7 +294,7 @@ def signtrim(data, decimals=None):
     decimals is an integer specifying how many decimals to round to.
     """
     if decimals is not None:
-        data = data.round(decimals) #np.round is buggy because -0 != 0
+        data = data.round(decimals)  # np.round is buggy because -0 != 0
 
     shape = data.shape
     data = data.reshape(-1)
@@ -305,7 +305,7 @@ def signtrim(data, decimals=None):
         data.real[i] = 0
         data.imag[j] = 0
     else:
-        i = np.argwhere(np.sign(data)==0).ravel()
+        i = np.argwhere(np.sign(data) == 0).ravel()
         data[i] = 0
 
     return data.reshape(shape)
@@ -339,12 +339,15 @@ def md5_array(data, numeric=False):
         data.dtype not in [bool, np.bool, np.bool_]):
         raise TypeError('MD5 hex digest only accepts numeric/boolean arrays.')
 
-    datahash = hashlib.md5(data.tostring())
+    datahash = hashlib.md5(data.tobytes())
 
     if numeric:
-        xor = lambda a,b: chr(ord(a)^ord(b)) # bitwise xor on 2 bytes -> 1 byte
+        def xor(a, b):
+            return chr(ord(a) ^ ord(b))  # bitwise xor on 2 bytes -> 1 byte
+
         sbuf128 = datahash.digest()
-        sbuf64 = ''.join([xor(a,b) for a,b in zip(sbuf128[::2],sbuf128[1::2])])
+        sbuf64 = ''.join([xor(a, b)
+                          for a, b in zip(sbuf128[::2], sbuf128[1::2])])
         return np.fromstring(sbuf64, np.int64).item()
     else:
         return datahash.hexdigest()
@@ -386,13 +389,13 @@ class Spline:
         """
         self.xy = (xi, yi)
         N = len(xi)
-        self.ypp = u = np.zeros(N) # The second derivatives y''
+        self.ypp = u = np.zeros(N)  # the second derivatives y''
         tmp = np.zeros(N - 1)
 
         # Set left boundary condition
-        if leftderiv is None: # natural spline - second derivative is zero
+        if leftderiv is None:  # natural spline - second derivative is zero
             tmp[0] = u[0] = 0.0
-        else: # clamped spline - first derivative is fixed
+        else:  # clamped spline - first derivative is fixed
             tmp[0] = 3 / (xi[1] - xi[0]) * (
                 (yi[1] - yi[0]) / (xi[1] - xi[0]) - leftderiv)
             u[0] = -.5
@@ -403,18 +406,19 @@ class Spline:
             u[i] = (sig - 1) / p
             tmp[i] = (yi[i + 1] - yi[i]) / (xi[i + 1] - xi[i]) - \
                      (yi[i] - yi[i - 1]) / (xi[i] - xi[i - 1])
-            tmp[i] = (6 * tmp[i] / (xi[i +1] - xi[i-1]) - sig * tmp[i - 1]) / p
+            tmp[i] = (6 * tmp[i] /
+                      (xi[i + 1] - xi[i - 1]) - sig * tmp[i - 1]) / p
 
         # Set right boundary condition
-        if rightderiv is None: # natural spline - second derivative is zero
+        if rightderiv is None:  # natural spline - second derivative is zero
             qn = tmpn = 0.0
-        else: # clamped spline - first derivative is fixed
+        else:  # clamped spline - first derivative is fixed
             qn = .5
             tmpn = 3 / (xi[N - 1] - xi[N - 2]) * (
                 rightderiv - (yi[N - 1] - yi[N - 2]) / (xi[N - 1] - xi[N - 2]))
 
         u[N - 1] = (tmpn - qn * tmp[N - 2]) / (qn * u[N - 1] + 1)
-        for k in range(N - 2, -1, -1): # backsubstitution step
+        for k in range(N - 2, -1, -1):  # backsubstitution step
             u[k] = u[k] * u[k + 1] + tmp[k]
 
     def __call__(self, x):
@@ -428,7 +432,8 @@ class Spline:
 
         """
         x = np.array(x, float)
-        if x.ndim == 0: x.shape = (1,)
+        if x.ndim == 0:
+            x.shape = (1,)
         y = np.zeros_like(x)
         xi, yi = self.xy
 
@@ -450,7 +455,11 @@ class Spline:
         1 or len(xi) - 1 is returned if x is outside list range.
         """
         xi = self.xy[0]
-        if x <= xi[0]: return 1
-        elif x > xi[-1]: return len(xi) - 1
-        elif guess and xi[guess - 1] < x <= xi[guess]: return guess
-        else: return np.searchsorted(xi, x)
+        if x <= xi[0]:
+            return 1
+        elif x > xi[-1]:
+            return len(xi) - 1
+        elif guess and xi[guess - 1] < x <= xi[guess]:
+            return guess
+        else:
+            return np.searchsorted(xi, x)
