@@ -9,7 +9,8 @@ from gpaw.utilities.tools import tri2full
 from gpaw.lcao.tci import TCIExpansions
 from gpaw.utilities.blas import gemm, gemmdot
 from gpaw.wavefunctions.base import WaveFunctions
-from gpaw.lcao.atomic_correction import get_atomic_correction
+from gpaw.lcao.atomic_correction import (DenseAtomicCorrection,
+                                         SparseAtomicCorrection)
 from gpaw.wavefunctions.mode import Mode
 
 
@@ -100,13 +101,13 @@ class LCAOWaveFunctions(WaveFunctions):
         self.debug_tci = False
 
         if atomic_correction is None:
-            if ksl.using_blacs:
-                atomic_correction = 'sparse'
-            else:
-                atomic_correction = 'dense'
-        if isinstance(atomic_correction, str):
-            atomic_correction = get_atomic_correction(atomic_correction)
-        self.atomic_correction = atomic_correction
+            atomic_correction = 'sparse' if ksl.using_blacs else 'dense'
+
+        if atomic_correction == 'sparse':
+            self.atomic_correction_cls = SparseAtomicCorrection
+        else:
+            assert atomic_correction == 'dense'
+            self.atomic_correction_cls = DenseAtomicCorrection
 
         #self.tci = NewTCI(gd.cell_cv, gd.pbc_c, setups, kd.ibzk_qc, kd.gamma)
         with self.timer('TCI: Evaluate splines'):
@@ -134,7 +135,8 @@ class LCAOWaveFunctions(WaveFunctions):
     def __str__(self):
         s = 'Wave functions: LCAO\n'
         s += '  Diagonalizer: %s\n' % self.ksl.get_description()
-        s += '  Atomic Correction: %s\n' % self.atomic_correction.description
+        s += ('  Atomic Correction: %s\n'
+              % self.atomic_correction_cls.description)
         s += '  Datatype: %s\n' % self.dtype.__name__
         return s
 
@@ -164,11 +166,11 @@ class LCAOWaveFunctions(WaveFunctions):
         mynao = Mstop - Mstart
 
         #if self.ksl.using_blacs:  # XXX
-            # S and T have been distributed to a layout with blacs, so
-            # discard them to force reallocation from scratch.
-            #
-            # TODO: evaluate S and T when they *are* distributed, thus saving
-            # memory and avoiding this problem
+        #     S and T have been distributed to a layout with blacs, so
+        #     discard them to force reallocation from scratch.
+        #
+        #     TODO: evaluate S and T when they *are* distributed, thus saving
+        #     memory and avoiding this problem
         for kpt in self.kpt_u:
             kpt.S_MM = None
             kpt.T_MM = None
@@ -225,6 +227,8 @@ class LCAOWaveFunctions(WaveFunctions):
         self.P_aqMi = newP_aqMi = manytci.P_aqMi(my_atom_indices)
         self.P_qIM = P_qIM  # XXX atomic correction
 
+        self.atomic_correction = self.atomic_correction_cls.new_from_wfs(self)
+
         # TODO
         #   OK complex/conj, periodic images
         #   OK scalapack
@@ -236,7 +240,6 @@ class LCAOWaveFunctions(WaveFunctions):
         #if self.atomic_correction.name != 'dense':
         #from gpaw.lcao.newoverlap import newoverlap
         #self.P_neighbors_a, self.P_aaqim = newoverlap(self, spos_ac)
-        self.atomic_correction.gobble_data(self)
 
         #if self.atomic_correction.name == 'scipy':
         #    Pold_qIM = self.atomic_correction.Psparse_qIM
@@ -245,11 +248,10 @@ class LCAOWaveFunctions(WaveFunctions):
         #        print('sparse maxerr', maxerr)
         #        assert maxerr == 0
 
-        self.atomic_correction.add_overlap_correction(self, newS_qMM)
+        self.atomic_correction.add_overlap_correction(newS_qMM)
         if self.debug_tci:
-            self.atomic_correction.add_overlap_correction(self, oldS_qMM)
+            self.atomic_correction.add_overlap_correction(oldS_qMM)
 
-        my_atom_indices = self.atomic_correction.get_a_values()
         self.allocate_arrays_for_projections(my_atom_indices)
 
         #S_MM = None  # allow garbage collection of old S_qMM after redist
@@ -262,7 +264,7 @@ class LCAOWaveFunctions(WaveFunctions):
 
         #if (debug and self.bd.comm.size == 1 and self.gd.comm.rank == 0 and
         #    nao > 0 and not self.ksl.using_blacs):
-            # S and T are summed only on comm master, so check only there
+        #    S and T are summed only on comm master, so check only there
         #    from numpy.linalg import eigvalsh
         #    self.timer.start('Check positive definiteness')
         #    for S_MM in S_qMM:
@@ -520,7 +522,7 @@ class LCAOWaveFunctions(WaveFunctions):
                         d_nn = np.zeros((self.bd.mynbands, self.bd.mynbands),
                                         dtype=kpt.C_nM.dtype)
                         for ne, c_n in zip(kpt.ne_o, kpt.c_on):
-                                d_nn += ne * np.outer(c_n.conj(), c_n)
+                            d_nn += ne * np.outer(c_n.conj(), c_n)
                         rhoT_MM += ksl.get_transposed_density_matrix_delta(
                             d_nn, kpt.C_nM)
                         ET_MM += ksl.get_transposed_density_matrix_delta(
