@@ -1,8 +1,5 @@
-from __future__ import print_function
 import warnings
 
-from ase.utils import basestring
-
 from gpaw.xc.libxc import LibXC
 from gpaw.xc.lda import LDA
 from gpaw.xc.gga import GGA
@@ -38,7 +35,7 @@ def XC(kernel, parameters=None, atoms=None, collinear=True):
     In this way one has access to all the functionals defined in libxc.
     See xc_funcs.h for the complete list.  """
 
-    if isinstance(kernel, basestring):
+    if isinstance(kernel, str):
         kernel = xc_string_to_dict(kernel)
 
     kwargs = {}
@@ -71,8 +68,8 @@ def XC(kernel, parameters=None, atoms=None, collinear=True):
             from gpaw.xc.hybrid import HybridXC
             return HybridXC(parts[0], omega=float(parts[1][:-1]))
         elif name in ['HSE03', 'HSE06']:
-            from gpaw.xc.exx import EXX
-            return EXX(name, **kwargs)
+            from gpaw.hybrids import HybridXC
+            return HybridXC(name, **kwargs)
         elif name == 'BEE1':
             from gpaw.xc.bee import BEE1
             kernel = BEE1(parameters)
