@@ -32,7 +32,8 @@ class GGARadialExpansion:
             w = weight_n[n]
             rnablaY_Lv = rnablaY_nLv[n, :Lmax]
             e_g, dedn_sg, b_vsg, dedsigma_xg = \
-                self.rcalc(rgd, n_sLg, Y_L, dndr_sLg, rnablaY_Lv, n, *self.args)
+                self.rcalc(rgd, n_sLg, Y_L, dndr_sLg, rnablaY_Lv, n,
+                           *self.args)
             dEdD_sqL += np.dot(rgd.dv_g * dedn_sg,
                                n_qg.T)[:, :, np.newaxis] * (w * Y_L)
             dedsigma_xg *= rgd.dr_g
@@ -103,7 +104,7 @@ class GGARadialCalculator:
 
 
 def calculate_sigma(gd, grad_v, n_sg):
-    """Calculate sigma(r) and grad n(r).
+    r"""Calculate sigma(r) and grad n(r).
                   _     __   _  2     __    _
     Returns sigma(r) = |\/ n(r)|  and \/ n (r).
 
@@ -134,7 +135,7 @@ def calculate_sigma(gd, grad_v, n_sg):
 
 
 def add_gradient_correction(grad_v, gradn_svg, sigma_xg, dedsigma_xg, v_sg):
-    """Add gradient correction to potential.
+    r"""Add gradient correction to potential.
 
     ::
 
@@ -309,6 +310,7 @@ class PurePythonGGAKernel:
             dedsigma_xg[1][:] += 2.0 * n * decda2
             dedsigma_xg[2][:] += 2.0 * nb * dexbda2 + n * decda2
 
+
 def pbe_constants(name):
     if name == 'pyPBE':
         name = 'PBE'
@@ -330,6 +332,7 @@ def pbe_constants(name):
 
     return name, kappa, mu, beta
 
+
 # a2 = |grad n|^2
 def gga_x(name, spin, n, a2, kappa, mu, dedmu_g=None):
     # if dedmu is given, calculate also d(e_x)/d(mu)
@@ -362,7 +365,7 @@ def gga_x(name, spin, n, a2, kappa, mu, dedmu_g=None):
     dexdrs = dexdrs * Fx + ex * dFxds2 * ds2drs
     dexda2 = ex * dFxds2 * c
     if dedmu_g is not None:
-        dedmu_g[:] = ex * s2 / (1 + mu*s2 / kappa) **2
+        dedmu_g[:] = ex * s2 / (1 + mu * s2 / kappa)**2
     ex *= Fx
 
     return ex, rs, dexdrs, dexda2
@@ -492,7 +495,8 @@ def gga_c(name, spin, n, a2, zeta, BETA, decdbeta_g=None):
             phi3 = 1.0
         Y = GAMMA * phi3
         decdbeta_g[:] = Y / X * t2 / GAMMA
-        decdbeta_g *= (1 + 2*At2) / (1+At2+At2**2) - (1+At2)*(At2+2*At2**2) / (1+At2+At2**2)**2
+        decdbeta_g *= ((1 + 2 * At2) / (1 + At2 + At2**2) -
+                       (1 + At2) * (At2 + 2 * At2**2) / (1 + At2 + At2**2)**2)
 
     return ec, rs, decdrs, decda2, decdzeta
 
