@@ -145,7 +145,7 @@ class NonLocalFunctional(XCFunctional):
         self.xcs[contribution.get_name()] = contribution
 
     def print_functional(self):
-        if world.rank is not 0:
+        if world.rank != 0:
             return
         print()
         print("Functional being used consists of")
