@@ -127,9 +127,10 @@ class LDA(XCFunctional):
         v_sg = self.gd.zeros(nspins)
         e_g = self.gd.empty()
         self.calculate_impl(self.gd, n_sg, v_sg, e_g)
-        stress = self.gd.integrate(e_g)
+        stress = self.gd.integrate(e_g, global_integral=False)
         for v_g, n_g in zip(v_sg, n_sg):
-            stress -= self.gd.integrate(v_g, n_g)
+            stress -= self.gd.integrate(v_g, n_g, global_integral=False)
+        stress = self.gd.comm.sum(stress)
         return np.eye(3) * stress
 
 
